import { Observable } from 'rxjs';
import { ProviderParams } from '../helpers/common';
import { MatchBy, MatchingBy, MatchingStrategy } from '../models/matching-strategy';
/**
 * Base data provider class.
 */
export declare abstract class AbstractDataProvider<T> {
    /** @hidden */
    abstract fetch(params: ProviderParams, start?: number, end?: number): Observable<T[]>;
    /** @hidden */
    abstract getTotalItems(params?: Map<string, any>): Observable<number>;
    /** @hidden */
    protected _keyPath: string;
    /** @hidden */
    protected _matchingStrategy: MatchingStrategy;
    /** @hidden */
    protected _matchingBy: MatchingBy | null;
    /** @hidden */
    setLookupKey(key: string): void;
    /** @hidden */
    setMatchingBy(matchingBy: MatchingBy): void;
    /** @hidden */
    setMatchingStrategy(strategy: MatchingStrategy): void;
}
/**
 * Default data provider class used for other components to extend from.
 */
export declare class DataProvider<T> extends AbstractDataProvider<T> {
    protected values: Observable<T[]> | T[];
    /** Default limit for the pagination. */
    defaultLimit: number;
    /** @hidden */
    constructor(values: Observable<T[]> | T[]);
    /** @hidden */
    fetch(params: Map<string, any>): Observable<T[]>;
    /**
     * Returns observable with the number of total items that satisfy the search query.
     * Warning: this is a naive implementation of the number of the filtered items.
     * For real-world scenarios, it is recommended to override this method with its own logic.
     */
    getTotalItems(params: Map<string, any>): Observable<number>;
    /**
     * Warning: If you don't supply search Key and you want fulltext search, and you use this
     * default implementation, be aware that it can perform poorly as it is a naive implementation
     * that does not do deep compare.
     */
    matches(item: T, pattern: string): boolean;
    /** @hidden */
    matchesBy(item: any, pattern: string, matchingBy: MatchBy): boolean;
    /** @hidden */
    protected hasObjectValue(obj: any, pattern: string): boolean;
    /** @hidden */
    private withLimit;
}
