import { BehaviorSubject, Observable, Subject } from 'rxjs';
import { DataSourceProvider } from '../models';
import { AbstractDataProvider } from './abstract-data-provider.class';
export declare abstract class BaseDataSource<T> implements DataSourceProvider<T> {
    dataProvider: AbstractDataProvider<any>;
    /**
     * Max limit of items to be returned.
     */
    static readonly MaxLimit = 5;
    /**
     * Whether to enable limit of max items.
     */
    limitless: boolean;
    /** @hidden */
    protected readonly _dataChanges$: BehaviorSubject<T[]>;
    /** @hidden */
    protected readonly _dataRequested$: BehaviorSubject<boolean>;
    /** @hidden */
    protected readonly _dataReceived$: BehaviorSubject<boolean>;
    /** @hidden */
    protected readonly _destroy$: Subject<void>;
    /** @hidden */
    protected readonly _dataLoading$: BehaviorSubject<boolean>;
    /**
     * Emitted when new data has been requested.
     * @returns Observable
     */
    get dataRequested(): Observable<boolean>;
    /**
     * Emitted when new data has been received.
     * @returns Observable
     */
    get dataReceived(): Observable<boolean>;
    /**
     * Emitted when loading state has been changed.
     * @returns Observable.
     */
    get dataLoading(): Observable<boolean>;
    /**
     * Emits when the data from the provider has been changed.
     * @returns Observable of data source objects.
     */
    get dataChanges(): Observable<T[]>;
    /** @hidden */
    protected constructor(dataProvider: AbstractDataProvider<any>);
    /**
     * Searches through the data source with defined parameters.
     * @param predicate Search query.
     * @param start start index.
     * @param end end index.
     */
    match(predicate?: string | Map<string, string>, start?: number, end?: number): void;
    /**
     * Returns the Observable of a total items number filtered by the `predicate` param.
     * @param predicate Search query.
     */
    getTotalItems(predicate?: string | Map<string, string>): Observable<number>;
    /**
     * Closes the stream
     */
    unsubscribe(): void;
    /** @hidden */
    private _getSearchParams;
}
