import { BooleanInput } from '@angular/cdk/coercion';
import { AfterViewInit, DoCheck, ElementRef, EventEmitter, OnDestroy, OnInit } from '@angular/core';
import { ControlContainer, ControlValueAccessor, NgControl, NgForm } from '@angular/forms';
import { HasElementRef, Nullable } from '@fundamental-ngx/cdk/utils';
import { Subject, Subscription } from 'rxjs';
import { BaseCVA } from '../models/cva';
import { FormField, FormFieldControl } from '../models/form-field';
import { FormStates } from '../models/form-state';
import * as i0 from "@angular/core";
export declare class CvaDirective<T = any> implements HasElementRef, BaseCVA, FormFieldControl, OnInit, DoCheck, AfterViewInit, OnDestroy, ControlValueAccessor {
    /** Input placeholder */
    placeholder: string;
    /**
     *  The state of the form control - applies css classes.
     *  Can be 'success', 'error', 'warning', 'default', 'information'.
     *
     * @default 'default'
     */
    set state(state: Nullable<FormStates>);
    get state(): FormStates;
    /** Holds the message with respect to state */
    stateMessage: Nullable<string>;
    /** Whether the input is disabled */
    set disabled(value: boolean);
    get disabled(): boolean;
    /**
     * readOnly Value to Mark component read only
     */
    readonly: boolean;
    /** Binds to control aria-labelledBy attribute */
    ariaLabelledBy: Nullable<string>;
    /** Sets control aria-label attribute value */
    ariaLabel: Nullable<string>;
    /**
     * Tell the component if we are in editing mode.
     */
    set editable(value: BooleanInput);
    get editable(): boolean;
    /**
     * Name of the control.
     */
    name: string;
    /**
     * Emits when change detection is needed.
     */
    detectChanges: EventEmitter<void>;
    /**
     * Emits when mark for changes detection is needed.
     */
    markForCheck: EventEmitter<void>;
    /**
     * Reference to internal Input element
     */
    protected _elementRef: ElementRef;
    /** @hidden */
    value: T;
    /** set when input field is mandatory form field */
    required: boolean;
    /**
     * See @FormFieldControl
     */
    focused: boolean;
    /** Whether control has errors */
    get controlInvalid(): boolean;
    /**
     * See @FormFieldControl
     */
    readonly stateChanges: Subject<any>;
    /** @hidden */
    readonly formField: FormField | null;
    /**
     * NgControl instance.
     */
    readonly ngControl: NgControl | null;
    /**
     * Form container instance. Usually ngForm or FormGroup directives.
     */
    readonly controlContainer: ControlContainer | null;
    /**
     * Separate NgForm instance. For cases when formGroup is used with the form itself.
     */
    readonly ngForm: NgForm | null;
    /** @hidden */
    readonly normalizedState$: import("@angular/core").Signal<"success" | "error" | "warning" | "default" | "information">;
    /** @hidden */
    protected _subscriptions: Subscription;
    /**
     * A private property to hold the ElementRef which might be null
     */
    private _elementRefOrNull;
    /**
     * Element reference.
     */
    get elementRef(): ElementRef;
    /** @hidden */
    private _defaultId;
    /** ID for the Element */
    id: string;
    /** @hidden */
    private _disabled;
    /** @hidden */
    private _editable;
    /**
     * @hidden
     */
    private readonly _controlInvalid$;
    /** @hidden */
    private readonly _parentControl;
    /**
     * @hidden
     * The state of the form control - applies css classes.
     * Can be `success`, `error`, `warning`, `information` or 'default'
     */
    private readonly _state$;
    /** @hidden */
    constructor();
    /** @hidden */
    onChange: (value: any) => void;
    /** @hidden */
    onTouched: () => void;
    /** @hidden */
    ngOnInit(): void;
    /**
     * Re-validate and emit event to parent container on every CD cycle as they are some errors
     * that we can't subscribe to.
     */
    ngDoCheck(): void;
    /** @hidden */
    ngAfterViewInit(): void;
    /** @hidden */
    registerOnChange(fn: (_: any) => void): void;
    /** @hidden */
    registerOnTouched(fn: () => void): void;
    /** @hidden */
    ngOnDestroy(): void;
    /** @hidden */
    setDisabledState(isDisabled: BooleanInput): void;
    /**
     * Method for setting the value
     * @param value
     */
    writeValue(value: T): void;
    /**
     *
     * Keeps track of element focus
     */
    _onFocusChanged(isFocused: boolean): void;
    /**
     * Handles even when we click on parent container which is the FormField Wrapping this
     * control
     */
    onContainerClick(event: MouseEvent): void;
    /**
     * In most of the cases when working with input element directly you should be just find to assign
     * variable to this element
     *
     * ```
     * <input #inputElementRef fd-form-control ...>
     * ```
     *
     * and this default behavior used. For other cases implement focus.
     *
     */
    focus(event?: MouseEvent): void;
    /**
     *  Need re-validates errors on every CD iteration to make sure we are also
     *  covering non-control errors, errors that happens outside of this control
     */
    updateErrorState(): void;
    /**
     * Used to change the value of a control.
     * @param value the value to be applied
     * @param emitOnChange whether to emit "onChange" event.
     * Should be "false", if the change is made programmatically (internally) by the control, "true" otherwise
     */
    setValue(value: T, emitOnChange?: boolean): void;
    /** @hidden */
    private _markForCheck;
    static ɵfac: i0.ɵɵFactoryDeclaration<CvaDirective<any>, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<CvaDirective<any>, "[fdkCva]", never, { "placeholder": { "alias": "placeholder"; "required": false; }; "state": { "alias": "state"; "required": false; }; "stateMessage": { "alias": "stateMessage"; "required": false; }; "disabled": { "alias": "disabled"; "required": false; }; "readonly": { "alias": "readonly"; "required": false; }; "ariaLabelledBy": { "alias": "ariaLabelledBy"; "required": false; }; "ariaLabel": { "alias": "ariaLabel"; "required": false; }; "editable": { "alias": "editable"; "required": false; }; "name": { "alias": "name"; "required": false; }; "id": { "alias": "id"; "required": false; }; }, { "detectChanges": "detectChanges"; "markForCheck": "markForCheck"; }, never, never, true, never>;
}
