import { CdkPortalOutlet, ComponentType } from '@angular/cdk/portal';
import { AfterViewInit, ComponentRef, ElementRef, EmbeddedViewRef, EventEmitter, TemplateRef } from '@angular/core';
import * as i0 from "@angular/core";
/**
 * A component that can be used to attach a portal to a DOM element, without explicitly creating portal instances on place.
 * This is useful when you have a list of the components or templates, or HTMLElmets, and you want to attach them to the DOM
 * dynamically in a loop.
 */
export declare class DynamicPortalComponent implements AfterViewInit {
    /** The DOM element to attach */
    set domElement(value: HTMLElement | ElementRef<HTMLElement> | string);
    /** The component to attach */
    set component(value: ComponentType<any>);
    /** The template to attach */
    set template(value: TemplateRef<any>);
    /** The Content which should be attached and can be any of the items */
    set auto(value: DynamicPortalComponent['domElement' | 'component' | 'template']);
    /** Emits when the portal is attached */
    attached: EventEmitter<Element | EmbeddedViewRef<any> | ComponentRef<any>>;
    /** @hidden */
    portalOutlet?: CdkPortalOutlet;
    /** @hidden */
    private portalContent$;
    /** @hidden */
    private readonly _destroyRef;
    /** @hidden */
    private viewContainerRef;
    /** @hidden */
    private renderer;
    /** @hidden */
    private elementRef;
    /** @hidden */
    ngAfterViewInit(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<DynamicPortalComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<DynamicPortalComponent, "fdk-dynamic-portal", never, { "domElement": { "alias": "domElement"; "required": false; }; "component": { "alias": "component"; "required": false; }; "template": { "alias": "template"; "required": false; }; "auto": { "alias": "auto"; "required": false; }; }, { "attached": "attached"; }, never, never, true, never>;
}
