import { AfterViewInit, ElementRef, EmbeddedViewRef, OnChanges, TemplateRef, ViewContainerRef } from '@angular/core';
import { BehaviorSubject, Observable, Subject } from 'rxjs';
import { BreakpointName } from './responsive-breakpoints';
import * as i0 from "@angular/core";
/**
 * Directive to show/hide element on specific breakpoint or range of window width.
 * Uses native ngIf directive to show/hide element.
 */
export declare class BreakpointDirective implements OnChanges, AfterViewInit {
    private readonly templateRef;
    private readonly viewContainer;
    /**
     * Provide list of the breakpoints to show element on.
     * */
    set fdkBreakpoint(value: BreakpointName[]);
    /**
     * Show element on S breakpoint.
     * S - 0 - 599px
     * */
    showOnS: boolean;
    /**
     * Show element on M breakpoint.
     * M - 0 - 1023px
     * */
    showOnM: boolean;
    /**
     * Show element on L breakpoint.
     * L - 0 - 1439px
     * */
    showOnL: boolean;
    /**
     * Show element on XL breakpoint.
     *  */
    showOnXL: boolean;
    /**
     * Show element on breakpoint less than provided value.
     * */
    fdkBreakpointLt: number;
    /**
     * Show element on breakpoint greater than provided value.
     *  */
    fdkBreakpointGt: number;
    /**
     * Observe element width changes.
     */
    set observationSource(value: HTMLElement | ElementRef<HTMLElement>);
    /** @hidden */
    templateViewRef?: EmbeddedViewRef<unknown>;
    /** @hidden */
    onChanges$: Subject<void>;
    /** @hidden */
    _sizeObservable$: BehaviorSubject<Observable<number>>;
    /** @hidden */
    private viewportSize$;
    /** @hidden */
    private _destroyRef;
    /** @hidden */
    private _resizeObserverService;
    /** @hidden */
    constructor(templateRef: TemplateRef<any>, viewContainer: ViewContainerRef);
    /** @hidden */
    ngAfterViewInit(): void;
    /** @hidden */
    ngOnChanges(): void;
    /** @hidden */
    private _shouldShow;
    static ɵfac: i0.ɵɵFactoryDeclaration<BreakpointDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<BreakpointDirective, "[fdkBreakpoint], [fdkBreakpointS], [fdkBreakpointM], [fdkBreakpointL], [fdkBreakpointXL], [fdkBreakpointLt], [fdkBreakpointGt]", never, { "fdkBreakpoint": { "alias": "fdkBreakpoint"; "required": false; }; "showOnS": { "alias": "fdkBreakpointS"; "required": false; }; "showOnM": { "alias": "fdkBreakpointM"; "required": false; }; "showOnL": { "alias": "fdkBreakpointL"; "required": false; }; "showOnXL": { "alias": "fdkBreakpointXL"; "required": false; }; "fdkBreakpointLt": { "alias": "fdkBreakpointLt"; "required": false; }; "fdkBreakpointGt": { "alias": "fdkBreakpointGt"; "required": false; }; "observationSource": { "alias": "fdkBreakpointObserve"; "required": false; }; }, {}, never, never, true, never>;
    static ngAcceptInputType_showOnS: unknown;
    static ngAcceptInputType_showOnM: unknown;
    static ngAcceptInputType_showOnL: unknown;
    static ngAcceptInputType_showOnXL: unknown;
}
export declare class BreakpointModule {
    static ɵfac: i0.ɵɵFactoryDeclaration<BreakpointModule, never>;
    static ɵmod: i0.ɵɵNgModuleDeclaration<BreakpointModule, never, [typeof BreakpointDirective], [typeof BreakpointDirective]>;
    static ɵinj: i0.ɵɵInjectorDeclaration<BreakpointModule>;
}
