import { AfterViewInit, EventEmitter } from '@angular/core';
import { Nullable } from '../../models/nullable';
import { FocusableItemPosition, FocusableListPosition } from '../focusable-item';
import { FocusableListDirective } from '../focusable-list';
import * as i0 from "@angular/core";
export interface FocusableCellPosition {
    rowIndex: number;
    colIndex: number;
}
export declare class FocusableGridDirective implements AfterViewInit {
    /** Direction of the content. */
    contentDirection: 'ltr' | 'rtl' | null;
    /** Whether the item in the previous/next row should be selected when going out of the first/last cell in the row. Default is false. */
    wrapHorizontally: boolean;
    /** Specify which item to select in prev/next row if its length smaller than current index. Nullish value means do not select. Default is null. */
    shortRowFocus: Nullable<'first' | 'last'>;
    /** Event emitted when item focused, contains item's position info. */
    readonly itemFocused: EventEmitter<FocusableItemPosition>;
    /** Event emitted when whole row focused, contains row's position info. */
    readonly rowFocused: EventEmitter<FocusableListPosition>;
    /** @hidden */
    private readonly _focusableLists;
    /** @hidden */
    private readonly _destroyRef;
    /** @hidden */
    ngAfterViewInit(): void;
    /**
     * Focus cell by position.
     * @param position position of the cell
     */
    focusCell(position: FocusableCellPosition): void;
    /** @hidden */
    _onKeydown(event: KeyboardEvent, list: FocusableListDirective, activeItemIndex: Nullable<number>): void;
    /** @hidden */
    private _getItemIndex;
    static ɵfac: i0.ɵɵFactoryDeclaration<FocusableGridDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<FocusableGridDirective, "[fdkFocusableGrid]", ["fdkFocusableGrid"], { "contentDirection": { "alias": "contentDirection"; "required": false; }; "wrapHorizontally": { "alias": "wrapHorizontally"; "required": false; }; "shortRowFocus": { "alias": "shortRowFocus"; "required": false; }; }, { "itemFocused": "itemFocused"; "rowFocused": "rowFocused"; }, ["_focusableLists"], never, true, never>;
    static ngAcceptInputType_wrapHorizontally: unknown;
}
