import { DestroyRef, ElementRef, EventEmitter, NgZone } from '@angular/core';
import { Subject } from 'rxjs';
import { HasElementRef } from '../../interfaces/has-element-ref.interface';
import { Nullable } from '../../models/nullable';
import { FocusableItem } from './focusable.item';
import * as i0 from "@angular/core";
export type CellFocusedEventAnnouncer = Nullable<(position: FocusableItemPosition) => string>;
export interface FocusableItemPosition {
    rowIndex: number;
    colIndex: number;
    totalRows: number;
    totalCols: number;
}
export declare class FocusableItemDirective implements FocusableItem, HasElementRef {
    /** Whether the item is focusable. Default is true. */
    set fdkFocusableItem(val: boolean);
    get fdkFocusableItem(): boolean;
    /** Function, which returns a string to be announced by screen-reader whenever an item which is in grid receives focus. */
    cellFocusedEventAnnouncer: CellFocusedEventAnnouncer;
    /** Event emitted when the cell receives focus, not being emitted when focus moves between item's children. */
    readonly cellFocused: EventEmitter<FocusableItemPosition>;
    /** Element reference. */
    readonly elementRef: ElementRef<HTMLElement>;
    /** @hidden */
    readonly keydown: Subject<KeyboardEvent>;
    /** @hidden */
    _position: FocusableItemPosition;
    /** @hidden */
    protected readonly _destroyRef: DestroyRef;
    /** @hidden */
    protected readonly _zone: NgZone;
    /** @hidden */
    private _focusable;
    /** @hidden */
    private _tabbableElements;
    /** @hidden */
    private _tabbable;
    /** @hidden */
    private _timerId;
    /** @hidden */
    private readonly _focusableObserver;
    /** @hidden */
    private readonly _tabbableElementService;
    /** @hidden */
    private readonly _liveAnnouncer;
    /** @hidden */
    private readonly _renderer2;
    /** @hidden */
    private readonly _document;
    /** @hidden */
    constructor();
    /** @hidden */
    element: () => HTMLElement;
    /** @hidden */
    isFocusable(): boolean;
    /** @hidden */
    focus(): void;
    /** Set tabbable state */
    setTabbable(state: boolean): void;
    /** @hidden */
    private _onFocusin;
    /** @hidden */
    private _onFocusout;
    /** @hidden */
    private _onKeydown;
    /** @hidden */
    private _enableTabbableElements;
    /** @hidden */
    private _disableTabbableElements;
    /** @hidden */
    private _defaultItemFocusedEventAnnouncer;
    static ɵfac: i0.ɵɵFactoryDeclaration<FocusableItemDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<FocusableItemDirective, "[fdkFocusableItem]", never, { "fdkFocusableItem": { "alias": "fdkFocusableItem"; "required": false; }; "cellFocusedEventAnnouncer": { "alias": "cellFocusedEventAnnouncer"; "required": false; }; }, { "cellFocused": "cellFocused"; }, never, never, true, never>;
    static ngAcceptInputType_fdkFocusableItem: unknown;
}
