import { AfterViewInit, DestroyRef, EventEmitter, OnChanges, OnDestroy, SimpleChanges } from '@angular/core';
import { Observable, Subject } from 'rxjs';
import { Nullable } from '../../models/nullable';
import { FocusableItem, FocusableListPosition } from '../focusable-item';
import { FocusableItemPosition } from '../focusable-item/focusable-item.directive';
import { ScrollPosition } from './scroll';
import * as i0 from "@angular/core";
export interface FocusableListItemFocusedEvent {
    index: number;
    total: number;
}
export interface FocusableListKeydownEvent {
    list: FocusableListDirective;
    event: KeyboardEvent;
    activeItemIndex: Nullable<number>;
}
export interface ItemsQueryList<T> extends Iterable<T> {
    changes: Observable<ItemsQueryList<T>>;
    length: number;
    toArray(): T[];
    find(predicate: (item: T, index: number) => boolean): Nullable<T>;
    get(index: number): Nullable<T>;
    forEach(param: (item: T, index: number) => void): void;
}
export declare class FocusableListDirective implements OnChanges, AfterViewInit, OnDestroy {
    /** Whether the whole list should be focusable, handy in grids. */
    set focusable(value: boolean);
    get focusable(): boolean;
    /** Direction of navigation. Should be set to 'grid' when list is a part of grid. */
    navigationDirection: 'horizontal' | 'vertical' | 'grid';
    /** Direction of the content. */
    contentDirection: 'ltr' | 'rtl' | null;
    /**
     * Configures wrapping mode which determines whether the active item will wrap to the other end of list when there are no more items in the given direction.
     */
    wrap: boolean;
    /** Function, which returns a string to be announced by screen-reader whenever an row which is in grid receives focus. */
    listFocusedEventAnnouncer: (position: FocusableListPosition) => string;
    /** Event emitted when list's item focused, contains item's position info. */
    readonly itemFocused: EventEmitter<FocusableListItemFocusedEvent>;
    /** @hidden */
    readonly _projectedFocusableItems: ItemsQueryList<FocusableItem>;
    /** @hidden */
    get _focusableItems(): ItemsQueryList<FocusableItem>;
    /** @hidden */
    _items: ItemsQueryList<FocusableItem> | undefined;
    /** @hidden */
    readonly _gridItemFocused$: Subject<FocusableItemPosition>;
    /** @hidden */
    readonly _gridListFocused$: Subject<FocusableListPosition>;
    /** @hidden */
    readonly _keydown$: Subject<FocusableListKeydownEvent>;
    /** @hidden */
    _isVisible: boolean;
    /** @hidden */
    protected readonly _destroyRef: DestroyRef;
    /** @hidden */
    protected _focusable: boolean;
    /** @hidden */
    private _gridPosition;
    /** @hidden */
    private _keyManager?;
    /** @hidden */
    private _tabbable;
    /** @hidden */
    private readonly _refreshItems$;
    /** @hidden */
    private readonly _refresh$;
    /** @hidden */
    private readonly _renderer;
    /** @hidden */
    private readonly _elementRef;
    /** @hidden */
    private readonly _liveAnnouncer;
    /** @hidden */
    private readonly _focusableObserver;
    /** @hidden */
    private readonly _document;
    /** @hidden */
    get _tabindex(): number;
    /** @hidden */
    constructor();
    /** @hidden */
    _onKeydown(event: KeyboardEvent): void;
    /** @hidden */
    _onFocus(): Promise<void>;
    /** @hidden */
    ngOnChanges(changes: SimpleChanges): void;
    /** @hidden */
    ngAfterViewInit(): void;
    /** Set items programmatically. */
    setItems(items: ItemsQueryList<FocusableItem>): void;
    /** @hidden */
    ngOnDestroy(): void;
    /** Set active item in list */
    setActiveItem(index: number, scrollPosition?: ScrollPosition): void;
    /** Focus whole list */
    focus(scrollPosition?: ScrollPosition): void;
    /** Set tabbable state */
    setTabbable(state: boolean): void;
    /** @hidden */
    _updateNavigationDirection(): void;
    /** @hidden */
    _setItemsTabbable(state: boolean): void;
    /** @hidden */
    _setGridPosition(position: FocusableListPosition): void;
    /** @hidden */
    private _initializeFocusManager;
    /** @hidden */
    private _defaultListFocusedEventAnnouncer;
    /** @hidden */
    private _listenOnItems;
    static ɵfac: i0.ɵɵFactoryDeclaration<FocusableListDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<FocusableListDirective, "[fdkFocusableList]", ["fdkFocusableList"], { "focusable": { "alias": "focusable"; "required": false; }; "navigationDirection": { "alias": "navigationDirection"; "required": false; }; "contentDirection": { "alias": "contentDirection"; "required": false; }; "wrap": { "alias": "wrap"; "required": false; }; "listFocusedEventAnnouncer": { "alias": "listFocusedEventAnnouncer"; "required": false; }; }, { "itemFocused": "itemFocused"; }, ["_projectedFocusableItems"], never, true, never>;
    static ngAcceptInputType_focusable: unknown;
    static ngAcceptInputType_wrap: unknown;
}
