import { AfterViewInit, ElementRef, EventEmitter, OnChanges, OnDestroy, SimpleChanges } from '@angular/core';
import { Nullable } from '../../models/nullable';
import { RtlService } from '../../services/rtl.service';
import { ResizeHandleDirective } from './resize-handle.directive';
import * as i0 from "@angular/core";
export declare class ResizeDirective implements OnChanges, AfterViewInit, OnDestroy {
    private _elementRef;
    private _rtlService;
    /** Element limiting resizable container growth */
    resizeBoundary: string | HTMLElement;
    /** Whether resizable behaviour should be disabled */
    disabled: boolean;
    /** Additional class to be applied to the Element ref during resize. */
    fdkResizeClass: string;
    /** Localization of resize handle inside resizable container */
    resizeHandleLocation: 'top-right' | 'top-left' | 'bottom-right' | 'bottom-left';
    /** Resize handle reference - should be used if Resize handle is not a ContentChild of resizable container */
    set setResizeHandleReference(value: ResizeHandleDirective);
    /** Emits event when resizing has tarted */
    onResizeStart: EventEmitter<void>;
    /** Emits event when resizing has ended */
    onResizeEnd: EventEmitter<void>;
    /** @hidden Reference to Resize handle */
    set resizeHandleReference(value: Nullable<ResizeHandleDirective>);
    get resizeHandleReference(): Nullable<ResizeHandleDirective>;
    /** @hidden */
    private _resizeHandleReference;
    /** @hidden */
    private _subscriptions;
    /** @hidden */
    private _resizeSubscriptions;
    /** @hidden */
    private readonly _direction$;
    /** @hidden */
    constructor(_elementRef: ElementRef<HTMLElement>, _rtlService: RtlService);
    /** @hidden */
    ngOnChanges(changes: SimpleChanges): void;
    /** @hidden */
    ngAfterViewInit(): void;
    /** @hidden */
    ngOnDestroy(): void;
    /** @hidden */
    private _unsubscribe;
    /** @hidden Sets Resize listeners */
    private _setResizeListeners;
    /** @hidden Creates resize function*/
    private _getResizeFunction;
    /** @hidden Creates move function */
    private _getMoveOffsetFunction;
    /** @hidden Return boundary container */
    private _findResizeContainer;
    /** @hidden Check whether resizable container is overflowing boundary container */
    private _getBoundaryOverflowFunction;
    /** @hidden Create Observable notifying on resize actions */
    private _getResizeEventsNotifiers;
    /** @hidden Block resizable container pointer events when resizing  */
    private _blockOtherPointerEvents;
    static ɵfac: i0.ɵɵFactoryDeclaration<ResizeDirective, [null, { optional: true; }]>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<ResizeDirective, "[fdkResize]", never, { "resizeBoundary": { "alias": "fdkResizeBoundary"; "required": false; }; "disabled": { "alias": "fdkResizeDisabled"; "required": false; }; "fdkResizeClass": { "alias": "fdkResizeClass"; "required": false; }; "resizeHandleLocation": { "alias": "fdkResizeHandleLocation"; "required": false; }; "setResizeHandleReference": { "alias": "fdkResizeResizeHandleRef"; "required": false; }; }, { "onResizeStart": "onResizeStart"; "onResizeEnd": "onResizeEnd"; }, ["resizeHandleReference"], never, true, never>;
}
