import { DragDrop } from '@angular/cdk/drag-drop';
import { AfterContentInit, ElementRef, EventEmitter, OnDestroy, Renderer2 } from '@angular/core';
import { Nullable } from '../../models/nullable';
import { DndItem, ElementChord, ElementPosition, LinkPosition } from '../dnd.interfaces';
import * as i0 from "@angular/core";
export declare class DndItemDirective<T = any> implements DndItem, AfterContentInit, OnDestroy {
    readonly elementRef: ElementRef;
    private readonly _dragDrop;
    private readonly _renderer;
    /** Item reference. Used for cases when `[items]` array of dnd list is different than `dndItems` content children. */
    item: Nullable<T>;
    /**
     * Whether to apply "fd-dnd-item" class.
     * @default true
     */
    applyDragItemClass: boolean;
    /** Container selector */
    containerSelector?: string;
    /** Event thrown when the element is moved by 1px */
    readonly moved: EventEmitter<ElementPosition>;
    /** Event thrown when the element is released */
    readonly released: EventEmitter<void>;
    /** Event thrown when the element is started to be dragged */
    readonly started: EventEmitter<void>;
    /**
     *  Defines if the item is prevented from being moved by other elements.
     * So nothing can be placed just before and just after it
     */
    stickInPlace: boolean;
    /** Defines if element is draggable */
    set draggable(draggable: boolean);
    /** Class added to element, when it's dragged. */
    classWhenElementDragged: string;
    /** Defines if every element in list is draggable */
    listDraggable: boolean;
    /** @hidden
     * Drag reference, object created from DND CDK Service
     */
    private _dragRef;
    /** @hidden */
    private _draggable;
    /** @hidden */
    private _subscriptions;
    /** @hidden */
    private _placeholderElement;
    /** @hidden */
    private _lineElement;
    /** @hidden */
    private _replaceIndicator;
    /** @hidden */
    constructor(elementRef: ElementRef, _dragDrop: DragDrop, _renderer: Renderer2);
    /** @hidden */
    getElementCoordinates(isBefore: boolean): ElementChord;
    /** @hidden */
    ngAfterContentInit(): void;
    /** @hidden */
    ngOnDestroy(): void;
    /** @hidden */
    onCdkMove(position: ElementPosition): void;
    /** @hidden */
    onCdkDragReleased(): void;
    /** @hidden */
    onCdkDragStart(): void;
    /** @hidden */
    removePlaceholder(): void;
    /** @hidden */
    removeLine(): void;
    /** @hidden */
    removeReplaceIndicator(): void;
    /** @hidden */
    createReplaceIndicator(): void;
    /** @hidden */
    createLine(position: LinkPosition, gridMode: boolean): void;
    /** @hidden */
    changeCDKDragState(): void;
    /**
     * Sets the disabled state of the dnd item.
     * @param state
     */
    setDisabledState(state: boolean): void;
    /** @hidden */
    private createPlaceholder;
    /** @hidden */
    private _setPlaceholderStyles;
    /** @hidden */
    private _getOffsetToParent;
    /** @hidden */
    private _setCDKDrag;
    /** IE11 equivalent of Node.after() Method */
    private _placeAfter;
    /** @hidden */
    private _listenElementEvents;
    static ɵfac: i0.ɵɵFactoryDeclaration<DndItemDirective<any>, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<DndItemDirective<any>, "[fdkDndItem], [fd-dnd-item]", never, { "item": { "alias": "fdkDndItem"; "required": false; }; "applyDragItemClass": { "alias": "applyDragItemClass"; "required": false; }; "containerSelector": { "alias": "containerSelector"; "required": false; }; "stickInPlace": { "alias": "stickInPlace"; "required": false; }; "draggable": { "alias": "draggable"; "required": false; }; "classWhenElementDragged": { "alias": "classWhenElementDragged"; "required": false; }; }, { "moved": "moved"; "released": "released"; "started": "started"; }, never, never, true, never>;
}
