import { ElementRef, OnDestroy, OnInit } from '@angular/core';
import { DndKeyboardGroupDirective } from '../dnd-keyboard-group/dnd-keyboard-group.directive';
import * as i0 from "@angular/core";
/**
 * This directive is used to provide drag & drop with keyboard support.
 * It should be used together with directive fdDndKeyboardGroup.
 * We are using _groups from fdDndKeyboardGroup and adding a possibility to move cards.
 * Please see example below:
 * @Component({
 * selector: 'cdk-drag-drop-example',
 * template: `<div
 *               cdkDragListGroup
 *               fdDndKeyboardGroup
 *               [groups]="groups"
 *           >
 *               <div
 *                   *ngFor="let group of groups; let groupIndex = index"
 *                   cdkDragList
 *               >
 *                   Group #{{ groupIndex }}
 *                   <div
 *                       *ngFor="let item of group; let index = index"
 *                       cdkDrag
 *                       fdDndKeyboardItem
 *                       [itemIndex]="index"
 *                       [groupIndex]="groupIndex"
 *                       [dndKeyboardDisabled]="flag for disable/enable keyboard navigation if needed"
 *                       tabindex="0"
 *                   >
 *                       Item #{{ item }}
 *                   </div>
 *               </div>
 *           </div>`,
 * })
 * export class CdkDragDropExample {
 *   groups = [
 *        [1, 2, 3],
 *        [4, 5, 6],
 *      ];
 *   }
 */
export declare class DndKeyboardItemDirective implements OnInit, OnDestroy {
    private readonly _dndGroup;
    private readonly _elementRef;
    /** item index in group(column) */
    itemIndex: number;
    /** group(column) index */
    groupIndex: number;
    /** @hidden */
    private readonly _onDestroy$;
    /** @hidden */
    constructor(_dndGroup: DndKeyboardGroupDirective, _elementRef: ElementRef);
    /** @hidden */
    _onKeyDown(event: KeyboardEvent): void;
    /** @hidden */
    ngOnInit(): void;
    /** @hidden */
    ngOnDestroy(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<DndKeyboardItemDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<DndKeyboardItemDirective, "[fdkDndKeyboardItem], [fdDndKeyboardItem]", never, { "itemIndex": { "alias": "itemIndex"; "required": false; }; "groupIndex": { "alias": "groupIndex"; "required": false; }; }, {}, never, never, true, never>;
}
