import { ApplicationRef, Compiler, ComponentFactoryResolver, ComponentRef, Injector, NgModuleFactory, TemplateRef, Type, ViewContainerRef } from '@angular/core';
import { DynamicComponentConfig } from './dynamic-component-config';
import * as i0 from "@angular/core";
/**
 * Service used to dynamically generate components like dialogs/alerts/notifications
 */
export declare class DynamicComponentService {
    private readonly _componentFactoryResolver;
    private readonly _applicationRef;
    private readonly _injector;
    private readonly _compiler;
    /** @hidden */
    constructor(_componentFactoryResolver: ComponentFactoryResolver, _applicationRef: ApplicationRef, _injector: Injector, _compiler: Compiler);
    /**
     * Function that creates dynamic component and injects services to allow communication between component and outside
     * @param content Type of the component content
     * @param componentType Type of component that should be rendered.
     * @param config Configuration that will be passed to the component.
     * @param inject  enables to provide preconfigured component injector and dependencies
     */
    createDynamicComponent<T>(content: TemplateRef<any> | Type<any> | string | Record<string, any>, componentType: Type<T>, config: DynamicComponentConfig, inject?: {
        injector?: Injector;
        services?: any[];
    }): ComponentRef<T>;
    /**
     * Function that creates dynamic component and injects services to allow communication between component and outside
     * @param content Type of the component content
     * @param moduleType Type of module that should be compiled.
     * @param componentType Type of component that should be rendered.
     * @param containerRef The container that the dynamic component is appended to.
     * @param injector enables to provide preconfigured component injector
     */
    createDynamicModule<M, C>(content: TemplateRef<any> | Type<any> | string | Record<string, any>, moduleType: Type<M> | NgModuleFactory<M>, componentType: Type<C>, containerRef: ViewContainerRef, injector?: Injector): Promise<ComponentRef<C>>;
    /** Function that destroys dynamic component */
    destroyComponent(componentRef: ComponentRef<any>): void;
    /** @hidden */
    private _createDependencyMap;
    /** @hidden */
    private _attachToContainer;
    /** @hidden */
    private _createComponent;
    /** @hidden */
    private _passExternalContent;
    static ɵfac: i0.ɵɵFactoryDeclaration<DynamicComponentService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<DynamicComponentService>;
}
