/** @hidden */
interface DfsOptions<T> {
    children: string | ((item: T) => Array<T>);
    shouldVisit: (item: T) => boolean;
    postOrder: boolean;
}
/**
 * Depth-first search algorithm, which traverses a tree/graph/tree-like structure.
 * callback is called for each item in the collection. The order of the callback calls
 * depends on the options. By default, the algorithm is post-order, which means that
 * the callback is called for each item after its children have been visited.
 *
 * @param collection
 * @param callback
 * @param options
 */
export declare function dfs<T>(collection: Array<T>, callback: (item: T) => void, options?: Partial<DfsOptions<T>>): void;
export {};
