import { FocusTrap, Options } from 'focus-trap';
import * as i0 from "@angular/core";
export declare class FocusTrapService {
    /** @hidden */
    private _focusTrapInstances;
    /**
     * Creates focus trap instance for defined element
     * @param element Container for which to create focus trap
     * @param userOptions Focus-trap specific configuration
     * @returns {string} Unique ID of focus trap instance
     */
    createFocusTrap(element: string | HTMLElement | SVGElement | (string | HTMLElement | SVGElement)[], userOptions?: Options): string;
    /**
     * Activates focus trap for defined ID
     * @param id Unique ID of focus trap instance
     */
    activateFocusTrap(id: string): void;
    /**
     * Deactivates focus trap for defined ID
     * @param id Unique ID of focus trap instance
     */
    deactivateFocusTrap(id: string): void;
    /**
     * Pauses current focus trap.
     */
    pauseCurrentFocusTrap(): void;
    /**
     * Unpauses current focus trap.
     */
    unpauseCurrentFocusTrap(): void;
    /**
     * Get focus trap instance by ID.
     * @param id ID of the instance.
     * @returns Focus trap instance if exists.
     */
    getFocusTrapInstance(id: string): FocusTrap | undefined;
    /** @hidden */
    private _getLastTrapedItem;
    /** @hidden */
    private _focusTrapExists;
    static ɵfac: i0.ɵɵFactoryDeclaration<FocusTrapService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<FocusTrapService>;
}
