import { ConnectedPosition, ScrollStrategy } from '@angular/cdk/overlay';
export interface ToastGlobalPosition {
    left?: string;
    right?: string;
    bottom?: string;
    top?: string;
    center: boolean;
    centerVertically?: boolean;
}
export interface ToastGlobalConnectedPosition extends ConnectedPosition {
    boundTo: HTMLElement;
}
export declare const toastConnectedTopPosition: ConnectedPosition;
export declare const toastConnectedTopLeftPosition: ConnectedPosition;
export declare const toastConnectedTopRightPosition: ConnectedPosition;
export declare const toastConnectedBottomPosition: ConnectedPosition;
export declare const toastConnectedBottomLeftPosition: ConnectedPosition;
export declare const toastConnectedBottomRightPosition: ConnectedPosition;
/**
 * Base Toast Position class.
 */
export declare abstract class BaseToastPosition {
    /**
     * Position strategy of the first item.
     */
    global: ToastGlobalPosition | ToastGlobalConnectedPosition;
    /**
     * Position strategy of the newly added items.
     */
    connected: ConnectedPosition;
    /**
     * Scroll strategy. Used when global position is bound to some HTML element on the page.
     */
    scrollPosition?: ScrollStrategy;
}
/**
 * Toast Position class.
 * The first item will pop from the top-center of the screen.
 * New items will stack after the first item.
 */
export declare class ToastTopCenterPosition extends BaseToastPosition {
    /** @hidden */
    static global: ToastGlobalPosition;
    /** @hidden */
    static connected: ConnectedPosition;
}
/**
 * Toast Position class.
 * The first item will pop from the bottom-center of the screen.
 * New items will stack before first item.
 */
export declare class ToastBottomCenterPosition extends BaseToastPosition {
    /** @hidden */
    static global: ToastGlobalPosition;
    /** @hidden */
    static connected: ConnectedPosition;
}
/**
 * Toast Position class.
 * The first item will pop from the top-left of the screen.
 * New items will stack after first item.
 */
export declare class ToastTopLeftPosition extends ToastTopCenterPosition {
    /** @hidden */
    static global: {
        left: string;
        center: boolean;
        right?: string;
        bottom?: string;
        top?: string;
        centerVertically?: boolean;
    };
    /** @hidden */
    static connected: ConnectedPosition;
}
/**
 * Toast Position class.
 * The first item will pop from the top-right of the screen.
 * New items will stack after first item.
 */
export declare class ToastTopRightPosition extends ToastTopCenterPosition {
    /** @hidden */
    static global: {
        right: string;
        center: boolean;
        left?: string;
        bottom?: string;
        top?: string;
        centerVertically?: boolean;
    };
    /** @hidden */
    static connected: ConnectedPosition;
}
/**
 * Toast Position class.
 * The first item will pop from the bottom-left of the screen.
 * New items will stack before first item.
 */
export declare class ToastBottomLeftPosition extends ToastBottomCenterPosition {
    /** @hidden */
    static global: {
        left: string;
        center: boolean;
        right?: string;
        bottom?: string;
        top?: string;
        centerVertically?: boolean;
    };
    /** @hidden */
    static connected: ConnectedPosition;
}
/**
 * Toast Position class.
 * The first item will pop from the bottom-right of the screen.
 * New items will stack before first item.
 */
export declare class ToastBottomRightPosition extends ToastBottomCenterPosition {
    /** @hidden */
    static global: {
        right: string;
        center: boolean;
        left?: string;
        bottom?: string;
        top?: string;
        centerVertically?: boolean;
    };
    /** @hidden */
    static connected: ConnectedPosition;
}
