import { OverlayRef } from '@angular/cdk/overlay';
import { BasePortalOutlet, CdkPortalOutlet, ComponentPortal, TemplatePortal } from '@angular/cdk/portal';
import { ComponentRef, EmbeddedViewRef } from '@angular/core';
import { Subject } from 'rxjs';
import { Nullable } from '../../models/nullable';
import { ToastContainerComponent } from '../interfaces/toast-container-component.interface';
import { BaseToastConfig } from './base-toast-config';
import * as i0 from "@angular/core";
export declare abstract class BaseToastContainerComponent<P extends BaseToastConfig = BaseToastConfig> extends BasePortalOutlet implements ToastContainerComponent<P> {
    config: P;
    /** Method, which is triggered when the Toast component is ready to be shown. Used to trigger animations. */
    abstract enter(): void;
    /** Method, which is triggered when the Toast component is ready to be removed. Used to trigger animations. */
    abstract exit(): void;
    /**
     * @hidden
     * The portal outlet inside this container into which the Toast content will be loaded.
     */
    _portalOutlet: CdkPortalOutlet;
    /** Min width of the toast component. */
    minWidth?: string | number | null;
    /** Max width of the toast component. */
    maxWidth?: string | number | null;
    /** Width of the toast component. */
    width?: string | number | null;
    /** Min height of the toast component. */
    minHeight?: string | number | null;
    /** Max height of the toast component. */
    maxHeight?: string | number | null;
    /** Height of the toast component. */
    height?: string | number | null;
    /** Subject for notifying that the Toast has finished exiting from view. */
    readonly onExit$: Subject<void>;
    /** Subject for notifying that the Toast has finished entering the view. */
    readonly onEnter$: Subject<void>;
    /** Overlay reference */
    overlayRef: OverlayRef;
    /** Aria label. */
    ariaLabel: Nullable<string>;
    /** ID of the Toast. */
    id: Nullable<string>;
    /** @hidden */
    protected constructor(config: P);
    /**
     * Attaches component to the portal.
     */
    attachComponentPortal<C>(portal: ComponentPortal<C>): ComponentRef<C>;
    /**
     * Attaches Template to the portal.
     * @param portal
     */
    attachTemplatePortal<T>(portal: TemplatePortal<T>): EmbeddedViewRef<T>;
    static ɵfac: i0.ɵɵFactoryDeclaration<BaseToastContainerComponent<any>, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<BaseToastContainerComponent<any>, never, never, {}, {}, never, never, true, never>;
}
