import { OverlayRef } from '@angular/cdk/overlay';
import { Observable, Subject } from 'rxjs';
import { BaseToastPosition } from '../base-toast-positions';
import { ToastContainerComponent } from '../interfaces/toast-container-component.interface';
export declare abstract class BaseToastRef<T = any, P = any, C extends ToastContainerComponent<P> = ToastContainerComponent<P>> {
    containerInstance: C;
    overlayRef: OverlayRef;
    positionStrategy: BaseToastPosition;
    /** The instance of the component is making up the content of the Toast. */
    instance: T;
    /** @hidden */
    _defaultPositionStrategy: boolean;
    /** @hidden
     * Used for flagging the toast as an anchor for all next appearing toasts.
     */
    _isAnchor: boolean;
    /**
     * @hidden
     * Subject for notifying the user that the Toast has been dismissed.
     */
    protected readonly _afterDismissed$: Subject<void>;
    /** @hidden */
    protected constructor(containerInstance: C, overlayRef: OverlayRef, positionStrategy: BaseToastPosition);
    /** Dismisses the Toast. */
    dismiss(): void;
    /** Gets an observable that is notified when the Toast is finished closing. */
    afterDismissed(): Observable<void>;
    /** Gets an observable that is notified when the Toast has opened and appeared. */
    afterOpened(): Observable<void>;
    /**
     * @hidden
     * Cleans up the DOM after closing.
     */
    protected _finishDismiss(): void;
}
