import * as i0 from '@angular/core';
import { INJECTOR, ElementRef, isDevMode, InjectionToken, EventEmitter, inject, NgZone, Input, Output, Directive, NgModule, DestroyRef, Injectable, Optional, Inject, booleanAttribute, Renderer2, PLATFORM_ID, Self, SkipSelf, ContentChildren, forwardRef, HostListener, HostBinding, Injector, computed, ContentChild, QueryList, ViewContainerRef, TemplateRef, ViewChild, Component, NgModuleFactory, Pipe, signal } from '@angular/core';
import { RIGHT_ARROW, DOWN_ARROW, LEFT_ARROW, UP_ARROW, SPACE, ESCAPE, DELETE, ENTER, MAC_ENTER, TAB, HOME, END, ALT, CONTROL, META, SHIFT, BACKSPACE, A, C, V, X, PAGE_UP, PAGE_DOWN, DASH, NUMPAD_MINUS, NUMPAD_ZERO, NUMPAD_ONE, NUMPAD_TWO, NUMPAD_THREE, NUMPAD_FOUR, NUMPAD_FIVE, NUMPAD_SIX, NUMPAD_SEVEN, NUMPAD_EIGHT, NUMPAD_NINE, F2, F7, hasModifierKey } from '@angular/cdk/keycodes';
import { takeUntilDestroyed, toSignal } from '@angular/core/rxjs-interop';
import { Observable, NEVER, fromEvent, switchMap, map as map$1, Subject, BehaviorSubject, ReplaySubject, merge, combineLatest, filter as filter$1, firstValueFrom, debounceTime, distinctUntilChanged as distinctUntilChanged$1, startWith as startWith$1, Subscription, of, isObservable, tap as tap$1, take as take$1 } from 'rxjs';
import { map, first, distinctUntilChanged, startWith, takeUntil, filter, tap, switchMap as switchMap$1, finalize, take, debounceTime as debounceTime$1, pairwise, shareReplay, delay } from 'rxjs/operators';
import { coerceElement, coerceBooleanProperty, coerceNumberProperty, coerceArray, coerceCssPixelValue } from '@angular/cdk/coercion';
import { get, findLastIndex, escape } from 'lodash-es';
import { createFocusTrap } from 'focus-trap';
import * as i1$1 from '@angular/cdk/a11y';
import { FocusKeyManager, LiveAnnouncer } from '@angular/cdk/a11y';
import * as i1 from '@angular/cdk/observers';
import { DOCUMENT, AsyncPipe } from '@angular/common';
import * as i1$5 from '@angular/cdk/overlay';
import { ViewportRuler, OverlayConfig, OverlayContainer } from '@angular/cdk/overlay';
import * as i1$4 from '@angular/platform-browser';
import { EVENT_MANAGER_PLUGINS } from '@angular/platform-browser';
import deepEqual from 'fast-deep-equal';
import * as i1$2 from '@angular/cdk/drag-drop';
import { DragDrop, moveItemInArray, transferArrayItem, DragDropModule } from '@angular/cdk/drag-drop';
import * as i1$3 from '@angular/cdk/portal';
import { DomPortal, TemplatePortal, ComponentPortal, PortalModule, CdkPortalOutlet, BasePortalOutlet } from '@angular/cdk/portal';
import { trigger, state, transition, style, animate } from '@angular/animations';
import { __decorate, __metadata } from 'tslib';

/**
 * Creates provider for ConsumerClass
 */
function consumerProviderFactory(ConsumerClass, providedConfiguration) {
    return {
        provide: ConsumerClass,
        useFactory: (injector) => new ConsumerClass(injector, providedConfiguration),
        deps: [INJECTOR]
    };
}

const pxToNum = (pixels) => Number(pixels.replace('px', '')) || 0;
const toNativeElement = (element) => element instanceof ElementRef ? element.nativeElement : element;
/** Return elements capacity (width subtract by element padding)
 * @param element - HTMLelement or element reference
 * */
function getElementCapacity(element) {
    const _element = toNativeElement(element);
    const computedStyle = window.getComputedStyle(_element);
    return pxToNum(computedStyle.width) - pxToNum(computedStyle.paddingLeft) - pxToNum(computedStyle.paddingRight);
}
/** Return elements width
 * @param element - HTMLelement or element reference
 * @param withMargin - weather to add element margins to width
 * */
function getElementWidth(element, withMargin) {
    const _element = toNativeElement(element);
    const computedStyle = getComputedStyle(_element);
    return withMargin
        ? pxToNum(computedStyle.width) + pxToNum(computedStyle.marginLeft) + pxToNum(computedStyle.marginRight)
        : pxToNum(computedStyle.width);
}

/** Get document font size in pixels. */
function getDocumentFontSize() {
    const DEFAULT_SIZE = 16;
    const clientFontSize = document?.documentElement
        ? parseFloat(getComputedStyle(document.documentElement).fontSize)
        : DEFAULT_SIZE;
    return isNaN(clientFontSize) ? DEFAULT_SIZE : clientFontSize;
}

/**
 * RxJS wrapper for IntersectionObserver class.
 * @param target HTML element to spy on.
 * @param options @see {IntersectionObserverInit}
 * @returns {Observable} with observer entries.
 */
function intersectionObservable(target, options) {
    if ('IntersectionObserver' in window) {
        return new Observable((subscriber) => {
            const io = new IntersectionObserver((entries) => {
                subscriber.next(entries);
            }, options);
            io.observe(target);
            return function unsubscribe() {
                io.disconnect();
            };
        });
    }
    else {
        // If browser doesn't support IntersectionObserver API never emit a value
        // since we're not supporting IE11 and any other browser should have it.
        return NEVER;
    }
}

/** Determines whether provided value is valid content density */
function isValidContentDensity(size) {
    return size === 'cozy' || size === 'compact' || size === 'condensed';
}
/**
 * Determines if "compact" styles should be applied based on provided content density
 */
function isCompactDensity(size) {
    return isValidContentDensity(size) && size !== 'cozy';
}

/**
 * Function checks whether the passed number is odd.
 * @param number number to check.
 * @returns Boolean whether the number is odd.
 */
function isOdd(number) {
    return number % 2 === 1;
}

/** Map of keyCodes and their corresponding "key" values */
const keyMap = new Map([
    [RIGHT_ARROW, ['ArrowRight', 'Right']],
    [DOWN_ARROW, ['ArrowDown', 'Down']],
    [LEFT_ARROW, ['ArrowLeft', 'Left']],
    [UP_ARROW, ['ArrowUp', 'Up']],
    [SPACE, ['Space', 'Spacebar', ' ']],
    [ESCAPE, ['Escape', 'Esc']],
    [DELETE, ['Delete', 'Del']],
    [ENTER, ['Enter']],
    [MAC_ENTER, ['Enter']],
    [TAB, ['Tab']],
    [HOME, ['Home']],
    [END, ['End']],
    [ALT, ['Alt']],
    [CONTROL, ['Ctrl', 'Control', 'Meta']],
    [META, ['Meta']],
    [SHIFT, ['Shift']],
    [BACKSPACE, ['Backspace']],
    [A, ['KeyA']],
    [C, ['KeyC']],
    [V, ['KeyV']],
    [X, ['KeyX']],
    [PAGE_UP, ['PageUp']],
    [PAGE_DOWN, ['PageDown']],
    [DASH, ['-']],
    [NUMPAD_MINUS, ['-']],
    [NUMPAD_ZERO, ['NumPad0']],
    [NUMPAD_ONE, ['NumPad1']],
    [NUMPAD_TWO, ['NumPad2']],
    [NUMPAD_THREE, ['NumPad3']],
    [NUMPAD_FOUR, ['NumPad4']],
    [NUMPAD_FIVE, ['NumPad5']],
    [NUMPAD_SIX, ['NumPad6']],
    [NUMPAD_SEVEN, ['NumPad7']],
    [NUMPAD_EIGHT, ['NumPad8']],
    [NUMPAD_NINE, ['NumPad9']],
    [F2, ['F2']],
    [F7, ['F7']]
]);
class KeyUtil {
    /**
     * Function used to unify key identification across different browsers using KeyCodes
     *
     * @param event     - KeyboardEvent
     * @param keyCode   - event.key name matching W3C specification / (ASSCI char. codes)
     * */
    static isKeyCode(event, keyCode) {
        if (Array.isArray(keyCode)) {
            return keyCode.some((key) => this.isKeyCode(event, key));
        }
        if (event && keyMap.get(keyCode)) {
            return keyMap.get(keyCode)?.some((alias) => alias === event.key) || keyCode === event.keyCode;
        }
        if (isDevMode()) {
            throw new Error(`Invalid function arguments. Check if "event" is a KeyboardEvent or "key" is defined in keyMap`);
        }
        return false;
    }
    /**
     * Function used to unify key identification across different browsers
     *
     * @param event     - KeyboardEvent
     * @param keyType   - Type of key
     * */
    static isKeyType(event, keyType) {
        if (event && keyType) {
            switch (keyType) {
                case 'numeric':
                    return event.code
                        ? event.code.toLowerCase().includes('digit')
                        : (event.keyCode >= 48 && event.keyCode <= 57) || (event.keyCode >= 96 && event.keyCode <= 105);
                case 'alphabetical':
                    return event.code
                        ? event.code.toLowerCase().includes('key')
                        : event.keyCode >= 65 && event.keyCode <= 90;
                // some service commands as alt, ctr, insert, print, f4 etc. All except letters, numbers and symbols
                case 'control':
                    return event.keyCode < 48 || (event.keyCode >= 112 && event.keyCode <= 123);
                case 'ime':
                    return event.key?.toLowerCase() === 'process' || event.keyCode === 229;
            }
        }
        if (isDevMode()) {
            throw new Error(`Invalid function arguments.`);
        }
        return false;
    }
}

const ModuleDeprecations = new InjectionToken('ModuleDeprecations');

/** Module deprecations provider */
function moduleDeprecationsProvider(classRef) {
    return {
        provide: ModuleDeprecations,
        useClass: classRef,
        multi: true
    };
}
/** Module deprecations provider factory */
function moduleDeprecationsFactory(factory) {
    return {
        provide: ModuleDeprecations,
        ...factory,
        multi: true
    };
}

const fileSizeMap = new Map([
    ['KB', 1024],
    ['MB', 1048576],
    ['GB', 1073741824],
    ['TB', 1099511627776]
]);
/** Parse file size to bytes */
function parserFileSize(fileSize) {
    if (fileSize === '') {
        return 0;
    }
    const sizes = fileSize.match(/[\d.]+|\D+/g);
    if (sizes && sizes.length > 1) {
        const size = Number(sizes[0].replace(/ +/g, ''));
        const unit = sizes[1].replace(/ +/g, '').toUpperCase();
        const unitSize = fileSizeMap.get(unit);
        if (isNaN(size)) {
            throw new Error('FileSizeError - Invalid File size please check.');
        }
        if (unit === 'B' || unit === 'BYTE' || unit === 'BYTES') {
            return size;
        }
        if (!unitSize) {
            throw new Error('FileSizeError - Invalid File size please check.');
        }
        else {
            return unitSize * size;
        }
    }
    else {
        if (isNaN(Number(sizes))) {
            throw new Error('FileSizeError - Invalid File size please check.');
        }
        return Number(sizes);
    }
}

/** Get random number from 1 to 10. */
function getRandomColorAccent() {
    return (Math.floor(Math.random() * 10) + 1);
}

/**
 * RxJS wrapper for ResizeObserver class.
 * @param target HTML element to spy on.
 * @param options @see {ResizeObserverOptions}
 * @returns {Observable} with observer entries.
 */
function resizeObservable(target, options) {
    if ('ResizeObserver' in window) {
        return new Observable((subscriber) => {
            let animationFrame;
            const ro = new ResizeObserver((entries) => {
                animationFrame = window.requestAnimationFrame(() => {
                    subscriber.next(entries);
                });
            });
            ro.observe(target, options);
            return function unsubscribe() {
                if (animationFrame) {
                    window.cancelAnimationFrame(animationFrame);
                }
                ro.unobserve(target);
                ro.disconnect();
            };
        });
    }
    else {
        // If current browser does not support resizeObserver, rely on window resize and return empty array of items.
        return fromEvent(window, 'resize').pipe(map(() => []));
    }
}

/**
 * Function used to scroll specified element by some distance
 *
 * @param containerElement     - Container element scrolled
 * @param distanceToScroll     - Distance of scroll in px
 * */
function scrollTop(containerElement, distanceToScroll) {
    // Check if scrollTo method is supported by current browser
    if (containerElement.scrollTo && containerElement.scrollTo instanceof Function) {
        containerElement.scrollTo({
            top: distanceToScroll,
            behavior: 'smooth'
        });
    }
    else {
        containerElement.scrollTop = distanceToScroll;
    }
}

/** Generate a UUID v4 */
function uuidv4() {
    const modifier = 16;
    return 'xxxxxxxx-xxxx-4xxx-yxxx-xxxxxxxxxxxx'.replace(/[xy]/g, (c) => {
        // eslint-disable-next-line no-bitwise
        const r = (Math.random() * modifier) | 0, 
        // eslint-disable-next-line no-bitwise
        v = c === 'x' ? r : (r & 0x3) | 0x8;
        return v.toString(modifier);
    });
}

class AutoCompleteDirective {
    /** @hidden */
    // eslint-disable-next-line @typescript-eslint/member-ordering
    constructor() {
        /** Whether the auto complete directive should be enabled */
        this.enable = true;
        /** Display function. Accepts an object of the same type as the
         * items passed to dropdownValues as argument, and outputs a string.
         * An arrow function can be used to access the *this* keyword in the calling component.
         * See search input examples for details. */
        this.displayFn = this._defaultDisplay;
        /** Event thrown, when the auto ahead text is accepted */
        this.onComplete = new EventEmitter();
        /** @hidden */
        this._completeKeys = [ENTER];
        /** @hidden */
        this._fillKeys = [LEFT_ARROW, RIGHT_ARROW];
        /** @hidden */
        this._stopKeys = [BACKSPACE, DELETE, ESCAPE];
        /** @hidden */
        this._isComposing = false;
        /** @hidden */
        this._elementRef = inject(ElementRef);
        this._zone = inject(NgZone);
        /** Matcher function for testing the str for a search term */
        this.matcher = (str, searchTerm) => str.startsWith(searchTerm);
        /**
         * Fixes #10710
         * With chinese characters inputText property update was triggered after the keyup event trigger.
         * By ensuring that we set all properties we can proceed with stable data.
         */
        this._zone.runOutsideAngular(() => {
            const keyupEvent = fromEvent(this._elementRef.nativeElement, 'keyup');
            const compositionStartEvent = fromEvent(this._elementRef.nativeElement, 'compositionstart');
            const compositionEndEvent = fromEvent(this._elementRef.nativeElement, 'compositionend');
            keyupEvent
                .pipe(switchMap((evt) => this._zone.onStable.pipe(first(), map$1(() => evt))), takeUntilDestroyed())
                .subscribe((evt) => this._handleKeyboardEvent(evt));
            compositionStartEvent.pipe(takeUntilDestroyed()).subscribe(() => {
                this._isComposing = true;
            });
            compositionEndEvent.pipe(takeUntilDestroyed()).subscribe(() => {
                this._isComposing = false;
                this.inputText = this._elementRef.nativeElement.value;
            });
        });
    }
    /** @hidden */
    _handleKeyboardEvent(event) {
        if (this.enable && !this._isComposing) {
            if (KeyUtil.isKeyCode(event, this._stopKeys)) {
                this._elementRef.nativeElement.value = this.inputText;
            }
            else if (KeyUtil.isKeyCode(event, this._completeKeys)) {
                this._sendCompleteEvent(true);
                this._moveIndicatorToLastCharacter();
            }
            else if (KeyUtil.isKeyCode(event, this._fillKeys)) {
                this._sendCompleteEvent(false);
            }
            else if (!this._isControlKey(event) && this.inputText) {
                if (!this._triggerTypeAhead()) {
                    return;
                }
                this.oldValue = this.inputText;
                const item = this.options.find((option) => this.matcher(this.displayFn(option).toLocaleLowerCase(), this.inputText.toLocaleLowerCase()));
                if (item) {
                    this._typeahead(this.displayFn(item));
                }
            }
        }
        this.lastKeyUpEvent = event;
    }
    /** @hidden */
    _typeahead(displayedValue) {
        this._elementRef.nativeElement.value = displayedValue;
        const selectionStartIndex = this.inputText.length;
        this._elementRef.nativeElement.setSelectionRange(selectionStartIndex, displayedValue.length);
    }
    /** @hidden */
    _isControlKey(event) {
        return KeyUtil.isKeyCode(event, CONTROL) || event.ctrlKey;
    }
    /** @hidden */
    _defaultDisplay(value) {
        return value;
    }
    /** @hidden */
    _triggerTypeAhead() {
        return !(this.lastKeyUpEvent &&
            KeyUtil.isKeyCode(this.lastKeyUpEvent, CONTROL) &&
            this.inputText === this.oldValue);
    }
    /** @hidden */
    _sendCompleteEvent(forceClose) {
        this.onComplete.emit({
            term: this._elementRef.nativeElement.value,
            forceClose
        });
    }
    /** @hidden */
    _moveIndicatorToLastCharacter() {
        const inputTextLength = this.inputText?.length ?? 0;
        this._elementRef.nativeElement.setSelectionRange(inputTextLength, inputTextLength);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: AutoCompleteDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "19.2.3", type: AutoCompleteDirective, isStandalone: true, selector: "[fdkAutoComplete]", inputs: { options: "options", inputText: "inputText", enable: "enable", displayFn: "displayFn", matcher: "matcher" }, outputs: { onComplete: "onComplete" }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: AutoCompleteDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[fdkAutoComplete]',
                    standalone: true
                }]
        }], ctorParameters: () => [], propDecorators: { options: [{
                type: Input
            }], inputText: [{
                type: Input
            }], enable: [{
                type: Input
            }], displayFn: [{
                type: Input
            }], onComplete: [{
                type: Output
            }], matcher: [{
                type: Input
            }] } });

class AutoCompleteModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: AutoCompleteModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "19.2.3", ngImport: i0, type: AutoCompleteModule, imports: [AutoCompleteDirective], exports: [AutoCompleteDirective] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: AutoCompleteModule }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: AutoCompleteModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [AutoCompleteDirective],
                    exports: [AutoCompleteDirective],
                    declarations: []
                }]
        }] });

/**
 * Creates an observable that emits when the component is destroyed.
 * @param destroyRef
 */
const destroyObservable = (destroyRef = inject(DestroyRef)) => {
    const destroy$ = new Subject();
    destroyRef.onDestroy(() => destroy$.next());
    return destroy$.asObservable();
};

/** @hidden */
const _defaultDfsOptions = {
    children: 'children',
    shouldVisit: () => true,
    postOrder: true
};
/** @hidden */
function postOrderDfs() {
    const iterator = (item, callback, options) => {
        if (options.shouldVisit(item)) {
            const children = typeof options.children === 'string' ? get(item, options.children) : options.children(item);
            children.forEach((child) => iterator(child, callback, options));
            callback(item);
        }
    };
    return iterator;
}
/** @hidden */
function preOrderDfs() {
    const iterator = (item, callback, options) => {
        if (options.shouldVisit(item)) {
            const children = typeof options.children === 'string' ? get(item, options.children) : options.children(item);
            callback(item);
            children.forEach((child) => iterator(child, callback, options));
        }
    };
    return iterator;
}
/**
 * Depth-first search algorithm, which traverses a tree/graph/tree-like structure.
 * callback is called for each item in the collection. The order of the callback calls
 * depends on the options. By default, the algorithm is post-order, which means that
 * the callback is called for each item after its children have been visited.
 *
 * @param collection
 * @param callback
 * @param options
 */
function dfs(collection, callback, options = {}) {
    const mergedOptions = { ..._defaultDfsOptions, ...options };
    const iterator = mergedOptions.postOrder ? postOrderDfs() : preOrderDfs();
    for (const item of collection) {
        iterator(item, callback, mergedOptions);
    }
}

/**
 * Retrieves native element from ElementRef.
 */
function getNativeElement(element) {
    let coercible = element;
    if (hasElementRef(element)) {
        coercible = element.elementRef;
    }
    return coerceElement(coercible);
}
/**
 * Checks whether object has element reference in it.
 */
function hasElementRef(something) {
    return something && something['elementRef'] instanceof ElementRef;
}

/**
 * Helper function check whether passed data is a JS object (including function).
 */
// eslint-disable-next-line @typescript-eslint/no-unsafe-function-type
function isJsObject(obj) {
    return obj !== null && (typeof obj === 'function' || typeof obj === 'object');
}
/**
 * Helper function checks whether passed value is not empty.
 */
function isPresent(obj) {
    return obj !== undefined && obj !== null;
}
/**
 * Helper function check whether passed value is empty.
 */
function isBlank(obj) {
    return obj === undefined || obj === null;
}
/**
 * Helper function checks whether passed value is a boolean.
 */
function isBoolean(obj) {
    return typeof obj === 'boolean';
}
/**
 * Helper function checks whether passed value is a valid number.
 */
function isNumber(obj) {
    return typeof obj === 'number';
}
/**
 * Helper function checks whether passed value is a string.
 */
function isString(obj) {
    return typeof obj === 'string';
}
/**
 * Helper function checks whether passed value is a function
 */
function isFunction(obj) {
    return typeof obj === 'function';
}
/** @hidden */
// eslint-disable-next-line @typescript-eslint/no-unsafe-function-type
function isType(obj) {
    return isFunction(obj);
}
/**
 * Helper function checks whether passed value is a record of `T` values.
 */
function isStringMap(obj) {
    return typeof obj === 'object' && obj !== null;
}
/**
 * Helper function checks whether passed value is an `object`.
 */
function isObject(item) {
    return typeof item === 'object' && !Array.isArray(item) && item !== null;
}
/**
 * Helper function checks whether passed value is a promise.
 */
function isPromise(obj) {
    // allow any Promise/A+ compliant thenable.
    // It's up to the caller to ensure that obj.then conforms to the spec
    return !!obj && isFunction(obj.then);
}
/**
 * Helper function checks whether passed value is an Observable/Subscribable.
 */
function isSubscribable(obj) {
    return !!obj && isFunction(obj.subscribe);
}

/**
 * Utility type, that allows to track and select ranges of elements while using multi-selection.
 *
 * @usage
 * Imagine we have a simple list of checkboxes:
 * ```html
 * <input
 *  #checkboxInput
 *  *ngFor="let o of options; let idx = index"
 *  type="checkbox"
 *  [checked]="selectionModel.checked(o)"
 *  (click)="toggle(idx, $event)"
 *  >
 * ```
 * With the given layout the logic should be as follows:
 * ```typescript
 * export class YourComponent {
 *  options = ['a', 'b', 'c'];
 *  readonly selectionModel = new SelectionModel(true);
 *
 *  private readonly _rangeSelector = new RangeSelector();
 *
 *
 *  toggle(idx: number, event: PointerEvent): void {
 *      // getting the toggled value of the checkbox
 *      const toggledSelection = event.target.value;
 *
 *      // registering the selection of current checkbox
 *      this._rangeSelector.onRangeElementToggled(idx, event);
 *
 *      // Apply value to each element in range.
 *      // If checkbox was toggled without shift pressed or without previously selected one,
 *      // this method will select only it.
 *      this._rangeSelector.applyValueToEachInRange(idx => {
 *          if (toggledSelection) {
 *              this.selectionModel.select(options[idx]);
 *          } else {
 *              this.selectionModel.deselect(options[idx]);
 *          }
 *      });
 *  }
 * }
 * ```
 */
class RangeSelector {
    constructor() {
        /** @hidden */
        this._previousSelectedIndex = null;
    }
    /**
     * Last registered selection state (either multiple or single).
     * Is updated on each `onRangeElementClicked` invokation. Will be `null` initially or once `reset()` is called.
     */
    get lastRangeSelectionState() {
        return this._state ? { ...this._state } : null;
    }
    /**
     * The method that should be used to register each checkbox toggle.
     * Accepts two arguments: `index` and `event`. If none provided, will reset existing state.
     * Otherwise will register current index as last checked.
     *
     * If toggling was done with "shift" pressed and there's a previously registered index, will register a range selection.
     * At the same time if checkbox was toggled without shift pressed or without previously selected one, this method will select only it.
     *
     * After calling this method it's recommended to use `applyValueToEachInRange` to actually toggle each checkbox in range.
     *
     * See usage example on this class itself.
     */
    onRangeElementToggled(index, event) {
        if (this._isNonNegativeInteger(this._previousSelectedIndex) &&
            this._isNonNegativeInteger(index) &&
            event?.shiftKey) {
            this._state = {
                isRangeSelection: true,
                from: Math.min(this._previousSelectedIndex, index),
                to: Math.max(this._previousSelectedIndex, index)
            };
            this._previousSelectedIndex = index;
        }
        else if (this._isNonNegativeInteger(index)) {
            this._state = { isRangeSelection: false, from: index, to: index };
            this._previousSelectedIndex = index;
        }
        else {
            this.reset();
        }
        return this.lastRangeSelectionState;
    }
    /**
     * Allows to apply selection to each item in selection range.
     * Accepts a function to apply selection to each item by registered index.
     *
     * See usage example on this class itself.
     */
    applyValueToEachInRange(selectionMethod) {
        const state = this.lastRangeSelectionState;
        if (!state) {
            return;
        }
        if (this._isNonNegativeInteger(state?.from) && this._isNonNegativeInteger(state?.to)) {
            for (let index = state.from; index <= state.to; index++) {
                selectionMethod(index);
            }
        }
    }
    /** Resets selection state. Useful when the list of selectable items is changed (e.g. by filtering, sorting, page change) */
    reset() {
        this._state = null;
        this._previousSelectedIndex = null;
    }
    /** @hidden */
    _isNonNegativeInteger(num) {
        return isNumber(num) && num >= 0;
    }
}

const messages = new Set();
/** @hidden */
function warnOnce(message) {
    if (!messages.has(message)) {
        console.warn(message);
        messages.add(message);
    }
}

const DEFAULT_CONTENT_DENSITY = 'cozy';
/**
 * Service taking care of ContentDensity
 */
class ContentDensityService {
    /** @hidden */
    constructor() {
        /** Content Density BehaviourSubject */
        this.contentDensity = new BehaviorSubject(DEFAULT_CONTENT_DENSITY);
        if (isDevMode()) {
            warnOnce(`[Deprecated] ContentDensityService is deprecated and will be removed in the next major version.
                 Please use ContentDensityControllerService instead, or use the ContentDensityModule forRoot method.`);
        }
    }
    /** @hidden */
    get _contentDensityListener() {
        return this.contentDensity.pipe(distinctUntilChanged(), startWith(this.contentDensity.getValue()));
    }
    /** @hidden */
    get _isCompactDensity() {
        return this._contentDensityListener.pipe(map((density) => isCompactDensity(density)));
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: ContentDensityService, deps: [], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: ContentDensityService }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: ContentDensityService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [] });

/**
 * @deprecated Use Angular's built-in `DestroyRef` and `takeUntilDestroyed` instead.
 * Will be removed in next release
 */
class DestroyedService extends ReplaySubject {
    /** @hidden */
    constructor() {
        super(1);
        warnOnce(`DestroyedService is deprecated. Use Angular's built-in 'DestroyRef' and 'takeUntilDestroyed' instead.`);
    }
    /** @hidden */
    ngOnDestroy() {
        this.next();
        this.complete();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: DestroyedService, deps: [], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: DestroyedService }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: DestroyedService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [] });

class FocusTrapService {
    constructor() {
        /** @hidden */
        this._focusTrapInstances = new Map();
    }
    /**
     * Creates focus trap instance for defined element
     * @param element Container for which to create focus trap
     * @param userOptions Focus-trap specific configuration
     * @returns {string} Unique ID of focus trap instance
     */
    createFocusTrap(element, userOptions) {
        const uid = uuidv4();
        const trap = createFocusTrap(element, userOptions);
        this._focusTrapInstances.set(uid, trap);
        this.activateFocusTrap(uid);
        return uid;
    }
    /**
     * Activates focus trap for defined ID
     * @param id Unique ID of focus trap instance
     */
    activateFocusTrap(id) {
        if (!this._focusTrapExists(id)) {
            return;
        }
        const trap = this.getFocusTrapInstance(id);
        trap?.activate();
    }
    /**
     * Deactivates focus trap for defined ID
     * @param id Unique ID of focus trap instance
     */
    deactivateFocusTrap(id) {
        if (!this._focusTrapExists(id)) {
            return;
        }
        const trap = this.getFocusTrapInstance(id);
        trap?.deactivate();
        this._focusTrapInstances.delete(id);
    }
    /**
     * Pauses current focus trap.
     */
    pauseCurrentFocusTrap() {
        if (this._focusTrapInstances.size === 0) {
            return;
        }
        const trapItem = this._getLastTrapedItem();
        trapItem?.pause();
    }
    /**
     * Unpauses current focus trap.
     */
    unpauseCurrentFocusTrap() {
        if (this._focusTrapInstances.size === 0) {
            return;
        }
        const trapItem = this._getLastTrapedItem();
        trapItem?.unpause();
    }
    /**
     * Get focus trap instance by ID.
     * @param id ID of the instance.
     * @returns Focus trap instance if exists.
     */
    getFocusTrapInstance(id) {
        return this._focusTrapInstances.get(id);
    }
    /** @hidden */
    _getLastTrapedItem() {
        const lastItem = Array.from(this._focusTrapInstances).pop();
        return lastItem ? lastItem[1] : undefined;
    }
    /** @hidden */
    _focusTrapExists(id) {
        return this._focusTrapInstances.has(id);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: FocusTrapService, deps: [], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: FocusTrapService, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: FocusTrapService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }] });

class KeyboardSupportService {
    constructor() {
        /** Subject that is thrown, when focus escapes the list */
        this.focusEscapeList = new Subject();
        /** @hidden  */
        this._destroyRef = inject(DestroyRef);
        /** An RxJS Subject that will kill the data stream upon queryList changes (for unsubscribing)  */
        this._onRefresh$ = new Subject();
        /** @hidden
         * allow tab key navigation. default is true.
         */
        this._tabKeyNavigation = true;
    }
    /** @hidden */
    get keyManager() {
        return this._keyManager;
    }
    /** @hidden */
    setKeyboardService(queryList, wrap, tabKeyNavigation = true) {
        this._keyManager?.destroy();
        this._tabKeyNavigation = tabKeyNavigation;
        this._keyManager = new FocusKeyManager(queryList).withWrap(wrap).withHomeAndEnd();
        queryList.changes
            .pipe(startWith(0), takeUntilDestroyed(this._destroyRef))
            .subscribe(() => this._refreshEscapeLogic(queryList));
    }
    /** @hidden */
    onKeyDown(event) {
        this._keyManager.onKeydown(event);
        if (KeyUtil.isKeyCode(event, TAB)) {
            if (KeyUtil.isKeyCode(event, TAB) && this._tabKeyNavigation) {
                event.preventDefault();
                hasModifierKey(event, 'shiftKey')
                    ? this.keyManager.setPreviousItemActive()
                    : this.keyManager.setNextItemActive();
            }
        }
    }
    /** Destroys KeyboardSupportService dependencies */
    ngOnDestroy() {
        this._keyManager?.destroy();
    }
    /** @hidden */
    _refreshEscapeLogic(queryList) {
        const createEscapeListener = (listItem, onKeyCode, escapeDirection) => {
            listItem.keyDown
                .pipe(takeUntil(unsubscribe$), filter((event) => KeyUtil.isKeyCode(event, onKeyCode)), tap((event) => event.preventDefault()))
                .subscribe(() => this.focusEscapeList.next(escapeDirection));
        };
        /** Finish all of the streams, form before */
        this._onRefresh$.next();
        const unsubscribe$ = merge(this._onRefresh$, destroyObservable(this._destroyRef));
        if (queryList.length) {
            createEscapeListener(queryList.last, DOWN_ARROW, 'down');
            createEscapeListener(queryList.first, UP_ARROW, 'up');
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: KeyboardSupportService, deps: [], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: KeyboardSupportService }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: KeyboardSupportService, decorators: [{
            type: Injectable
        }] });

class MockStorage {
    // eslint-disable-next-line
    key(index) { }
    clear() { }
    // eslint-disable-next-line
    getItem(key) { }
    // eslint-disable-next-line
    removeItem(key) { }
    // eslint-disable-next-line
    setItem(key, value) { }
}
class LocalStorageService {
    /** @hidden */
    constructor() {
        typeof localStorage !== 'undefined' ? (this._storage = localStorage) : (this._storage = new MockStorage());
    }
    /** Get item from local storage. */
    get(key) {
        const value = this._storage.getItem(key);
        if (value) {
            return JSON.parse(value);
        }
        return null;
    }
    /** Set item in local storage. */
    set(key, value) {
        this._storage.setItem(key, JSON.stringify(value));
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: LocalStorageService, deps: [], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: LocalStorageService, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: LocalStorageService, decorators: [{
            type: Injectable,
            args: [{ providedIn: 'root' }]
        }], ctorParameters: () => [] });

/* eslint-disable @typescript-eslint/no-non-null-assertion */
class AttributeObserver {
    /** @hidden */
    constructor(_mutationObserverFactory) {
        this._mutationObserverFactory = _mutationObserverFactory;
        /** @Hidden */
        this._observedElements = new Map();
    }
    /** @hidden */
    ngOnDestroy() {
        this._observedElements.forEach((_, element) => this._cleanupObserver(element));
    }
    /** @Hidden */
    observe(elementOrRef) {
        const element = getNativeElement(elementOrRef);
        return new Observable((observer) => {
            const stream = this._observeElement(element);
            const subscription = stream.subscribe(observer);
            return () => {
                subscription.unsubscribe();
                this._unobserveElement(element);
            };
        });
    }
    /** @Hidden */
    unobserve(element) {
        this._unobserveElement(getNativeElement(element));
    }
    /** @hidden */
    _observeElement(element) {
        if (!this._observedElements.has(element)) {
            const stream = new Subject();
            const observer = this._mutationObserverFactory.create((mutations) => stream.next(mutations));
            if (observer) {
                observer.observe(element, {
                    attributes: true
                });
            }
            this._observedElements.set(element, { observer, stream, count: 1 });
        }
        else {
            this._observedElements.get(element).count++;
        }
        return this._observedElements.get(element).stream;
    }
    /** @Hidden */
    _unobserveElement(element) {
        if (this._observedElements.has(element)) {
            this._observedElements.get(element).count--;
            if (!this._observedElements.get(element).count) {
                this._cleanupObserver(element);
            }
        }
    }
    /** @hidden */
    _cleanupObserver(element) {
        if (this._observedElements.has(element)) {
            const { observer, stream } = this._observedElements.get(element);
            if (observer) {
                observer.disconnect();
            }
            stream.complete();
            this._observedElements.delete(element);
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: AttributeObserver, deps: [{ token: i1.MutationObserverFactory }], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: AttributeObserver, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: AttributeObserver, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: () => [{ type: i1.MutationObserverFactory }] });

class ResizeObserverFactory {
    /** Factory to create ResizeObserver if it's present in browser.  */
    create(callback) {
        return typeof ResizeObserver === 'undefined' ? null : new ResizeObserver(callback);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: ResizeObserverFactory, deps: [], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: ResizeObserverFactory, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: ResizeObserverFactory, decorators: [{
            type: Injectable,
            args: [{ providedIn: 'root' }]
        }] });
class ResizeObserverService {
    /** @hidden */
    constructor(_resizeObserverFactory) {
        this._resizeObserverFactory = _resizeObserverFactory;
        /** @hidden */
        this._observedElements = new Map();
    }
    /** @hidden */
    ngOnDestroy() {
        this._observedElements.forEach((_, element) => this._cleanupObserver(element));
    }
    /** Observe the given element and emit whenever its size changes. */
    observe(elementOrRef) {
        const element = coerceElement(elementOrRef);
        return new Observable((observer) => {
            const stream = this._observeElement(element);
            const subscription = stream?.subscribe(observer);
            return () => {
                subscription?.unsubscribe();
                this._unobserveElement(element);
            };
        });
    }
    /**
     * Observes the given element by using the existing MutationObserver if available, or creating a
     * new one if not.
     */
    _observeElement(element) {
        let observedElement = this._observedElements.get(element);
        if (!observedElement) {
            const stream = new Subject();
            const observer = this._resizeObserverFactory.create((mutations) => stream.next(mutations));
            if (observer) {
                observer.observe(element);
            }
            observedElement = { observer, stream, count: 0 };
            this._observedElements.set(element, observedElement);
        }
        observedElement.count++;
        return observedElement?.stream;
    }
    /**
     * Un-observes the given element and cleans up the underlying MutationObserver if nobody else is
     * observing this element.
     */
    _unobserveElement(element) {
        const observedElement = this._observedElements.get(element);
        if (!observedElement) {
            return;
        }
        if (--observedElement.count) {
            return;
        }
        this._cleanupObserver(element);
    }
    /** Clean up the underlying MutationObserver for the specified element. */
    _cleanupObserver(element) {
        const observedElement = this._observedElements.get(element);
        if (!observedElement) {
            return;
        }
        const { observer, stream } = observedElement;
        if (observer) {
            observer.disconnect();
        }
        stream.complete();
        this._observedElements.delete(element);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: ResizeObserverService, deps: [{ token: ResizeObserverFactory }], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: ResizeObserverService, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: ResizeObserverService, decorators: [{
            type: Injectable,
            args: [{ providedIn: 'root' }]
        }], ctorParameters: () => [{ type: ResizeObserverFactory }] });

/** Default RTL languages */
const DefaultRtlLanguages = ['ar', 'arc', 'dv', 'fa', 'ha', 'he', 'khw', 'ks', 'ku', 'ps', 'ur', 'yi'];
const RTL_LANGUAGE = new InjectionToken('RtlLanguage');
/**
 * Service taking care of RTL trough behavior subject
 * language list is used to determine if rtl should be enabled at start
 * user can overwrite default languages by using injection token RtlLanguageToken
 */
class RtlService {
    /** @hidden */
    constructor(injectedRtlLanguages) {
        injectedRtlLanguages = injectedRtlLanguages || DefaultRtlLanguages;
        const filtered = injectedRtlLanguages.filter((language) => navigator.language.includes(language));
        this.rtl = new BehaviorSubject(filtered.length > 0);
        this.rtlSignal = toSignal(this.rtl, { requireSync: true });
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: RtlService, deps: [{ token: RTL_LANGUAGE, optional: true }], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: RtlService }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: RtlService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [RTL_LANGUAGE]
                }] }] });

class TabbableElementService {
    /** @hidden */
    constructor(_checker, _document) {
        this._checker = _checker;
        this._document = _document;
    }
    /** Get the first tabbable element from a DOM subtree (inclusive). */
    getTabbableElement(root, focusLastElement = false, skipSelf = false) {
        if (!skipSelf && this._checker.isFocusable(root) && this._checker.isTabbable(root)) {
            return root;
        }
        // Iterate in DOM order. Note that IE doesn't have `children` for SVG, so we fall
        // back to `childNodes` which includes text nodes, comments etc.
        const rootChildren = root.children || root.childNodes;
        const children = focusLastElement ? Array.from(rootChildren).reverse() : rootChildren;
        for (let i = 0; i < children.length; i++) {
            const tabbableChild = children[i].nodeType === this._document?.ELEMENT_NODE
                ? this.getTabbableElement(children[i], focusLastElement)
                : null;
            if (tabbableChild) {
                return tabbableChild;
            }
        }
        return null;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: TabbableElementService, deps: [{ token: i1$1.InteractivityChecker }, { token: DOCUMENT, optional: true }], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: TabbableElementService, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: TabbableElementService, decorators: [{
            type: Injectable,
            args: [{ providedIn: 'root' }]
        }], ctorParameters: () => [{ type: i1$1.InteractivityChecker }, { type: Document, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [DOCUMENT]
                }] }] });

/**
 * Injection token for the viewport size observable.
 * Emits the viewport size in pixels, which are outputted by the ViewportRuler
 * from @angular/cdk/overlay.
 */
const ViewportSizeObservable = new InjectionToken('ViewportSizeObservable', {
    providedIn: 'root',
    factory: () => {
        const viewportRuler = inject(ViewportRuler);
        return viewportRuler
            .change(50)
            .pipe(map$1((e) => e.target.innerWidth))
            .pipe(startWith(window.innerWidth));
    }
});

const ResponsiveBreakpoints = {
    S: 600,
    M: 1024,
    L: 1440
};
/** @hidden */
function getBreakpointName(width) {
    if (width < ResponsiveBreakpoints.S) {
        return 'S';
    }
    if (width < ResponsiveBreakpoints.M) {
        return 'M';
    }
    if (width < ResponsiveBreakpoints.L) {
        return 'L';
    }
    return 'XL';
}

/* eslint-disable @angular-eslint/no-input-rename */
/**
 * Directive to show/hide element on specific breakpoint or range of window width.
 * Uses native ngIf directive to show/hide element.
 */
class BreakpointDirective {
    /**
     * Provide list of the breakpoints to show element on.
     * */
    set fdkBreakpoint(value) {
        const providedValues = value.map((v) => v.toLowerCase());
        this.showOnS = providedValues.includes('s');
        this.showOnM = providedValues.includes('m');
        this.showOnL = providedValues.includes('l');
        this.showOnXL = providedValues.includes('xl');
    }
    /**
     * Observe element width changes.
     */
    set observationSource(value) {
        if (!value) {
            this._sizeObservable$.next(this.viewportSize$);
            return;
        }
        const element = coerceElement(value);
        this._sizeObservable$.next(this._resizeObserverService.observe(value).pipe(map(() => element.offsetWidth), startWith(element.offsetWidth)));
    }
    /** @hidden */
    constructor(templateRef, viewContainer) {
        this.templateRef = templateRef;
        this.viewContainer = viewContainer;
        /**
         * Show element on S breakpoint.
         * S - 0 - 599px
         * */
        this.showOnS = false;
        /**
         * Show element on M breakpoint.
         * M - 0 - 1023px
         * */
        this.showOnM = false;
        /**
         * Show element on L breakpoint.
         * L - 0 - 1439px
         * */
        this.showOnL = false;
        /**
         * Show element on XL breakpoint.
         *  */
        this.showOnXL = false;
        /** @hidden */
        this.onChanges$ = new Subject();
        /** @hidden */
        this._sizeObservable$ = new BehaviorSubject(inject(ViewportSizeObservable));
        /** @hidden */
        this.viewportSize$ = inject(ViewportSizeObservable);
        /** @hidden */
        this._destroyRef = inject(DestroyRef);
        /** @hidden */
        this._resizeObserverService = inject(ResizeObserverService);
    }
    /** @hidden */
    ngAfterViewInit() {
        combineLatest([this._sizeObservable$.pipe(switchMap$1((obs$) => obs$)), this.onChanges$.pipe(startWith(void 0))])
            .pipe(map(([w]) => [w, getBreakpointName(w)]), map(([width, breakpointName]) => this._shouldShow(width, breakpointName)), tap((shouldShow) => {
            if (shouldShow) {
                if (!this.templateViewRef) {
                    this.viewContainer.clear();
                    this.templateViewRef = this.viewContainer.createEmbeddedView(this.templateRef);
                    this.templateViewRef.detectChanges();
                }
            }
            else {
                this.viewContainer.clear();
                this.templateViewRef = undefined;
            }
        }), takeUntilDestroyed(this._destroyRef), finalize(() => {
            this.viewContainer.clear();
            this.templateViewRef = undefined;
        }))
            .subscribe();
    }
    /** @hidden */
    ngOnChanges() {
        this.onChanges$.next();
    }
    /** @hidden */
    _shouldShow(width, currentBreakpoint) {
        const shouldShowOnBreakpoints = [
            this.showOnS && 'S',
            this.showOnM && 'M',
            this.showOnL && 'L',
            this.showOnXL && 'XL'
        ].filter(Boolean);
        const shouldShow = shouldShowOnBreakpoints.includes(currentBreakpoint);
        if (this.fdkBreakpointLt) {
            return width < this.fdkBreakpointLt;
        }
        if (this.fdkBreakpointGt) {
            return width > this.fdkBreakpointGt;
        }
        return shouldShow;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: BreakpointDirective, deps: [{ token: i0.TemplateRef }, { token: i0.ViewContainerRef }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "16.1.0", version: "19.2.3", type: BreakpointDirective, isStandalone: true, selector: "[fdkBreakpoint], [fdkBreakpointS], [fdkBreakpointM], [fdkBreakpointL], [fdkBreakpointXL], [fdkBreakpointLt], [fdkBreakpointGt]", inputs: { fdkBreakpoint: "fdkBreakpoint", showOnS: ["fdkBreakpointS", "showOnS", booleanAttribute], showOnM: ["fdkBreakpointM", "showOnM", booleanAttribute], showOnL: ["fdkBreakpointL", "showOnL", booleanAttribute], showOnXL: ["fdkBreakpointXL", "showOnXL", booleanAttribute], fdkBreakpointLt: "fdkBreakpointLt", fdkBreakpointGt: "fdkBreakpointGt", observationSource: ["fdkBreakpointObserve", "observationSource"] }, usesOnChanges: true, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: BreakpointDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[fdkBreakpoint], [fdkBreakpointS], [fdkBreakpointM], [fdkBreakpointL], [fdkBreakpointXL], [fdkBreakpointLt], [fdkBreakpointGt]',
                    standalone: true
                }]
        }], ctorParameters: () => [{ type: i0.TemplateRef }, { type: i0.ViewContainerRef }], propDecorators: { fdkBreakpoint: [{
                type: Input
            }], showOnS: [{
                type: Input,
                args: [{ alias: 'fdkBreakpointS', transform: booleanAttribute }]
            }], showOnM: [{
                type: Input,
                args: [{ alias: 'fdkBreakpointM', transform: booleanAttribute }]
            }], showOnL: [{
                type: Input,
                args: [{ alias: 'fdkBreakpointL', transform: booleanAttribute }]
            }], showOnXL: [{
                type: Input,
                args: [{ alias: 'fdkBreakpointXL', transform: booleanAttribute }]
            }], fdkBreakpointLt: [{
                type: Input
            }], fdkBreakpointGt: [{
                type: Input
            }], observationSource: [{
                type: Input,
                args: ['fdkBreakpointObserve']
            }] } });
class BreakpointModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: BreakpointModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "19.2.3", ngImport: i0, type: BreakpointModule, imports: [BreakpointDirective], exports: [BreakpointDirective] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: BreakpointModule }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: BreakpointModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [BreakpointDirective],
                    exports: [BreakpointDirective]
                }]
        }] });

class ClickedDirective {
    /**
     * Event name.
     */
    static { this.eventName = 'fdkClicked'; }
    /** @hidden */
    constructor() {
        const { nativeElement: element } = inject(ElementRef);
        const renderer = inject(Renderer2);
        const destroyRef = inject(DestroyRef);
        const enter$ = new Subject();
        const space$ = new Subject();
        destroyRef.onDestroy(renderer.listen(element, 'keydown.enter', (e) => enter$.next(e)));
        destroyRef.onDestroy(renderer.listen(element, 'keydown.space', (e) => space$.next(e)));
        destroyRef.onDestroy(() => {
            enter$.complete();
            space$.complete();
        });
        this.fdkClicked = merge(fromEvent(element, 'click'), enter$, space$);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: ClickedDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "19.2.3", type: ClickedDirective, isStandalone: true, selector: "[fdkClicked]", outputs: { fdkClicked: "fdkClicked" }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: ClickedDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[fdkClicked]',
                    standalone: true
                }]
        }], ctorParameters: () => [], propDecorators: { fdkClicked: [{
                type: Output
            }] } });

/**
 * @deprecated
 * No need to use it anymore. Use ClickedDirective directly instead.
 */
class ClickedEventPlugin {
    /** @hidden */
    constructor(document, platformId) {
        this.document = document;
        this.platformId = platformId;
        console.warn(`ClickedEventPlugin is deprecated and will be removed in the next major release. Use ClickedDirective instead.`);
    }
    /** @hidden */
    addEventListener(element, eventName, handler) {
        return this._setupEventBinding(element, handler);
    }
    /** @hidden */
    addGlobalEventListener(higherOrderElement, eventName, handler) {
        const target = this._parseHigherOrderElement(higherOrderElement);
        return this._setupEventBinding(target, handler);
    }
    /** @hidden */
    supports(eventName) {
        return eventName === ClickedDirective.eventName;
    }
    /** @hidden */
    _parseHigherOrderElement(selector) {
        if (this.platformId !== 'browser') {
            return this.document;
        }
        switch (selector) {
            case 'window':
                return window;
            case 'document':
                return document;
            case 'body':
                return document.body;
            default:
                throw new Error(`Element selector [${selector}] not supported.`);
        }
    }
    /** @hidden */
    _setupEventBinding(target, handler) {
        const addProxyFunction = () => {
            target.addEventListener('click', proxyFunction, false);
            target.addEventListener('keydown', proxyFunction, false);
        };
        const removeProxyFunction = () => {
            target.removeEventListener('click', proxyFunction, false);
            target.removeEventListener('keydown', proxyFunction, false);
        };
        const proxyFunction = (event) => {
            if (event instanceof KeyboardEvent) {
                if (event.keyCode !== ENTER && event.keyCode !== SPACE) {
                    return;
                }
            }
            handler(event);
        };
        addProxyFunction();
        return removeProxyFunction;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: ClickedEventPlugin, deps: [{ token: DOCUMENT }, { token: PLATFORM_ID }], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: ClickedEventPlugin }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: ClickedEventPlugin, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: Document, decorators: [{
                    type: Inject,
                    args: [DOCUMENT]
                }] }, { type: undefined, decorators: [{
                    type: Inject,
                    args: [PLATFORM_ID]
                }] }] });

/**
 * @deprecated
 * ClickedBehaviorModule is deprecated and will be removed in the next major release. Use ClickedDirective instead.
 */
const ClickedBehaviorModuleForRootLoadedOnce = new InjectionToken('Checking Module providers had been loaded', { factory: () => false });
/**
 * Provides ClickedEventPlugin to the application
 * @deprecated
 */
function provideFdkClicked() {
    if (isDevMode()) {
        console.warn(`provideFdkClicked() is deprecated and will be removed in the next major release. Use ClickedDirective instead.`);
    }
    return [
        {
            provide: EVENT_MANAGER_PLUGINS,
            useClass: ClickedEventPlugin,
            multi: true
        },
        {
            provide: ClickedBehaviorModuleForRootLoadedOnce,
            useValue: true
        }
    ];
}

/**
 * @deprecated
 * ClickedBehaviorModule is deprecated and will be removed in the next major release. Use ClickedDirective instead.
 */
class ClickedBehaviorModule {
    /** @hidden */
    constructor() {
        console.warn(`ClickedBehaviorModule is deprecated and will be removed in the next major release. Use ClickedDirective instead.`);
    }
    /** @hidden */
    static forRoot() {
        if (isDevMode()) {
            console.warn(`ClickedBehaviorModule.forRoot() is deprecated and will be removed in the next major release. Use ClickedDirective instead.`);
        }
        return {
            ngModule: ClickedBehaviorModule,
            providers: [provideFdkClicked()]
        };
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: ClickedBehaviorModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "19.2.3", ngImport: i0, type: ClickedBehaviorModule, imports: [ClickedDirective], exports: [ClickedDirective] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: ClickedBehaviorModule }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: ClickedBehaviorModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [ClickedDirective],
                    exports: [ClickedDirective]
                }]
        }], ctorParameters: () => [] });

/**
 * Returns Observable that emits when element is clicked. Uses Renderer2 to listen to events.
 * @param element
 * @param renderer
 */
function elementClick$(element, renderer = inject(Renderer2)) {
    return new Observable((observer) => {
        const cleanups = [
            renderer.listen(element, 'click', (event) => observer.next(event)),
            renderer.listen(element, 'keydown.enter', (event) => observer.next(event)),
            renderer.listen(element, 'keydown.space', (event) => {
                event.preventDefault();
                observer.next(event);
            })
        ];
        return () => cleanups.forEach((cleanup) => cleanup());
    });
}

class FdkClickedProvider extends Subject {
    /** @hidden */
    constructor(_elementRef, _renderer, eventManagerPlugins) {
        super();
        this._elementRef = _elementRef;
        this._renderer = _renderer;
        /** @hidden */
        this._preventDefault = true;
        this._fdkClickedEventManagerPluginLoaded = eventManagerPlugins.some((em) => em instanceof ClickedEventPlugin);
        this._initialize();
    }
    /** @hidden */
    setPreventDefault(val) {
        this._preventDefault = val;
    }
    /** @hidden */
    ngOnDestroy() {
        this._listeners.forEach((d) => d());
        this.complete();
    }
    /** @hidden */
    _initialize() {
        const eventsList = this._fdkClickedEventManagerPluginLoaded
            ? [ClickedDirective.eventName]
            : ['click', 'keydown.enter', 'keydown.space'];
        this._listeners = eventsList.map((eventName) => this._renderer.listen(this._elementRef.nativeElement, eventName, (event) => {
            if (this._preventDefault) {
                event.preventDefault();
            }
            this.next(event);
        }));
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: FdkClickedProvider, deps: [{ token: i0.ElementRef }, { token: i0.Renderer2 }, { token: EVENT_MANAGER_PLUGINS }], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: FdkClickedProvider }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: FdkClickedProvider, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i0.ElementRef }, { type: i0.Renderer2 }, { type: undefined, decorators: [{
                    type: Inject,
                    args: [EVENT_MANAGER_PLUGINS]
                }] }] });

const FDK_DISABLED_DIRECTIVE = new InjectionToken('Disabled directive token');

/** @hidden */
function setDisabledState(element, isDisabled, disabledClass, addDisabledClass) {
    const htmlElement = getNativeElement(element);
    if (isDisabled) {
        if (addDisabledClass) {
            htmlElement.classList.add(disabledClass);
        }
        htmlElement.setAttribute('disabled', '');
        htmlElement.setAttribute('aria-disabled', 'true');
    }
    else {
        htmlElement.classList.remove(disabledClass);
        htmlElement.removeAttribute('disabled');
        htmlElement.removeAttribute('aria-disabled');
    }
}

class DisabledBehaviorDirective extends ReplaySubject {
    /** @hidden */
    set fdkDisabled(value) {
        const val = coerceBooleanProperty(value);
        this._clicked.setPreventDefault(val);
        this._fdkDisableInput$.next(val);
    }
    get fdkDisabled() {
        return this._disabled;
    }
    /** @hidden */
    constructor(_elementRef, _destroyRef, _clicked) {
        super(1);
        this._elementRef = _elementRef;
        this._destroyRef = _destroyRef;
        this._clicked = _clicked;
        /**
         * Whether to add `disabledClass` class to the element.
         */
        this.addDisabledClass = true;
        /**
         * Disabled css class to apply to the element.
         */
        this.disabledClass = 'is-disabled';
        /** @hidden */
        this._disabled = false;
        /** @hidden */
        this._fdkDisableInput$ = new BehaviorSubject(false);
        /** @hidden */
        this.setDisabledState = (isDisabled) => {
            setDisabledState(this._elementRef, isDisabled, this.disabledClass, this.addDisabledClass);
        };
        this._destroyRef.onDestroy(() => this.complete());
    }
    /** @hidden */
    ngAfterViewInit() {
        this._fdkDisableInput$
            .pipe(filter$1((isDisabled) => isDisabled !== this._disabled), tap((isDisabled) => {
            this.setDisabledState(isDisabled);
            this._disabled = isDisabled;
            this.next(isDisabled);
        }), takeUntilDestroyed(this._destroyRef))
            .subscribe();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: DisabledBehaviorDirective, deps: [{ token: i0.ElementRef }, { token: i0.DestroyRef }, { token: FdkClickedProvider }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "19.2.3", type: DisabledBehaviorDirective, isStandalone: true, selector: "[fdkDisabled]", inputs: { fdkDisabled: "fdkDisabled", addDisabledClass: "addDisabledClass", disabledClass: "disabledClass" }, providers: [
            {
                provide: FDK_DISABLED_DIRECTIVE,
                useExisting: DisabledBehaviorDirective
            },
            FdkClickedProvider
        ], usesInheritance: true, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: DisabledBehaviorDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[fdkDisabled]',
                    standalone: true,
                    providers: [
                        {
                            provide: FDK_DISABLED_DIRECTIVE,
                            useExisting: DisabledBehaviorDirective
                        },
                        FdkClickedProvider
                    ]
                }]
        }], ctorParameters: () => [{ type: i0.ElementRef }, { type: i0.DestroyRef }, { type: FdkClickedProvider }], propDecorators: { fdkDisabled: [{
                type: Input
            }], addDisabledClass: [{
                type: Input
            }], disabledClass: [{
                type: Input
            }] } });

class DisabledBehaviorModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: DisabledBehaviorModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "19.2.3", ngImport: i0, type: DisabledBehaviorModule, imports: [DisabledBehaviorDirective], exports: [DisabledBehaviorDirective] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: DisabledBehaviorModule }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: DisabledBehaviorModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [DisabledBehaviorDirective],
                    exports: [DisabledBehaviorDirective]
                }]
        }] });

class DisabledObserver {
    /** @hidden */
    constructor(_attributeObserver) {
        this._attributeObserver = _attributeObserver;
    }
    /** @hidden */
    static isDisabled(el) {
        return (el.hasAttribute('disabled') ||
            el.getAttribute('aria-disabled') === 'true' ||
            el.classList.contains('is-disabled'));
    }
    /** @hidden */
    observe(element) {
        return this._attributeObserver.observe(element).pipe(map(() => DisabledObserver.isDisabled(getNativeElement(element))), distinctUntilChanged());
    }
    /** @hidden */
    unobserve(element) {
        this._attributeObserver.unobserve(element);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: DisabledObserver, deps: [{ token: AttributeObserver }], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: DisabledObserver, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: DisabledObserver, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: () => [{ type: AttributeObserver }] });

class DefaultDisabledViewModifier {
    /** @hidden */
    constructor(elementRef) {
        this.elementRef = elementRef;
        /** @hidden */
        this.setDisabledState = (isDisabled) => {
            setDisabledState(this.elementRef, isDisabled, 'is-disabled', true);
        };
    }
}

class FdkDisabledProvider extends ReplaySubject {
    /** @hidden */
    constructor(ngZone, elementRef, disabledObserver, selfDisabled$, parentDisabled$) {
        super(1);
        this.ngZone = ngZone;
        this.elementRef = elementRef;
        this.disabledObserver = disabledObserver;
        this.selfDisabled$ = selfDisabled$;
        this.parentDisabled$ = parentDisabled$;
        /** @Hidden */
        this.fdkDisabled = false;
        /** @Hidden */
        this._destroyRef = inject(DestroyRef);
        /** @hidden */
        this._viewModifiers$ = new BehaviorSubject(this._getInitialViewModifiers());
        /** @hidden */
        this._disabledChange$ = this._getDisabledChange$();
        combineLatest([this._disabledChange$, this._viewModifiers$])
            .pipe(tap(([isDisabled]) => this.setDisabledState(isDisabled)), takeUntilDestroyed(this._destroyRef))
            .subscribe();
        this._disabledChange$
            .pipe(tap((isDisabled) => (this.fdkDisabled = isDisabled)), tap((isDisabled) => this.next(isDisabled)), takeUntilDestroyed(this._destroyRef))
            .subscribe();
    }
    /** @hidden */
    addViewModifier(modifier) {
        const viewModifiers = [...new Set([...this._viewModifiers$.value, modifier]).values()];
        this._viewModifiers$.next(viewModifiers);
    }
    /** @hidden */
    setDisabledState(isDisabled) {
        firstValueFrom(this.ngZone.onStable).then(() => {
            this._viewModifiers$.value.forEach((viewModifier) => viewModifier.setDisabledState(isDisabled));
        });
    }
    /** @hidden */
    ngOnDestroy() {
        this.complete();
        this.disabledObserver.unobserve(this.elementRef);
    }
    /** @hidden */
    _getDisabledChange$() {
        let selfDisabled = false;
        let parentDisabled = false;
        if (this.parentDisabled$) {
            this.parentDisabled$
                .pipe(startWith(this.parentDisabled$.fdkDisabled), tap((d) => (parentDisabled = d)), distinctUntilChanged(), tap(() => {
                if (parentDisabled) {
                    this.setDisabledState(true);
                }
                if (!selfDisabled && !parentDisabled) {
                    this.setDisabledState(false);
                }
            }), takeUntilDestroyed(this._destroyRef))
                .subscribe();
        }
        if (this.selfDisabled$) {
            this.selfDisabled$
                .pipe(startWith(this.selfDisabled$.fdkDisabled), tap((d) => (selfDisabled = d)), distinctUntilChanged(), tap((isDisabled) => {
                if (!parentDisabled) {
                    this.setDisabledState(isDisabled);
                }
            }), takeUntilDestroyed(this._destroyRef))
                .subscribe();
        }
        return this.disabledObserver.observe(this.elementRef).pipe(distinctUntilChanged());
    }
    /** @hidden */
    _getInitialViewModifiers() {
        return !this.selfDisabled$ ? [new DefaultDisabledViewModifier(this.elementRef)] : [this.selfDisabled$];
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: FdkDisabledProvider, deps: [{ token: i0.NgZone }, { token: i0.ElementRef }, { token: DisabledObserver }, { token: FDK_DISABLED_DIRECTIVE, optional: true, self: true }, { token: FDK_DISABLED_DIRECTIVE, optional: true, skipSelf: true }], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: FdkDisabledProvider }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: FdkDisabledProvider, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i0.NgZone }, { type: i0.ElementRef }, { type: DisabledObserver }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Self
                }, {
                    type: Inject,
                    args: [FDK_DISABLED_DIRECTIVE]
                }] }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: SkipSelf
                }, {
                    type: Inject,
                    args: [FDK_DISABLED_DIRECTIVE]
                }] }] });

const FOCUSABLE_ITEM = new InjectionToken('Focusable Option');

/** Directive to apply Angular Material FocusKeyManager to lists.
 * To be used with FocusKeyManagerItemDirective
 */
class FocusKeyManagerListDirective {
    /** @hidden */
    get focusKeyManager() {
        return this._focusKeyManager;
    }
    /** @hidden */
    constructor(_rtlService, _cdr) {
        this._rtlService = _rtlService;
        this._cdr = _cdr;
        /** @hidden */
        this._onDestroy$ = inject(DestroyRef);
    }
    /** @hidden */
    ngOnChanges(changes) {
        if (!this._focusKeyManager) {
            return;
        }
        if ('orientation' in changes) {
            this._applyOrientation();
        }
        if ('skiPredicate' in changes) {
            this._focusKeyManager.skipPredicate(this.skipPredicate);
        }
    }
    /** @hidden */
    ngAfterContentInit() {
        this._focusKeyManager = new FocusKeyManager(this._items).skipPredicate(this.skipPredicate);
        this._applyOrientation();
        this._cdr.detectChanges();
        this._rtlService?.rtl
            .pipe(filter(() => this.orientation === 'horizontal'), takeUntilDestroyed(this._onDestroy$))
            .subscribe(() => this._applyOrientation());
    }
    /** @hidden */
    ngOnDestroy() {
        this._focusKeyManager.destroy();
    }
    /** Focus certain list's item */
    focusItem(item) {
        if (typeof item === 'number') {
            this._focusKeyManager.setActiveItem(item);
        }
        else {
            this._focusKeyManager.setActiveItem(item);
        }
    }
    /** @hidden */
    _applyOrientation() {
        switch (this.orientation) {
            case 'horizontal':
                this._focusKeyManager.withHorizontalOrientation(this._rtlService?.rtl.value ? 'rtl' : 'ltr');
                break;
            case 'vertical':
                this._focusKeyManager.withVerticalOrientation(true);
                break;
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: FocusKeyManagerListDirective, deps: [{ token: RtlService, optional: true }, { token: i0.ChangeDetectorRef }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "19.2.3", type: FocusKeyManagerListDirective, isStandalone: true, selector: "[fdkFocusKeyManagerList]", inputs: { orientation: "orientation", skipPredicate: "skipPredicate" }, queries: [{ propertyName: "_items", predicate: FOCUSABLE_ITEM }], usesOnChanges: true, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: FocusKeyManagerListDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: `[fdkFocusKeyManagerList]`,
                    standalone: true
                }]
        }], ctorParameters: () => [{ type: RtlService, decorators: [{
                    type: Optional
                }] }, { type: i0.ChangeDetectorRef }], propDecorators: { orientation: [{
                type: Input
            }], skipPredicate: [{
                type: Input
            }], _items: [{
                type: ContentChildren,
                args: [FOCUSABLE_ITEM]
            }] } });

/** Directive to apply Angular Material FocusKeyManager to lists.
 * To be used with FocusKeyManagerItemDirective
 */
class FocusKeyManagerItemDirective {
    /** @hidden */
    get _tabindex() {
        return this.initialFocus ? 0 : (this.nativeElement?.tabIndex ?? -1);
    }
    /** Native element of the item */
    get nativeElement() {
        return this._elRef?.nativeElement;
    }
    /** @hidden */
    get _focusKeyManager() {
        return this._list.focusKeyManager;
    }
    /** @hidden */
    constructor(_list, _elRef) {
        this._list = _list;
        this._elRef = _elRef;
        /** Whether item should be initially focused */
        this.initialFocus = false;
    }
    /** @hidden */
    _onFocus() {
        // For cases where initially selected item doesn't have 0 index
        this._focusKeyManager?.updateActiveItem(this);
    }
    /** @hidden */
    _onKeydown(event) {
        this._focusKeyManager?.onKeydown(event);
    }
    /** Focus current item native element */
    focus() {
        this._elRef?.nativeElement.focus();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: FocusKeyManagerItemDirective, deps: [{ token: FocusKeyManagerListDirective }, { token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "16.1.0", version: "19.2.3", type: FocusKeyManagerItemDirective, isStandalone: true, selector: "[fdkFocusKeyManagerItem]", inputs: { initialFocus: ["initialFocus", "initialFocus", booleanAttribute], _tabindex: "_tabindex" }, host: { listeners: { "focus": "_onFocus()", "keydown": "_onKeydown($event)" }, properties: { "attr.tabindex": "this._tabindex" } }, providers: [{ provide: FOCUSABLE_ITEM, useExisting: forwardRef(() => FocusKeyManagerItemDirective) }], ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: FocusKeyManagerItemDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[fdkFocusKeyManagerItem]',
                    standalone: true,
                    providers: [{ provide: FOCUSABLE_ITEM, useExisting: forwardRef(() => FocusKeyManagerItemDirective) }]
                }]
        }], ctorParameters: () => [{ type: FocusKeyManagerListDirective }, { type: i0.ElementRef }], propDecorators: { initialFocus: [{
                type: Input,
                args: [{ transform: booleanAttribute }]
            }], _tabindex: [{
                type: Input
            }, {
                type: HostBinding,
                args: ['attr.tabindex']
            }], _onFocus: [{
                type: HostListener,
                args: ['focus']
            }], _onKeydown: [{
                type: HostListener,
                args: ['keydown', ['$event']]
            }] } });

class FocusKeyManagerHelpersModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: FocusKeyManagerHelpersModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "19.2.3", ngImport: i0, type: FocusKeyManagerHelpersModule, imports: [FocusKeyManagerItemDirective, FocusKeyManagerListDirective], exports: [FocusKeyManagerItemDirective, FocusKeyManagerListDirective] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: FocusKeyManagerHelpersModule }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: FocusKeyManagerHelpersModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [FocusKeyManagerItemDirective, FocusKeyManagerListDirective],
                    exports: [FocusKeyManagerItemDirective, FocusKeyManagerListDirective]
                }]
        }] });

const FDK_FOCUSABLE_ITEM_DIRECTIVE = new InjectionToken('Focusable directive token');

const focusableTagnamesByDefault = new Set(['select', 'textarea', 'input', 'button', 'audio', 'video']);
const focusableTagOptions = [
    {
        tag: 'div',
        attributes: [
            {
                name: 'contenteditable',
                valueMatcher: (value) => coerceBooleanProperty(value)
            }
        ]
    }
];
/** @hidden */
function isElementFocusableByDefault(el) {
    const element = getNativeElement(el);
    const tagName = element.tagName.toLowerCase();
    if (focusableTagnamesByDefault.has(tagName)) {
        return true;
    }
    return focusableTagOptions.some((tagOptions) => {
        if (tagOptions.tag === tagName) {
            return tagOptions.attributes.some((attribute) => {
                const attrVal = element.getAttribute(attribute.name);
                return attrVal && attribute.valueMatcher(attrVal);
            });
        }
        return false;
    });
}

class FocusableObserver {
    /** @hidden */
    constructor(_attributeObserver) {
        this._attributeObserver = _attributeObserver;
    }
    /** @Hidden */
    static isFocusable(element, respectTabIndex) {
        if (DisabledObserver.isDisabled(element)) {
            return false;
        }
        if (!respectTabIndex) {
            return true;
        }
        const tabIndex = parseInt(element.getAttribute('tabindex') + '', 10);
        if (isNaN(tabIndex)) {
            return isElementFocusableByDefault(element);
        }
        return tabIndex > -1;
    }
    /** @hidden */
    observe(element, respectTabIndex = true) {
        const nativeElement = getNativeElement(element);
        return this._attributeObserver.observe(nativeElement).pipe(map(() => FocusableObserver.isFocusable(nativeElement, respectTabIndex)), distinctUntilChanged());
    }
    /** @hidden */
    unobserve(element) {
        this._attributeObserver.unobserve(element);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: FocusableObserver, deps: [{ token: AttributeObserver }], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: FocusableObserver, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: FocusableObserver, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: () => [{ type: AttributeObserver }] });

class FocusableItemDirective {
    /** Whether the item is focusable. Default is true. */
    set fdkFocusableItem(val) {
        this._focusable = val;
        this.setTabbable(this._focusable);
    }
    get fdkFocusableItem() {
        return this._focusable;
    }
    /** @hidden */
    constructor() {
        /** Function, which returns a string to be announced by screen-reader whenever an item which is in grid receives focus. */
        this.cellFocusedEventAnnouncer = this._defaultItemFocusedEventAnnouncer;
        /** Event emitted when the cell receives focus, not being emitted when focus moves between item's children. */
        this.cellFocused = new EventEmitter();
        /** Element reference. */
        this.elementRef = inject(ElementRef);
        /** @hidden */
        this.keydown = new Subject();
        /** @hidden */
        this._destroyRef = inject(DestroyRef);
        /** @hidden */
        this._zone = inject(NgZone);
        /** @hidden */
        this._focusable = true;
        /** @hidden */
        this._tabbableElements = new Map();
        /** @hidden */
        this._tabbable = true;
        /** @hidden */
        this._focusableObserver = inject(FocusableObserver);
        /** @hidden */
        this._tabbableElementService = inject(TabbableElementService);
        /** @hidden */
        this._liveAnnouncer = inject(LiveAnnouncer);
        /** @hidden */
        this._renderer2 = inject(Renderer2);
        /** @hidden */
        this._document = inject(DOCUMENT);
        /** @hidden */
        this.element = () => this.elementRef.nativeElement;
        this._focusableObserver
            .observe(this.elementRef, false)
            .pipe(takeUntilDestroyed())
            .subscribe((isFocusable) => {
            if (isFocusable !== this.fdkFocusableItem) {
                this.fdkFocusableItem = isFocusable;
            }
        });
        this._zone.runOutsideAngular(() => {
            fromEvent(this.elementRef.nativeElement, 'focusin')
                .pipe(takeUntilDestroyed())
                .subscribe(async () => {
                await this._onFocusin();
            });
            fromEvent(this.elementRef.nativeElement, 'focusout')
                .pipe(takeUntilDestroyed())
                .subscribe(() => {
                this._onFocusout();
            });
            fromEvent(this.elementRef.nativeElement, 'keydown')
                .pipe(takeUntilDestroyed())
                .subscribe((event) => {
                this._onKeydown(event);
            });
        });
    }
    /** @hidden */
    isFocusable() {
        return this._focusable;
    }
    /** @hidden */
    focus() {
        this.elementRef.nativeElement.focus();
    }
    /** Set tabbable state */
    setTabbable(state) {
        this._tabbable = state;
        this._renderer2.setAttribute(this.elementRef.nativeElement, 'tabindex', this._tabbable ? '0' : '-1');
        if (state) {
            this._enableTabbableElements();
        }
        else {
            this._disableTabbableElements();
        }
    }
    /** @hidden */
    async _onFocusin() {
        if (!this.fdkFocusableItem) {
            return;
        }
        if (this._timerId != null) {
            clearTimeout(this._timerId);
            this._timerId = null;
            return;
        }
        if (this._position) {
            this.cellFocused.next(this._position);
            if (this.cellFocusedEventAnnouncer) {
                this._liveAnnouncer.clear();
                await this._liveAnnouncer.announce(this.cellFocusedEventAnnouncer(this._position));
            }
        }
    }
    /** @hidden */
    _onFocusout() {
        if (!this.fdkFocusableItem) {
            return;
        }
        // Timeout is needed to prevent focusout event from being emitted when focus moves between item's children.
        this._timerId = setTimeout(() => (this._timerId = null));
    }
    /** @hidden */
    _onKeydown(event) {
        if (!this.fdkFocusableItem) {
            return;
        }
        const isFocused = this._document.activeElement === this.elementRef.nativeElement;
        const shouldFocusChild = KeyUtil.isKeyCode(event, [ENTER, MAC_ENTER, F2]) && !event.shiftKey && isFocused;
        const shouldFocusCell = ((KeyUtil.isKeyCode(event, F2) && event.shiftKey) || KeyUtil.isKeyCode(event, ESCAPE)) && !isFocused;
        if (shouldFocusChild) {
            event.stopPropagation();
            const tabbableElement = this._tabbableElementService.getTabbableElement(this.elementRef.nativeElement, false, true);
            tabbableElement?.focus();
            return;
        }
        else if (shouldFocusCell) {
            event.stopPropagation();
            this.elementRef.nativeElement.focus();
            return;
        }
        if (isFocused) {
            this.keydown.next(event);
        }
    }
    /** @hidden */
    _enableTabbableElements() {
        if (this._tabbableElements.size === 0) {
            return;
        }
        this._tabbableElements.forEach((tabIndex, element) => (element.tabIndex = tabIndex));
        this._tabbable = false;
    }
    /** @hidden */
    _disableTabbableElements() {
        // Since we cannot select by tabindex attribute (links, inputs, buttons might not have one but still can be focusable),
        // Select all elements from the cell and filter by tabIndex property.
        Array.from(this.elementRef.nativeElement.querySelectorAll('*'))
            .filter((elm) => elm.tabIndex >= 0)
            .forEach((elm) => {
            this._tabbableElements.set(elm, elm.tabIndex);
            elm.tabIndex = -1;
        });
    }
    /** @hidden */
    _defaultItemFocusedEventAnnouncer(position) {
        return `Column ${position.colIndex + 1} of ${position.totalCols}, row: ${position.rowIndex + 1} of ${position.totalRows}`;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: FocusableItemDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "16.1.0", version: "19.2.3", type: FocusableItemDirective, isStandalone: true, selector: "[fdkFocusableItem]", inputs: { fdkFocusableItem: ["fdkFocusableItem", "fdkFocusableItem", booleanAttribute], cellFocusedEventAnnouncer: "cellFocusedEventAnnouncer" }, outputs: { cellFocused: "cellFocused" }, providers: [
            {
                provide: FDK_FOCUSABLE_ITEM_DIRECTIVE,
                useExisting: FocusableItemDirective
            }
        ], ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: FocusableItemDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[fdkFocusableItem]',
                    standalone: true,
                    providers: [
                        {
                            provide: FDK_FOCUSABLE_ITEM_DIRECTIVE,
                            useExisting: FocusableItemDirective
                        }
                    ]
                }]
        }], ctorParameters: () => [], propDecorators: { fdkFocusableItem: [{
                type: Input,
                args: [{ transform: booleanAttribute }]
            }], cellFocusedEventAnnouncer: [{
                type: Input
            }], cellFocused: [{
                type: Output
            }] } });

class FocusableItemModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: FocusableItemModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "19.2.3", ngImport: i0, type: FocusableItemModule, imports: [FocusableItemDirective], exports: [FocusableItemDirective] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: FocusableItemModule }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: FocusableItemModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [FocusableItemDirective],
                    exports: [FocusableItemDirective]
                }]
        }] });

const FDK_FOCUSABLE_LIST_DIRECTIVE = new InjectionToken('Focusable list token');

class IndirectFocusableListDirective {
    /** @hidden */
    constructor() {
        /** @hidden */
        this.injector = inject(Injector);
        /** @hidden */
        this._focusableList = inject(FDK_FOCUSABLE_LIST_DIRECTIVE, { optional: true });
        /** @hidden */
        this._indirectChildren = new BehaviorSubject([]);
        /** @hidden */
        this._indirectChildrenMap = new Map();
        if (this._focusableList) {
            const queryList = {
                toArray: () => this._indirectChildren.value,
                get: (index) => this._indirectChildren.value[index],
                [Symbol.iterator]: () => this._indirectChildren.value[Symbol.iterator](),
                forEach: (callback, thisArg) => this._indirectChildren.value.forEach(callback, thisArg)
            };
            queryList['changes'] = this._indirectChildren.pipe(debounceTime(100), distinctUntilChanged$1(deepEqual), map$1(() => queryList));
            this._focusableList.setItems(queryList);
        }
    }
    /** @hidden */
    register(item, itemOrder) {
        this._indirectChildrenMap.set(item, itemOrder);
        this._updateIndirectChildren();
    }
    /** @hidden */
    unregister(item) {
        this._indirectChildrenMap.delete(item);
        this._updateIndirectChildren();
    }
    /** @hidden */
    _updateIndirectChildren() {
        this._indirectChildren.next(Array.from(this._indirectChildrenMap.entries())
            .sort(([, orderA], [, orderB]) => {
            const orderAValue = typeof orderA === 'function' ? orderA() : orderA;
            const orderBValue = typeof orderB === 'function' ? orderB() : orderB;
            return orderAValue - orderBValue;
        })
            .map(([focusableItem]) => focusableItem));
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: IndirectFocusableListDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "19.2.3", type: IndirectFocusableListDirective, isStandalone: true, selector: "[fdkIndirectFocusableList]", exportAs: ["fdkIndirectFocusableList"], ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: IndirectFocusableListDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[fdkIndirectFocusableList]',
                    exportAs: 'fdkIndirectFocusableList',
                    standalone: true
                }]
        }], ctorParameters: () => [] });

const FDK_INDIRECT_FOCUSABLE_ITEM_ORDER = new InjectionToken('FDK_INDIRECT_FOCUSABLE_ITEM_ORDER');
/**
 * Directive, to mark the focusable item in the focusable list, which
 * is not the direct child of the focusable list.
 *
 * Useful in cases, when you need to make the item focusable, and
 * you do not have the access to the focusable list.
 */
class IndirectFocusableItemDirective {
    /** @hidden */
    constructor() {
        /** @hidden */
        this._focusableItem = inject(FDK_FOCUSABLE_ITEM_DIRECTIVE, { optional: true });
        /** @hidden */
        this._indirectFocusableList = inject(IndirectFocusableListDirective, { optional: true });
        /** @hidden */
        this._order = inject(FDK_INDIRECT_FOCUSABLE_ITEM_ORDER, { optional: true });
        /** @hidden */
        this._destroyRef = inject(DestroyRef);
        if (!this._focusableItem) {
            throw new Error('fdkIndirectFocusableItem directive must be used in conjunction with fdkFocusableItem directive');
        }
        if (this._indirectFocusableList && this._order) {
            const focusableItem = this._focusableItem;
            const indirectFocusableList = this._indirectFocusableList;
            indirectFocusableList.register(this._focusableItem, this._order);
            this._destroyRef.onDestroy(() => indirectFocusableList.unregister(focusableItem));
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: IndirectFocusableItemDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "19.2.3", type: IndirectFocusableItemDirective, isStandalone: true, selector: "[fdkIndirectFocusableItem]", ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: IndirectFocusableItemDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[fdkIndirectFocusableItem]',
                    standalone: true
                }]
        }], ctorParameters: () => [] });

/**
 * Returns true if the item configured to be focusable.
 * @param item
 */
function isItemFocusable(item) {
    return Boolean(typeof item.isFocusable === 'function' ? item.isFocusable() : item.isFocusable);
}

/**
 * Returns the element of the item.
 * @param item
 */
function getItemElement(item) {
    if (!item) {
        return null;
    }
    if (typeof item.element === 'function') {
        return item.element();
    }
    return item.element;
}

/** Helper function to scroll to focusable list or its item relatively to the container. */
function scrollIntoView(element, position) {
    if (!element) {
        return;
    }
    const scrollableParent = getScrollParent(element);
    if (scrollableParent) {
        const itemOffsetTop = element.offsetTop - scrollableParent.offsetTop;
        if (!position) {
            /**
             * check if top of focused element is fully visible, and if not, adjust scroll.
             * this is triggered when a sticky table header overlaps the focused cell.
             */
            const elRect = element.getBoundingClientRect();
            const topEl = document.elementFromPoint(elRect.left, elRect.top);
            if (!element.isSameNode(topEl) &&
                topEl &&
                element.getBoundingClientRect().top !== topEl.getBoundingClientRect().top) {
                scrollableParent.scrollBy({ top: elRect.top - topEl.getBoundingClientRect().bottom });
            }
        }
        switch (position) {
            case 'top':
                scrollableParent.scrollTop = itemOffsetTop;
                break;
            case 'bottom':
                scrollableParent.scrollTop = itemOffsetTop - (scrollableParent.offsetHeight - element.offsetHeight);
                break;
        }
    }
}
function getScrollParent(node) {
    if (node == null) {
        return null;
    }
    if (node.scrollHeight > node.clientHeight && ['auto', 'scroll'].includes(getComputedStyle(node).overflowY)) {
        return node;
    }
    else {
        return getScrollParent(node.parentNode);
    }
}

class FocusableListDirective {
    /** Whether the whole list should be focusable, handy in grids. */
    set focusable(value) {
        this._focusable = value;
        this.setTabbable(this._focusable);
    }
    get focusable() {
        return this._focusable;
    }
    /** @hidden */
    get _focusableItems() {
        return this._items ? this._items : this._projectedFocusableItems;
    }
    /** @hidden */
    get _tabindex() {
        return this._tabbable ? 0 : -1;
    }
    /** @hidden */
    constructor() {
        /** Direction of navigation. Should be set to 'grid' when list is a part of grid. */
        this.navigationDirection = 'vertical';
        /** Direction of the content. */
        this.contentDirection = 'ltr';
        /**
         * Configures wrapping mode which determines whether the active item will wrap to the other end of list when there are no more items in the given direction.
         */
        this.wrap = false;
        /** Function, which returns a string to be announced by screen-reader whenever an row which is in grid receives focus. */
        this.listFocusedEventAnnouncer = this._defaultListFocusedEventAnnouncer;
        /** Event emitted when list's item focused, contains item's position info. */
        this.itemFocused = new EventEmitter();
        /** @hidden */
        this._gridItemFocused$ = new Subject();
        /** @hidden */
        this._gridListFocused$ = new Subject();
        /** @hidden */
        this._keydown$ = new Subject();
        /** @hidden */
        this._isVisible = false;
        /** @hidden */
        this._destroyRef = inject(DestroyRef);
        /** @hidden */
        this._focusable = false;
        /** @hidden */
        this._tabbable = false;
        /** @hidden */
        this._refreshItems$ = new Subject();
        /** @hidden */
        this._refresh$ = new Subject();
        /** @hidden */
        this._renderer = inject(Renderer2);
        /** @hidden */
        this._elementRef = inject(ElementRef);
        /** @hidden */
        this._liveAnnouncer = inject(LiveAnnouncer);
        /** @hidden */
        this._focusableObserver = inject(FocusableObserver);
        /** @hidden */
        this._document = inject(DOCUMENT);
        intersectionObservable(this._elementRef.nativeElement, { threshold: 0.25 })
            .pipe(takeUntilDestroyed())
            .subscribe((isVisible) => (this._isVisible = isVisible[0]?.isIntersecting));
        this._focusableObserver
            .observe(this._elementRef, false)
            .pipe(takeUntilDestroyed())
            .subscribe((isFocusable) => {
            if (!isFocusable && isFocusable !== this.focusable) {
                this.focusable = isFocusable;
            }
        });
    }
    /** @hidden */
    _onKeydown(event) {
        // Already handled
        if (event.defaultPrevented) {
            return;
        }
        const isFocused = this._document.activeElement === this._elementRef.nativeElement;
        const shouldFocusChild = KeyUtil.isKeyCode(event, [ENTER, MAC_ENTER, F2]) && !event.shiftKey && isFocused;
        const shouldFocusList = ((KeyUtil.isKeyCode(event, F2) && event.shiftKey) || KeyUtil.isKeyCode(event, ESCAPE)) && !isFocused;
        if (shouldFocusChild) {
            event.stopPropagation();
            this.setActiveItem(0);
            return;
        }
        else if (shouldFocusList) {
            event.stopPropagation();
            this.focus();
            return;
        }
        this._keydown$.next({ list: this, event, activeItemIndex: this._keyManager?.activeItemIndex ?? null });
    }
    /** @hidden */
    async _onFocus() {
        if (this._gridPosition) {
            this._gridListFocused$.next(this._gridPosition);
            this._liveAnnouncer.clear();
            await this._liveAnnouncer.announce(this.listFocusedEventAnnouncer(this._gridPosition));
            this.setTabbable(true);
        }
    }
    /** @hidden */
    ngOnChanges(changes) {
        if (!this._keyManager) {
            return;
        }
        if (changes['wrap']) {
            this._keyManager = this._keyManager.withWrap(changes['wrap'].currentValue);
        }
        if (changes['navigationDirection']) {
            this._updateNavigationDirection();
        }
    }
    /** @hidden */
    ngAfterViewInit() {
        this._listenOnItems();
    }
    /** Set items programmatically. */
    setItems(items) {
        this._items = items;
        this._listenOnItems();
    }
    /** @hidden */
    ngOnDestroy() {
        this._keyManager?.destroy();
    }
    /** Set active item in list */
    setActiveItem(index, scrollPosition) {
        let availableIndex;
        this._focusableItems.find((item, itemIndex) => {
            if (itemIndex >= index && isItemFocusable(item)) {
                availableIndex = itemIndex;
                return true;
            }
            return false;
        });
        if (availableIndex != null) {
            scrollIntoView(getItemElement(this._focusableItems.get(availableIndex)), scrollPosition);
            this._keyManager?.setActiveItem(availableIndex);
        }
    }
    /** Focus whole list */
    focus(scrollPosition) {
        if (this.focusable) {
            scrollIntoView(this._elementRef.nativeElement, scrollPosition);
            this._elementRef.nativeElement.focus();
        }
    }
    /** Set tabbable state */
    setTabbable(state) {
        this._tabbable = state;
    }
    /** @hidden */
    _updateNavigationDirection() {
        if (!this._keyManager) {
            return;
        }
        if (this.navigationDirection === 'vertical') {
            this._keyManager = this._keyManager.withVerticalOrientation(true);
            this._keyManager = this._keyManager.withHorizontalOrientation(null);
        }
        else {
            this._keyManager = this._keyManager.withVerticalOrientation(false);
            this._keyManager = this._keyManager.withHorizontalOrientation(this.contentDirection || 'ltr');
        }
    }
    /** @hidden */
    _setItemsTabbable(state) {
        this._focusableItems.forEach((item) => item.setTabbable(state));
    }
    /** @hidden */
    _setGridPosition(position) {
        this._gridPosition = position;
        this._focusableItems.changes
            .pipe(startWith(this._focusableItems), takeUntilDestroyed(this._destroyRef))
            .subscribe((items) => items.forEach((item, index) => (item._position = {
            ...this._gridPosition,
            colIndex: index,
            totalCols: this._focusableItems.length
        })));
    }
    /** @hidden */
    _initializeFocusManager(items, config = {}) {
        this._refreshItems$.next();
        let keyManager = new FocusKeyManager(items).withHomeAndEnd();
        if (config.wrap !== false) {
            keyManager = keyManager.withWrap();
        }
        if (config.direction === 'horizontal') {
            keyManager = keyManager.withHorizontalOrientation(config.contentDirection || 'ltr'); // should be replaced
            // Vertical is enabled by default, so let's disable it here in consistency purposes
            keyManager = keyManager.withVerticalOrientation(false);
        }
        keyManager.skipPredicate((i) => !isItemFocusable(i));
        this._keyManager = keyManager;
        const focusListenerDestroyers = items.map((item, index) => this._renderer.listen(getItemElement(item), 'focus', () => {
            const directiveItem = this._focusableItems.get(index);
            if (!directiveItem) {
                return;
            }
            if (this._gridPosition) {
                // eslint-disable-next-line @typescript-eslint/no-non-null-assertion
                this._gridItemFocused$.next(directiveItem._position);
            }
            this.itemFocused.next({ index, total: items.length });
            this._focusableItems.forEach((i) => i.setTabbable(i === directiveItem));
            this._keyManager?.setActiveItem(index);
        }));
        merge(...items.map((item) => item.keydown))
            .pipe(tap((event) => {
            // Already handled
            if (event.defaultPrevented) {
                return;
            }
            this._keyManager?.onKeydown(event);
        }), takeUntil(merge(this._refreshItems$, destroyObservable(this._destroyRef))), finalize(() => focusListenerDestroyers.forEach((d) => d())))
            .subscribe();
    }
    /** @hidden */
    _defaultListFocusedEventAnnouncer(position) {
        return `Row: ${position.rowIndex + 1} of ${position.totalRows}, use F2 button to dive in and focus list's item`;
    }
    /** @hidden */
    _listenOnItems() {
        const refresh$ = merge(this._refresh$, destroyObservable(this._destroyRef));
        this._refresh$.next();
        this._focusableItems.changes
            .pipe(startWith(null), map(() => this._focusableItems.toArray()), tap((items) => {
            const direction = this.navigationDirection === 'grid' ? 'horizontal' : this.navigationDirection;
            this._initializeFocusManager(items, {
                direction,
                contentDirection: this.contentDirection,
                wrap: !!this.wrap
            });
        }), takeUntil(refresh$))
            .subscribe();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: FocusableListDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "16.1.0", version: "19.2.3", type: FocusableListDirective, isStandalone: true, selector: "[fdkFocusableList]", inputs: { focusable: ["focusable", "focusable", booleanAttribute], navigationDirection: "navigationDirection", contentDirection: "contentDirection", wrap: ["wrap", "wrap", booleanAttribute], listFocusedEventAnnouncer: "listFocusedEventAnnouncer" }, outputs: { itemFocused: "itemFocused" }, host: { listeners: { "keydown": "_onKeydown($event)", "focus": "_onFocus()" }, properties: { "attr.tabindex": "this._tabindex" } }, providers: [
            {
                provide: FDK_FOCUSABLE_LIST_DIRECTIVE,
                useExisting: FocusableListDirective
            }
        ], queries: [{ propertyName: "_projectedFocusableItems", predicate: FDK_FOCUSABLE_ITEM_DIRECTIVE, descendants: true }], exportAs: ["fdkFocusableList"], usesOnChanges: true, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: FocusableListDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[fdkFocusableList]',
                    exportAs: 'fdkFocusableList',
                    standalone: true,
                    providers: [
                        {
                            provide: FDK_FOCUSABLE_LIST_DIRECTIVE,
                            useExisting: FocusableListDirective
                        }
                    ]
                }]
        }], ctorParameters: () => [], propDecorators: { focusable: [{
                type: Input,
                args: [{ transform: booleanAttribute }]
            }], navigationDirection: [{
                type: Input
            }], contentDirection: [{
                type: Input
            }], wrap: [{
                type: Input,
                args: [{ transform: booleanAttribute }]
            }], listFocusedEventAnnouncer: [{
                type: Input
            }], itemFocused: [{
                type: Output
            }], _projectedFocusableItems: [{
                type: ContentChildren,
                args: [FDK_FOCUSABLE_ITEM_DIRECTIVE, { descendants: true }]
            }], _tabindex: [{
                type: HostBinding,
                args: ['attr.tabindex']
            }], _onKeydown: [{
                type: HostListener,
                args: ['keydown', ['$event']]
            }], _onFocus: [{
                type: HostListener,
                args: ['focus']
            }] } });

class FocusableListModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: FocusableListModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "19.2.3", ngImport: i0, type: FocusableListModule, imports: [FocusableItemDirective, FocusableListDirective], exports: [FocusableItemDirective, FocusableListDirective] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: FocusableListModule }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: FocusableListModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [FocusableItemDirective, FocusableListDirective],
                    exports: [FocusableItemDirective, FocusableListDirective]
                }]
        }] });

const FDK_FOCUSABLE_GRID_DIRECTIVE = new InjectionToken('Focusable grid directive token');

class FocusableGridDirective {
    constructor() {
        /** Direction of the content. */
        this.contentDirection = 'ltr';
        /** Whether the item in the previous/next row should be selected when going out of the first/last cell in the row. Default is false. */
        this.wrapHorizontally = false;
        /** Specify which item to select in prev/next row if its length smaller than current index. Nullish value means do not select. Default is null. */
        this.shortRowFocus = null;
        /** Event emitted when item focused, contains item's position info. */
        this.itemFocused = new EventEmitter();
        /** Event emitted when whole row focused, contains row's position info. */
        this.rowFocused = new EventEmitter();
        /** @hidden */
        this._destroyRef = inject(DestroyRef);
    }
    /** @hidden */
    ngAfterViewInit() {
        this._focusableLists.changes
            .pipe(startWith$1(this._focusableLists), takeUntilDestroyed(this._destroyRef))
            .subscribe((lists) => lists.forEach((list, index) => list._setGridPosition({ rowIndex: index, totalRows: this._focusableLists.length })));
        this._focusableLists.changes
            .pipe(startWith$1(this._focusableLists), switchMap((queryList) => merge(...queryList.toArray().map((list) => list._gridListFocused$))), takeUntilDestroyed(this._destroyRef))
            .subscribe((focusedEvent) => {
            this.rowFocused.emit(focusedEvent);
            this._focusableLists.forEach((list) => list.setTabbable(false));
            this._focusableLists.forEach((list) => list._setItemsTabbable(false));
        });
        this._focusableLists.changes
            .pipe(startWith$1(this._focusableLists), switchMap((queryList) => merge(...queryList.toArray().map((list) => list._gridItemFocused$))), takeUntilDestroyed(this._destroyRef))
            .subscribe((focusedEvent) => {
            this.itemFocused.emit(focusedEvent);
            this._focusableLists.forEach((list) => list.setTabbable(false));
            this._focusableLists.forEach((list) => list._setItemsTabbable(false));
        });
        this._focusableLists.changes
            .pipe(startWith$1(this._focusableLists), switchMap((queryList) => merge(...queryList.toArray().map((list) => list._keydown$))), takeUntilDestroyed(this._destroyRef))
            .subscribe(({ event, list, activeItemIndex }) => this._onKeydown(event, list, activeItemIndex));
    }
    /**
     * Focus cell by position.
     * @param position position of the cell
     */
    focusCell(position) {
        const list = this._focusableLists.get(position.rowIndex);
        if (list) {
            list.setActiveItem(position.colIndex);
        }
    }
    /** @hidden */
    _onKeydown(event, list, activeItemIndex) {
        if (!KeyUtil.isKeyCode(event, [UP_ARROW, DOWN_ARROW, LEFT_ARROW, RIGHT_ARROW, PAGE_DOWN, PAGE_UP])) {
            return;
        }
        const lists = this._focusableLists.toArray();
        const currentRowIndex = lists.findIndex((item) => item === list);
        let nextRowIndex;
        let nextRowItemIndex = activeItemIndex ?? 0;
        let scrollIntoView;
        const isFirstItemLtr = activeItemIndex === 0 && this.contentDirection !== 'rtl';
        const isLastItemRtl = activeItemIndex === list._focusableItems.length - 1 && this.contentDirection === 'rtl';
        const isFirstItemRtl = activeItemIndex === 0 && this.contentDirection === 'rtl';
        const isLastItemLtr = activeItemIndex === list._focusableItems.length - 1 && this.contentDirection !== 'rtl';
        switch (event.keyCode) {
            case UP_ARROW:
                event.preventDefault();
                nextRowIndex = currentRowIndex - 1;
                break;
            case DOWN_ARROW:
                event.preventDefault();
                nextRowIndex = currentRowIndex + 1;
                break;
            case LEFT_ARROW:
                if (this.wrapHorizontally && (isFirstItemLtr || isLastItemRtl)) {
                    event.preventDefault();
                    nextRowIndex = currentRowIndex - 1;
                    nextRowItemIndex = lists[nextRowIndex]?._focusableItems.length - 1;
                }
                break;
            case RIGHT_ARROW:
                if (this.wrapHorizontally && (isFirstItemRtl || isLastItemLtr)) {
                    event.preventDefault();
                    nextRowIndex = currentRowIndex + 1;
                    nextRowItemIndex = 0;
                }
                break;
            case PAGE_DOWN:
                event.preventDefault();
                nextRowIndex = findLastIndex(lists, (item) => item._isVisible);
                scrollIntoView = 'top';
                break;
            case PAGE_UP:
                event.preventDefault();
                nextRowIndex = lists.findIndex((item) => item._isVisible);
                scrollIntoView = 'bottom';
                break;
        }
        const nextRow = lists[nextRowIndex ?? -1];
        if (nextRow) {
            if (nextRow.focusable) {
                nextRow.focus(scrollIntoView);
                return;
            }
            const itemIndex = this._getItemIndex(nextRow, nextRowItemIndex);
            if (itemIndex != null) {
                nextRow.setActiveItem(itemIndex, scrollIntoView);
            }
        }
    }
    /** @hidden */
    _getItemIndex(list, activeIndex) {
        if (activeIndex >= 0 && activeIndex < list._focusableItems.length) {
            return activeIndex;
        }
        if (this.shortRowFocus == null) {
            return null;
        }
        return this.shortRowFocus === 'first' ? 0 : list._focusableItems.length - 1;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: FocusableGridDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "16.1.0", version: "19.2.3", type: FocusableGridDirective, isStandalone: true, selector: "[fdkFocusableGrid]", inputs: { contentDirection: "contentDirection", wrapHorizontally: ["wrapHorizontally", "wrapHorizontally", booleanAttribute], shortRowFocus: "shortRowFocus" }, outputs: { itemFocused: "itemFocused", rowFocused: "rowFocused" }, providers: [
            {
                provide: FDK_FOCUSABLE_GRID_DIRECTIVE,
                useExisting: FocusableGridDirective
            }
        ], queries: [{ propertyName: "_focusableLists", predicate: FDK_FOCUSABLE_LIST_DIRECTIVE, descendants: true }], exportAs: ["fdkFocusableGrid"], ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: FocusableGridDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[fdkFocusableGrid]',
                    exportAs: 'fdkFocusableGrid',
                    standalone: true,
                    providers: [
                        {
                            provide: FDK_FOCUSABLE_GRID_DIRECTIVE,
                            useExisting: FocusableGridDirective
                        }
                    ]
                }]
        }], propDecorators: { contentDirection: [{
                type: Input
            }], wrapHorizontally: [{
                type: Input,
                args: [{ transform: booleanAttribute }]
            }], shortRowFocus: [{
                type: Input
            }], itemFocused: [{
                type: Output
            }], rowFocused: [{
                type: Output
            }], _focusableLists: [{
                type: ContentChildren,
                args: [FDK_FOCUSABLE_LIST_DIRECTIVE, { descendants: true }]
            }] } });

class FocusableGridModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: FocusableGridModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "19.2.3", ngImport: i0, type: FocusableGridModule, imports: [FocusableListModule, FocusableGridDirective], exports: [FocusableListModule, FocusableGridDirective] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: FocusableGridModule, imports: [FocusableListModule, FocusableListModule] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: FocusableGridModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [FocusableListModule, FocusableGridDirective],
                    exports: [FocusableListModule, FocusableGridDirective]
                }]
        }] });

const IgnoreClickOnSelectionDirectiveToken = new InjectionToken('Ignore click on selection directive');

/**
 * Directive will stop propagation and prevent default of click, if selected area is coming from
 * directive's host element. This gives ability to not cancel all clicks on element, just the ones
 * which include selection
 */
class IgnoreClickOnSelectionDirective {
    /** @hidden */
    constructor(document, _elementRef) {
        this.document = document;
        this._elementRef = _elementRef;
    }
    /** Host click listener. Checks for selection existence and if finds one, checks anchor */
    clicked($event) {
        const selection = this.document.getSelection();
        if (selection?.toString()) {
            if (selection.anchorNode &&
                (this._elementRef.nativeElement.isSameNode(selection.anchorNode) ||
                    this._elementRef.nativeElement.isSameNode(selection.anchorNode.parentElement))) {
                $event.stopPropagation();
                $event.preventDefault();
            }
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: IgnoreClickOnSelectionDirective, deps: [{ token: DOCUMENT }, { token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "19.2.3", type: IgnoreClickOnSelectionDirective, isStandalone: true, selector: "[fdkIgnoreClickOnSelection]", host: { listeners: { "click": "clicked($event)" } }, providers: [
            {
                provide: IgnoreClickOnSelectionDirectiveToken,
                useExisting: IgnoreClickOnSelectionDirective
            }
        ], ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: IgnoreClickOnSelectionDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[fdkIgnoreClickOnSelection]',
                    standalone: true,
                    providers: [
                        {
                            provide: IgnoreClickOnSelectionDirectiveToken,
                            useExisting: IgnoreClickOnSelectionDirective
                        }
                    ]
                }]
        }], ctorParameters: () => [{ type: Document, decorators: [{
                    type: Inject,
                    args: [DOCUMENT]
                }] }, { type: i0.ElementRef }], propDecorators: { clicked: [{
                type: HostListener,
                args: ['click', ['$event']]
            }] } });

class IgnoreClickOnSelectionModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: IgnoreClickOnSelectionModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "19.2.3", ngImport: i0, type: IgnoreClickOnSelectionModule, imports: [IgnoreClickOnSelectionDirective], exports: [IgnoreClickOnSelectionDirective] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: IgnoreClickOnSelectionModule }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: IgnoreClickOnSelectionModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [IgnoreClickOnSelectionDirective],
                    exports: [IgnoreClickOnSelectionDirective]
                }]
        }] });

class InitialFocusDirective {
    /**
     * Whether initial focus enabled for a current element.
     */
    set enabled(value) {
        if (value === this.enabled) {
            return;
        }
        this._enabled$.next(value);
    }
    get enabled() {
        return this._enabled$.getValue();
    }
    /** @hidden */
    constructor(_elmRef, _ngZone, _tabbableService) {
        this._elmRef = _elmRef;
        this._ngZone = _ngZone;
        this._tabbableService = _tabbableService;
        /**
         * CSS selector of an element that should be focused.
         */
        this.fdkInitialFocus = '.fd-initial-focus-item';
        /**
         * Whether to focus last element in a found array of elements.
         */
        this.focusLastElement = false;
        /** @hidden */
        this._destroyRef = inject(DestroyRef);
        /** @hidden */
        this._enabled$ = new BehaviorSubject(true);
    }
    /** @hidden */
    ngAfterViewInit() {
        this._enabled$
            .pipe(distinctUntilChanged(), filter((enabled) => enabled), takeUntilDestroyed(this._destroyRef))
            .subscribe(() => {
            this._executeOnEmpty(() => this._focus());
        });
    }
    /**
     * @hidden
     * Executes a function when the zone is stable.
     */
    _executeOnEmpty(fn) {
        if (!this._ngZone.hasPendingMicrotasks) {
            fn();
        }
        else {
            this._ngZone.onMicrotaskEmpty.pipe(take(1)).subscribe(fn);
        }
    }
    /**
     * @hidden
     * Searches for an appropriate focusable element
     */
    _getFocusableElement() {
        if (!this.fdkInitialFocus) {
            return this._tabbableService.getTabbableElement(this._elmRef.nativeElement, this.focusLastElement);
        }
        const autoFocusableItems = this._elmRef.nativeElement.querySelectorAll(this.fdkInitialFocus);
        if (autoFocusableItems.length > 0) {
            return !this.focusLastElement ? autoFocusableItems[0] : autoFocusableItems[autoFocusableItems.length - 1];
        }
        // If no elements found, fallback to a first tabbable element.
        return this._tabbableService.getTabbableElement(this._elmRef.nativeElement, this.focusLastElement);
    }
    /** @hidden */
    _focus() {
        if (!this.enabled) {
            return;
        }
        const elm = this._getFocusableElement();
        elm?.focus();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: InitialFocusDirective, deps: [{ token: i0.ElementRef }, { token: i0.NgZone }, { token: TabbableElementService }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "19.2.3", type: InitialFocusDirective, isStandalone: true, selector: "[fdkInitialFocus]", inputs: { fdkInitialFocus: "fdkInitialFocus", enabled: "enabled", focusLastElement: "focusLastElement" }, providers: [TabbableElementService], ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: InitialFocusDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[fdkInitialFocus]',
                    standalone: true,
                    providers: [TabbableElementService]
                }]
        }], ctorParameters: () => [{ type: i0.ElementRef }, { type: i0.NgZone }, { type: TabbableElementService }], propDecorators: { fdkInitialFocus: [{
                type: Input
            }], enabled: [{
                type: Input
            }], focusLastElement: [{
                type: Input
            }] } });

class InitialFocusModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: InitialFocusModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "19.2.3", ngImport: i0, type: InitialFocusModule, imports: [InitialFocusDirective], exports: [InitialFocusDirective] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: InitialFocusModule }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: InitialFocusModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [InitialFocusDirective],
                    exports: [InitialFocusDirective]
                }]
        }] });

class IntersectionSpyDirective {
    constructor() {
        /** Intersection offset in px. */
        this.offset = 20;
        /** Event emitted when intersection observer emits with the current element. */
        this.intersected = new EventEmitter();
        /** @hidden */
        this._destroyRef = inject(DestroyRef);
        /** @hidden */
        this._elementRef = inject(ElementRef);
    }
    /** @hidden */
    ngOnInit() {
        intersectionObservable(this._elementRef.nativeElement, this.viewportOptions)
            .pipe(map$1((entries) => entries[0]), takeUntilDestroyed(this._destroyRef))
            .subscribe((entry) => {
            this.intersected.emit(entry.isIntersecting);
        });
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: IntersectionSpyDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "19.2.3", type: IntersectionSpyDirective, isStandalone: true, selector: "[fdkIntersectionSpy]", inputs: { offset: ["fdkIntersectionSpy", "offset"], viewportOptions: "viewportOptions" }, outputs: { intersected: "intersected" }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: IntersectionSpyDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[fdkIntersectionSpy]',
                    standalone: true
                }]
        }], propDecorators: { offset: [{
                type: Input,
                args: ['fdkIntersectionSpy']
            }], viewportOptions: [{
                type: Input
            }], intersected: [{
                type: Output
            }] } });

class LineClampTargetDirective {
    /** @hidden */
    constructor(_elementRef) {
        this._elementRef = _elementRef;
        /**
         * Event with target instance for clamping
         */
        this.update = new EventEmitter();
    }
    /**
     * Native element of clamping target
     */
    get targetElement() {
        return this._elementRef.nativeElement;
    }
    /** @hidden */
    ngOnChanges() {
        this.update.emit(this);
    }
    /** @hidden */
    ngAfterViewInit() {
        this.update.emit(this);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: LineClampTargetDirective, deps: [{ token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "19.2.3", type: LineClampTargetDirective, isStandalone: true, selector: "[fdkLineClampTarget], [fdLineClampTarget], [fd-lineclamp-target]", inputs: { fdLineClampTargetText: "fdLineClampTargetText" }, outputs: { update: "update" }, exportAs: ["fdLineClampTarget"], usesOnChanges: true, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: LineClampTargetDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[fdkLineClampTarget], [fdLineClampTarget], [fd-lineclamp-target]',
                    exportAs: 'fdLineClampTarget',
                    standalone: true
                }]
        }], ctorParameters: () => [{ type: i0.ElementRef }], propDecorators: { fdLineClampTargetText: [{
                type: Input
            }], update: [{
                type: Output
            }] } });
class LineClampDirective {
    /**
     * Count lines for clamping
     */
    set fdLineClampLines(value) {
        this._lineCount = coerceNumberProperty(value);
    }
    /** @hidden */
    /**
     * Root native element of clamping box
     */
    get rootElement() {
        return this._elementRef.nativeElement;
    }
    /** @hidden */
    constructor(_elementRef, _renderer) {
        this._elementRef = _elementRef;
        this._renderer = _renderer;
        /**
         * Clamping state
         */
        this.fdLineclampState = false;
        /**
         * Event return count of lines from the target
         */
        this.lineCountUpdate = new EventEmitter();
        /** @hidden */
        this._isNativeSupport = true;
        /** @hidden */
        this.viewportSize$ = inject(ViewportSizeObservable);
        /** @hidden */
        this._destroyRef = inject(DestroyRef);
    }
    /** @hidden */
    ngAfterViewInit() {
        this._isNativeSupport = typeof this.rootElement.style.webkitLineClamp !== 'undefined';
        // need to use setTimeout to force recheck of parent elements
        setTimeout(() => {
            this._checkLineCount();
        });
        this.viewportSize$
            .pipe(distinctUntilChanged(), debounceTime$1(200), takeUntilDestroyed(this._destroyRef))
            .subscribe({
            next: () => this._checkLineCount()
        });
    }
    /** @hidden */
    ngOnChanges() {
        this.reset();
        this.refreshClamp();
    }
    /** @hidden */
    reset() {
        if (this._lineClampTarget) {
            this._lineClampTarget.textContent = this._originalText;
        }
        if (this._isNativeSupport) {
            this._resetNative();
        }
    }
    /** @hidden */
    refreshTarget(event) {
        this._lineClampTarget = event.targetElement;
        this._originalText = event.fdLineClampTargetText;
        this._checkLineCount();
    }
    /** @hidden */
    refreshClamp() {
        if (this.fdLineclampState && this._lineCount) {
            this.native();
            if (!this._isNativeSupport) {
                this._truncate();
            }
        }
    }
    /** @hidden
     * Truncate text in the target box, if browser not support lineclamp style
     */
    _truncate() {
        if (!this._lineClampTarget) {
            return;
        }
        const lineClampHeight = Math.ceil(this.getLineHeight() * this._lineCount);
        const ellipsisTextArray = this._originalText.split(' ');
        const ellipsisText = () => {
            if (this.rootElement.scrollHeight > lineClampHeight) {
                ellipsisTextArray.pop();
                this._lineClampTarget.textContent = ellipsisTextArray.join(' ') + '...';
                ellipsisText.call(this);
            }
        };
        ellipsisText();
    }
    /** @hidden
     * Get lineheight for rootelement, if browser not support lineclamp style
     */
    getLineHeight() {
        const lineHeight = window.getComputedStyle(this.rootElement, null).getPropertyValue('line-height');
        if (lineHeight === 'normal') {
            return parseInt(window.getComputedStyle(this.rootElement, null).getPropertyValue('font-size'), 10) * 1.25;
        }
        return parseFloat(lineHeight);
    }
    /** @hidden
     * Setup native styles for lineclamp text
     */
    native() {
        if (this._isNativeSupport) {
            this._renderer.setStyle(this.rootElement, 'display', '-webkit-box');
            this._renderer.setStyle(this.rootElement, 'overflow', 'hidden');
            this._renderer.setStyle(this.rootElement, 'text-overflow', 'ellipsis');
            this._renderer.setStyle(this.rootElement, '-webkit-box-orient', 'vertical');
            this._renderer.setStyle(this.rootElement, '-webkit-line-clamp', `${this._lineCount}`);
        }
    }
    /** @hidden
     * Reset native styles for lineclamp text
     */
    _resetNative() {
        if (this._isNativeSupport) {
            this._renderer.setStyle(this.rootElement, 'display', '');
            this._renderer.setStyle(this.rootElement, 'overflow', '');
            this._renderer.setStyle(this.rootElement, 'text-overflow', '');
            this._renderer.setStyle(this.rootElement, '-webkit-box-orient', '');
            this._renderer.setStyle(this.rootElement, '-webkit-line-clamp', '');
        }
    }
    /** @hidden */
    _checkLineCount() {
        if (!this.rootElement) {
            return;
        }
        const style = window.getComputedStyle(this.rootElement, null);
        this.reset();
        const fontSize = parseInt(style.getPropertyValue('font-size'), 10);
        const boxSizing = style.getPropertyValue('box-sizing');
        let height = parseInt(style.getPropertyValue('height'), 10);
        let lineHeight = parseFloat(style.getPropertyValue('line-height'));
        if (isNaN(lineHeight)) {
            lineHeight = fontSize * 1.2;
        }
        if (boxSizing === 'border-box') {
            const padding_top = parseInt(style.getPropertyValue('padding-top'), 10);
            const padding_bottom = parseInt(style.getPropertyValue('padding-bottom'), 10);
            const border_top = parseInt(style.getPropertyValue('border-top-width'), 10);
            const border_bottom = parseInt(style.getPropertyValue('border-bottom-width'), 10);
            height = height - padding_top - padding_bottom - border_top - border_bottom;
        }
        this.refreshClamp();
        this.lineCountUpdate.emit(Math.ceil(height / lineHeight));
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: LineClampDirective, deps: [{ token: i0.ElementRef }, { token: i0.Renderer2 }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "19.2.3", type: LineClampDirective, isStandalone: true, selector: "[fdkLineClamp]", inputs: { fdLineClampLines: "fdLineClampLines", fdLineclampState: "fdLineclampState" }, outputs: { lineCountUpdate: "lineCountUpdate" }, exportAs: ["fdLineClamp"], usesOnChanges: true, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: LineClampDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[fdkLineClamp]',
                    exportAs: 'fdLineClamp',
                    standalone: true
                }]
        }], ctorParameters: () => [{ type: i0.ElementRef }, { type: i0.Renderer2 }], propDecorators: { fdLineClampLines: [{
                type: Input
            }], fdLineclampState: [{
                type: Input
            }], lineCountUpdate: [{
                type: Output
            }] } });

class LineClampModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: LineClampModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "19.2.3", ngImport: i0, type: LineClampModule, imports: [LineClampTargetDirective, LineClampDirective], exports: [LineClampTargetDirective, LineClampDirective] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: LineClampModule }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: LineClampModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [LineClampTargetDirective, LineClampDirective],
                    exports: [LineClampTargetDirective, LineClampDirective]
                }]
        }] });

class OnlyDigitsDirective {
    /** @hidden */
    constructor(_el) {
        this._el = _el;
        /** Allow using decimal */
        this.decimal = false;
        /** Define decimal separator
         * Default: .(dot)
         */
        this.decimalSeparator = '.';
        /** @hidden */
        this._hasDecimalPoint = false;
        this._inputElement = this._el.nativeElement;
    }
    /** @hidden */
    onKeyDown(e) {
        if (
        // Allow: Delete, Backspace, Tab, Escape, Enter, End, Home, Arrow Left, Arrow Right, Arrow Up, Arrow Down
        KeyUtil.isKeyCode(e, [
            DELETE,
            BACKSPACE,
            TAB,
            ESCAPE,
            ENTER,
            END,
            HOME,
            LEFT_ARROW,
            RIGHT_ARROW,
            UP_ARROW,
            DOWN_ARROW
        ]) ||
            // Allow: Ctrl+(A/C/V/X) and Cmd+(A/C/V/X) (Mac)
            (KeyUtil.isKeyCode(e, [A, C, V, X]) && (e.ctrlKey || e.metaKey))) {
            return; // let it happen, don't do anything
        }
        if (KeyUtil.isKeyCode(e, [DASH, NUMPAD_MINUS])) {
            const newValue = this._forecastValue(e.key);
            if (this._inputElement.value[0] === '-' || newValue[0] !== '-') {
                e.preventDefault();
                return; // has DASH point
            }
            else {
                return; // Allow: only one DASH point
            }
        }
        if (this.decimal && e.key === this.decimalSeparator) {
            const newValue = this._forecastValue(e.key);
            if (newValue.split(this.decimalSeparator).length > 2) {
                // has two or more decimal points
                e.preventDefault();
                return;
            }
            else {
                this._hasDecimalPoint = newValue.indexOf(this.decimalSeparator) > -1;
                return; // Allow: only one decimal point
            }
        }
        // Ensure that it is a number and stop the keypress
        if (e.key === ' ' || isNaN(Number(e.key))) {
            e.preventDefault();
            return;
        }
    }
    /** @hidden */
    onPaste(event) {
        if (window['clipboardData']) {
            // Browser is IE
            this._pasteData(window['clipboardData'].getData('text'));
        }
        else if (event.clipboardData && event.clipboardData.getData) {
            // Other browsers
            this._pasteData(event.clipboardData.getData('text/plain'));
        }
        event.preventDefault();
    }
    /** @hidden */
    onDrop(event) {
        const textData = event.dataTransfer?.getData('text') ?? '';
        this._inputElement.focus();
        this._pasteData(textData);
        event.preventDefault();
    }
    /** @hidden */
    _pasteData(pastedContent) {
        const sanitizedContent = this._sanitizeInput(pastedContent);
        const pasted = document.execCommand('insertText', false, sanitizedContent);
        if (!pasted) {
            if (this._inputElement.setRangeText) {
                const { selectionStart: start, selectionEnd: end } = this._inputElement;
                this._inputElement.setRangeText(sanitizedContent, start ?? 0, end ?? 0, 'end');
                // Angular's Reactive Form relies on "input" event, but on Firefox, the setRangeText method doesn't trigger it
                // so we have to trigger it ourself.
                if (typeof window['InstallTrigger'] !== 'undefined') {
                    this._inputElement.dispatchEvent(new Event('input', { cancelable: true }));
                }
            }
            else {
                // Browser does not support setRangeText, e.g. IE
                this._insertAtCursor(this._inputElement, sanitizedContent);
            }
        }
        if (this.decimal) {
            this._hasDecimalPoint = this._inputElement.value.indexOf(this.decimalSeparator) > -1;
        }
    }
    // The following 2 methods were added from the below article for browsers that do not support setRangeText
    // https://stackoverflow.com/questions/11076975/how-to-insert-text-into-the-textarea-at-the-current-cursor-position
    /** @hidden */
    _insertAtCursor(myField, myValue) {
        const startPos = myField.selectionStart ?? 0;
        const endPos = myField.selectionEnd ?? 0;
        myField.value =
            myField.value.substring(0, startPos) + myValue + myField.value.substring(endPos, myField.value.length);
        const pos = startPos + myValue.length;
        myField.focus();
        myField.setSelectionRange(pos, pos);
        this._triggerEvent(myField, 'input');
    }
    /** @hidden */
    _triggerEvent(el, type) {
        if ('createEvent' in document) {
            // modern browsers, IE9+
            const e = document.createEvent('HTMLEvents');
            e.initEvent(type, false, true);
            el.dispatchEvent(e);
        }
    }
    // end stack overflow code
    /** @hidden */
    _sanitizeInput(input) {
        let result = '';
        if (this.decimal && this._isValidDecimal(input)) {
            const regex = new RegExp(`[^0-9${this.decimalSeparator}]`, 'g');
            result = input.replace(regex, '');
        }
        else {
            result = input.replace(/[^0-9]/g, '');
        }
        if (input[0] === '-') {
            result = `-${result}`;
        }
        const maxLength = this._inputElement.maxLength;
        if (maxLength > 0) {
            // the input element has maxLength limit
            const allowedLength = maxLength - this._inputElement.value.length;
            result = allowedLength > 0 ? result.substring(0, allowedLength) : '';
        }
        return result;
    }
    /** @hidden */
    _isValidDecimal(string) {
        if (!this._hasDecimalPoint) {
            return string.split(this.decimalSeparator).length <= 2;
        }
        else {
            // the input element already has a decimal separator
            const selectedText = this._getSelection;
            if (selectedText && selectedText.indexOf(this.decimalSeparator) > -1) {
                return string.split(this.decimalSeparator).length <= 2;
            }
            else {
                return string.indexOf(this.decimalSeparator) < 0;
            }
        }
    }
    /** @hidden */
    get _getSelection() {
        const { selectionStart, selectionEnd } = this._inputElement;
        return this._inputElement.value.substring(selectionStart ?? 0, selectionEnd ?? 0);
    }
    /** @hidden */
    _forecastValue(key) {
        const { selectionStart, selectionEnd, value: oldValue } = this._inputElement;
        const selection = oldValue.substring(selectionStart ?? 0, selectionEnd ?? 0);
        return selection
            ? oldValue.replace(selection, key)
            : oldValue.substring(0, selectionStart ?? 0) + key + oldValue.substring(selectionStart ?? 0);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: OnlyDigitsDirective, deps: [{ token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "19.2.3", type: OnlyDigitsDirective, isStandalone: true, selector: "[fdkOnlyDigits]", inputs: { decimal: "decimal", decimalSeparator: "decimalSeparator" }, host: { listeners: { "keydown": "onKeyDown($event)", "paste": "onPaste($event)", "drop": "onDrop($event)" } }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: OnlyDigitsDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[fdkOnlyDigits]',
                    standalone: true
                }]
        }], ctorParameters: () => [{ type: i0.ElementRef }], propDecorators: { decimal: [{
                type: Input
            }], decimalSeparator: [{
                type: Input
            }], onKeyDown: [{
                type: HostListener,
                args: ['keydown', ['$event']]
            }], onPaste: [{
                type: HostListener,
                args: ['paste', ['$event']]
            }], onDrop: [{
                type: HostListener,
                args: ['drop', ['$event']]
            }] } });

class OnlyDigitsModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: OnlyDigitsModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "19.2.3", ngImport: i0, type: OnlyDigitsModule, imports: [OnlyDigitsDirective], exports: [OnlyDigitsDirective] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: OnlyDigitsModule }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: OnlyDigitsModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [OnlyDigitsDirective],
                    exports: [OnlyDigitsDirective]
                }]
        }] });

class OverflowListItemDirective {
    /** @hidden */
    constructor(el) {
        this.el = el;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: OverflowListItemDirective, deps: [{ token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "19.2.3", type: OverflowListItemDirective, isStandalone: true, selector: "[fdkOverflowListItem]", ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: OverflowListItemDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[fdkOverflowListItem]',
                    standalone: true
                }]
        }], ctorParameters: () => [{ type: i0.ElementRef }] });

class OverflowListDirective {
    /** @hidden */
    constructor(_el, _ngZone) {
        this._el = _el;
        this._ngZone = _ngZone;
        /**
         * @description Offset to calculate correct position
         */
        this.overflowOffset = 0;
        /**
         * @description value of display property of existed list items
         */
        this.itemCssBlockValue = 'flex';
        /**
         * @description Emits when changed amount of extra items
         */
        this.overflowChanged = new EventEmitter();
        /** @hidden */
        this._destroyRef = inject(DestroyRef);
    }
    /** @hidden */
    ngAfterViewInit() {
        this.initResizeObserver();
        this.calculateOverflow();
        fromEvent(window, 'resize')
            .pipe(debounceTime$1(100))
            .subscribe(() => this.calculateOverflow());
    }
    /**
     * @description Get amount of extra items in current list
     * */
    getAmountOfExtraItems() {
        const elements = this.overflowItems.toArray().map((item) => item.el.nativeElement);
        const computed = getComputedStyle(this._el.nativeElement);
        const contentWidth = Math.floor(this._el.nativeElement.clientWidth -
            parseFloat(computed.paddingLeft || '0') -
            parseFloat(computed.paddingRight || '0'));
        if (contentWidth <= 0) {
            return 0;
        }
        return this._checkWidthWithOffset(elements, contentWidth);
    }
    /**
     * @description Ensuring that calculations run in the Angular zone
     */
    calculateOverflow() {
        this._ngZone.run(() => {
            setTimeout(() => {
                const elements = this.overflowItems.map((item) => item.el.nativeElement);
                const contentWidth = this._el.nativeElement.clientWidth;
                let totalWidth = 0;
                let overflowCount = 0;
                elements.forEach((elm) => {
                    const elmWidth = elm.offsetWidth;
                    totalWidth += elmWidth;
                    if (totalWidth > contentWidth) {
                        overflowCount++;
                    }
                });
                this._calculateAmountOfOverflowedItems();
            }, 0);
        });
    }
    initResizeObserver() {
        this.observer = new ResizeObserver(() => {
            this._ngZone.run(() => this.calculateOverflow());
        });
        this.observer.observe(this._el.nativeElement);
    }
    /** @hidden */
    _calculateAmountOfOverflowedItems() {
        const extra = this.getAmountOfExtraItems();
        this.overflowChanged.emit(extra);
    }
    /**
     * @hidden
     * @param arrItems
     * @param containerWidth
     * @param checkWithOffset
     * */
    _checkWidthWithOffset(arrItems, containerWidth, checkWithOffset = false) {
        let itemsTotalWidth = 0;
        const parentWidth = checkWithOffset ? containerWidth - this.overflowOffset : containerWidth;
        arrItems.forEach((item) => {
            item.hidden = true;
            item.style.display = this.itemCssBlockValue;
        });
        for (let i = 0; i < arrItems.length; i++) {
            const item = arrItems[i];
            itemsTotalWidth += this.isRtl
                ? containerWidth - item.offsetLeft - itemsTotalWidth
                : Math.ceil(item.offsetWidth + item.offsetLeft - itemsTotalWidth);
            if (parentWidth < itemsTotalWidth) {
                this._clearTempStyles(arrItems);
                return checkWithOffset
                    ? arrItems.length - i
                    : this._checkWidthWithOffset(arrItems, containerWidth, true);
            }
        }
        this._clearTempStyles(arrItems);
        return 0;
    }
    /**
     * @param arrItems
     * @hidden
     * */
    _clearTempStyles(arrItems) {
        arrItems.forEach((item) => {
            item.hidden = false;
            item.style.removeProperty('display');
        });
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: OverflowListDirective, deps: [{ token: i0.ElementRef }, { token: i0.NgZone }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "19.2.3", type: OverflowListDirective, isStandalone: true, selector: "[fdkOverflowList]", inputs: { overflowOffset: "overflowOffset", isRtl: "isRtl", itemCssBlockValue: "itemCssBlockValue" }, outputs: { overflowChanged: "overflowChanged" }, queries: [{ propertyName: "overflowItems", predicate: OverflowListItemDirective }], ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: OverflowListDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[fdkOverflowList]',
                    standalone: true
                }]
        }], ctorParameters: () => [{ type: i0.ElementRef }, { type: i0.NgZone }], propDecorators: { overflowOffset: [{
                type: Input
            }], isRtl: [{
                type: Input
            }], itemCssBlockValue: [{
                type: Input
            }], overflowChanged: [{
                type: Output
            }], overflowItems: [{
                type: ContentChildren,
                args: [OverflowListItemDirective]
            }] } });

class OverflowListModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: OverflowListModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "19.2.3", ngImport: i0, type: OverflowListModule, imports: [OverflowListDirective, OverflowListItemDirective], exports: [OverflowListDirective, OverflowListItemDirective] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: OverflowListModule }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: OverflowListModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [OverflowListDirective, OverflowListItemDirective],
                    exports: [OverflowListDirective, OverflowListItemDirective]
                }]
        }] });

/** @Hidden */
function setReadonlyState(element, isReadonly) {
    const htmlElement = getNativeElement(element);
    if (isReadonly) {
        htmlElement.classList.add('is-readonly');
        htmlElement.setAttribute('readonly', '');
    }
    else {
        htmlElement.classList.remove('is-readonly');
        htmlElement.removeAttribute('readonly');
    }
}

class DefaultReadonlyViewModifier {
    /** @hidden */
    constructor(elementRef) {
        this.elementRef = elementRef;
        /** @hidden */
        this.setReadonlyState = (isDisabled) => {
            setReadonlyState(this.elementRef, isDisabled);
        };
    }
}

const FDK_READONLY_DIRECTIVE = new InjectionToken('Readonly directive token');

class ReadonlyObserver {
    /** @Hidden */
    constructor(_attributeObserver) {
        this._attributeObserver = _attributeObserver;
    }
    /** @Hidden */
    static isReadonly(element) {
        return element.classList.contains('is-readonly') || element.hasAttribute('readonly');
    }
    /** @hidden */
    observe(element) {
        return this._attributeObserver.observe(element).pipe(map(() => ReadonlyObserver.isReadonly(getNativeElement(element))), distinctUntilChanged());
    }
    /** @Hidden */
    unobserve(element) {
        this._attributeObserver.unobserve(element);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: ReadonlyObserver, deps: [{ token: AttributeObserver }], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: ReadonlyObserver, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: ReadonlyObserver, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: () => [{ type: AttributeObserver }] });

class FdkReadonlyProvider extends ReplaySubject {
    /** @hidden */
    constructor(ngZone, elementRef, readonlyObserver, selfReadonly$, parentReadonly$) {
        super(1);
        this.ngZone = ngZone;
        this.elementRef = elementRef;
        this.readonlyObserver = readonlyObserver;
        this.selfReadonly$ = selfReadonly$;
        this.parentReadonly$ = parentReadonly$;
        /** @Hidden */
        this.fdkReadonly = false;
        /** @hidden */
        this._viewModifiers$ = new BehaviorSubject(this._getInitialViewModifiers());
        /** @hidden */
        this._readonlyChange$ = this._getReadonlyChange$();
        /** @hidden */
        this._destroyRef = inject(DestroyRef);
        combineLatest([this._readonlyChange$, this._viewModifiers$])
            .pipe(tap(([isReadonly]) => this.setReadonlyState(isReadonly)), takeUntilDestroyed(this._destroyRef))
            .subscribe();
        this._readonlyChange$
            .pipe(tap((isDisabled) => (this.fdkReadonly = isDisabled)), tap((isDisabled) => this.next(isDisabled)), takeUntilDestroyed(this._destroyRef))
            .subscribe();
    }
    /** @hidden */
    addViewModifier(modifier) {
        const viewModifiers = [...new Set([...this._viewModifiers$.value, modifier]).values()];
        this._viewModifiers$.next(viewModifiers);
    }
    /** @hidden */
    setReadonlyState(isReadonly) {
        firstValueFrom(this.ngZone.onStable).then(() => {
            this._viewModifiers$.value.forEach((viewModifier) => viewModifier.setReadonlyState(isReadonly));
        });
    }
    /** @hidden */
    ngOnDestroy() {
        this.complete();
        this.readonlyObserver.unobserve(this.elementRef);
    }
    /** @hidden */
    _getReadonlyChange$() {
        let selfReadonly = false;
        let parentReadonly = false;
        if (this.parentReadonly$) {
            this.parentReadonly$
                .pipe(startWith(this.parentReadonly$.fdkReadonly), tap((d) => (parentReadonly = d)), distinctUntilChanged(), tap(() => {
                if (parentReadonly) {
                    this.setReadonlyState(true);
                }
                if (!selfReadonly && !parentReadonly) {
                    this.setReadonlyState(false);
                }
            }), takeUntilDestroyed(this._destroyRef))
                .subscribe();
        }
        if (this.selfReadonly$) {
            this.selfReadonly$
                .pipe(startWith(this.selfReadonly$.fdkReadonly), tap((d) => (selfReadonly = d)), distinctUntilChanged(), tap((isReadonly) => {
                if (!parentReadonly) {
                    this.setReadonlyState(isReadonly);
                }
            }), takeUntilDestroyed(this._destroyRef))
                .subscribe();
        }
        return this.readonlyObserver.observe(this.elementRef).pipe(distinctUntilChanged());
    }
    /** @hidden */
    _getInitialViewModifiers() {
        return !this.selfReadonly$ ? [new DefaultReadonlyViewModifier(this.elementRef)] : [this.selfReadonly$];
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: FdkReadonlyProvider, deps: [{ token: i0.NgZone }, { token: i0.ElementRef }, { token: ReadonlyObserver }, { token: FDK_READONLY_DIRECTIVE, optional: true, self: true }, { token: FDK_READONLY_DIRECTIVE, optional: true, skipSelf: true }], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: FdkReadonlyProvider }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: FdkReadonlyProvider, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i0.NgZone }, { type: i0.ElementRef }, { type: ReadonlyObserver }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Self
                }, {
                    type: Inject,
                    args: [FDK_READONLY_DIRECTIVE]
                }] }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: SkipSelf
                }, {
                    type: Inject,
                    args: [FDK_READONLY_DIRECTIVE]
                }] }] });

class ReadonlyBehaviorDirective extends ReplaySubject {
    /** @Hidden */
    set fdkReadonly(value) {
        this._readonlyInput$.next(value);
    }
    get fdkReadonly() {
        return this._readonly;
    }
    /** @hidden */
    constructor(_elementRef, _destroyRef) {
        super(1);
        this._elementRef = _elementRef;
        this._destroyRef = _destroyRef;
        /** @Hidden */
        this._readonly = false;
        /** @hidden */
        this._readonlyInput$ = new BehaviorSubject(false);
        /** @Hidden */
        this.setReadonlyState = (isReadonly) => {
            setReadonlyState(this._elementRef, isReadonly);
        };
        this._destroyRef.onDestroy(() => this.complete());
    }
    /** @hidden */
    ngAfterViewInit() {
        this._readonlyInput$
            .pipe(tap((isReadonly) => {
            if (isReadonly !== this._readonly) {
                this.setReadonlyState(isReadonly);
                this._readonly = isReadonly;
                this.next(isReadonly);
            }
        }), takeUntilDestroyed(this._destroyRef))
            .subscribe();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: ReadonlyBehaviorDirective, deps: [{ token: i0.ElementRef }, { token: i0.DestroyRef }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "16.1.0", version: "19.2.3", type: ReadonlyBehaviorDirective, isStandalone: true, selector: "[fdkReadonly]", inputs: { fdkReadonly: ["fdkReadonly", "fdkReadonly", booleanAttribute] }, providers: [
            {
                provide: FDK_READONLY_DIRECTIVE,
                useExisting: ReadonlyBehaviorDirective
            }
        ], usesInheritance: true, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: ReadonlyBehaviorDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[fdkReadonly]',
                    standalone: true,
                    providers: [
                        {
                            provide: FDK_READONLY_DIRECTIVE,
                            useExisting: ReadonlyBehaviorDirective
                        }
                    ]
                }]
        }], ctorParameters: () => [{ type: i0.ElementRef }, { type: i0.DestroyRef }], propDecorators: { fdkReadonly: [{
                type: Input,
                args: [{ transform: booleanAttribute }]
            }] } });

class ReadonlyBehaviorModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: ReadonlyBehaviorModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "19.2.3", ngImport: i0, type: ReadonlyBehaviorModule, imports: [ReadonlyBehaviorDirective], exports: [ReadonlyBehaviorDirective] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: ReadonlyBehaviorModule }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: ReadonlyBehaviorModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [ReadonlyBehaviorDirective],
                    exports: [ReadonlyBehaviorDirective]
                }]
        }] });

/**
 * Directive to repeatably render template N times.
 */
class RepeatDirective {
    /** @hidden */
    constructor(_templateRef, _viewContainerRef) {
        this._templateRef = _templateRef;
        this._viewContainerRef = _viewContainerRef;
    }
    /** @hidden */
    ngOnChanges(changes) {
        if ((changes['count'] || changes['deprecatedCount']) && Number.isInteger(this.count)) {
            this._viewContainerRef.clear();
            for (let index = 0; index < Math.max(0, this.count); index++) {
                this._viewContainerRef.createEmbeddedView(this._templateRef, { index });
            }
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: RepeatDirective, deps: [{ token: i0.TemplateRef }, { token: i0.ViewContainerRef }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "19.2.3", type: RepeatDirective, isStandalone: true, selector: "[fdkRepeat]", inputs: { count: ["fdkRepeat", "count"] }, usesOnChanges: true, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: RepeatDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[fdkRepeat]',
                    standalone: true
                }]
        }], ctorParameters: () => [{ type: i0.TemplateRef }, { type: i0.ViewContainerRef }], propDecorators: { count: [{
                type: Input,
                args: ['fdkRepeat']
            }] } });

class RepeatModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: RepeatModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "19.2.3", ngImport: i0, type: RepeatModule, imports: [RepeatDirective], exports: [RepeatDirective] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: RepeatModule }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: RepeatModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [RepeatDirective],
                    exports: [RepeatDirective]
                }]
        }] });

class ResizeObserverDirective {
    /** @hidden */
    constructor() {
        /**
         * The reference to the Resize target element.
         **/
        this.elementRef = inject(ElementRef);
        /** @hidden */
        this._resizeObserverService = inject(ResizeObserverService);
        this.resized = this._resizeObserverService.observe(this.elementRef.nativeElement);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: ResizeObserverDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "19.2.3", type: ResizeObserverDirective, isStandalone: true, selector: "[fdkResizeObserver]", outputs: { resized: "resized" }, exportAs: ["fdkResizeObserver"], ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: ResizeObserverDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[fdkResizeObserver]',
                    exportAs: 'fdkResizeObserver',
                    standalone: true
                }]
        }], ctorParameters: () => [], propDecorators: { resized: [{
                type: Output
            }] } });

class ResizeHandleDirective {
    /** @hidden */
    constructor(elementRef) {
        this.elementRef = elementRef;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: ResizeHandleDirective, deps: [{ token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "19.2.3", type: ResizeHandleDirective, isStandalone: true, selector: "[fdkResizeHandle]", ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: ResizeHandleDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[fdkResizeHandle]',
                    standalone: true
                }]
        }], ctorParameters: () => [{ type: i0.ElementRef }] });

class ResizeDirective {
    /** Resize handle reference - should be used if Resize handle is not a ContentChild of resizable container */
    // eslint-disable-next-line @angular-eslint/no-input-rename
    set setResizeHandleReference(value) {
        this.resizeHandleReference = value;
    }
    /** @hidden Reference to Resize handle */
    set resizeHandleReference(value) {
        this._resizeHandleReference = value;
        if (!value) {
            this._unsubscribe();
        }
        else {
            this._setResizeListeners();
        }
    }
    get resizeHandleReference() {
        return this._resizeHandleReference;
    }
    /** @hidden */
    constructor(_elementRef, _rtlService) {
        this._elementRef = _elementRef;
        this._rtlService = _rtlService;
        /** Element limiting resizable container growth */
        // eslint-disable-next-line @angular-eslint/no-input-rename
        this.resizeBoundary = 'body';
        /** Whether resizable behaviour should be disabled */
        // eslint-disable-next-line @angular-eslint/no-input-rename
        this.disabled = false;
        /** Localization of resize handle inside resizable container */
        // eslint-disable-next-line @angular-eslint/no-input-rename
        this.resizeHandleLocation = 'bottom-right';
        /** Emits event when resizing has tarted */
        // eslint-disable-next-line @angular-eslint/no-output-on-prefix
        this.onResizeStart = new EventEmitter();
        /** Emits event when resizing has ended */
        // eslint-disable-next-line @angular-eslint/no-output-on-prefix
        this.onResizeEnd = new EventEmitter();
        /** @hidden */
        this._subscriptions = new Subscription();
        /** @hidden */
        this._resizeSubscriptions = new Subscription();
        /** @hidden */
        this._direction$ = computed(() => (this._rtlService?.rtlSignal() ? -1 : 1));
    }
    /** @hidden */
    ngOnChanges(changes) {
        if (changes['disabled']) {
            if (changes['disabled'].previousValue === false && changes['disabled'].currentValue === true) {
                this._unsubscribe();
            }
            else if (changes['disabled'].previousValue === true && changes['disabled'].currentValue === false) {
                this._setResizeListeners();
            }
        }
    }
    /** @hidden */
    ngAfterViewInit() {
        if (!this.disabled) {
            this._setResizeListeners();
        }
    }
    /** @hidden */
    ngOnDestroy() {
        this._subscriptions.unsubscribe();
        this._resizeSubscriptions.unsubscribe();
    }
    /** @hidden */
    _unsubscribe() {
        this._resizeSubscriptions.unsubscribe();
        this._resizeSubscriptions = new Subscription();
    }
    /** @hidden Sets Resize listeners */
    _setResizeListeners() {
        this._unsubscribe();
        const resize = this._getResizeFunction();
        let moveOffset = this._getMoveOffsetFunction();
        const resizeContainer = this._findResizeContainer();
        if (!resizeContainer || !this.resizeHandleReference) {
            return;
        }
        const isBoundaryOverflow = this._getBoundaryOverflowFunction(resizeContainer);
        const mouseUpEvent$ = fromEvent(window, 'mouseup');
        const mouseMoveEvent$ = fromEvent(resizeContainer, 'mousemove');
        const mouseDownEvent$ = fromEvent(this.resizeHandleReference.elementRef.nativeElement, 'mousedown');
        const resizeActive$ = merge(mouseDownEvent$.pipe(map(() => true), tap(() => {
            moveOffset = this._getMoveOffsetFunction();
        })), mouseUpEvent$.pipe(map(() => false)));
        const emitResizableEvents$ = this._getResizeEventsNotifiers(resizeActive$);
        const preventOtherPointerEvents$ = this._blockOtherPointerEvents(resizeActive$);
        const resizingCursorMovement$ = mouseMoveEvent$.pipe(pairwise(), map(([event1, event2]) => moveOffset(event1, event2)), filter((move) => isBoundaryOverflow(move)));
        const setupResizer = () => {
            resizingCursorMovement$.pipe(takeUntil(mouseUpEvent$)).subscribe((event) => resize(event));
        };
        const setupResize$ = resizeActive$.pipe(filter((isActive) => isActive), tap(() => setupResizer()));
        this._resizeSubscriptions.add(setupResize$.subscribe());
        this._resizeSubscriptions.add(emitResizableEvents$.subscribe());
        this._resizeSubscriptions.add(preventOtherPointerEvents$.subscribe());
    }
    /** @hidden Creates resize function*/
    _getResizeFunction() {
        return (move) => {
            this._elementRef.nativeElement.style.width = `${this._elementRef.nativeElement.offsetWidth + move.x}px`;
            this._elementRef.nativeElement.style.height = `${this._elementRef.nativeElement.offsetHeight + move.y}px`;
        };
    }
    /** @hidden Creates move function */
    _getMoveOffsetFunction() {
        let verticalModifier;
        let horizontalModifier;
        switch (this.resizeHandleLocation) {
            case 'top-left':
                horizontalModifier = -1;
                verticalModifier = -1;
                break;
            case 'top-right':
                horizontalModifier = -1;
                verticalModifier = 1;
                break;
            case 'bottom-left':
                horizontalModifier = 1;
                verticalModifier = -1;
                break;
            case 'bottom-right':
                horizontalModifier = 1;
                verticalModifier = 1;
                break;
        }
        return (event1, event2) => {
            const x = (event2.screenX - event1.screenX) * this._direction$();
            const y = event2.screenY - event1.screenY;
            return {
                x: x * verticalModifier,
                y: y * horizontalModifier
            };
        };
    }
    /** @hidden Return boundary container */
    _findResizeContainer() {
        let resizeContainer;
        if (typeof this.resizeBoundary === 'string') {
            if (this.resizeBoundary === 'body') {
                return document.body;
            }
            resizeContainer = this._elementRef.nativeElement.closest(this.resizeBoundary);
        }
        else {
            resizeContainer = this.resizeBoundary;
        }
        if (resizeContainer) {
            return resizeContainer;
        }
        else {
            console.warn(`fdResize - Cannot find "${this.resizeBoundary}", falling back to "body"`);
            return document.body;
        }
    }
    /** @hidden Check whether resizable container is overflowing boundary container */
    _getBoundaryOverflowFunction(resizeContainer) {
        return (move) => {
            const containerPosition = resizeContainer.getBoundingClientRect();
            const elementPosition = this._elementRef.nativeElement.getBoundingClientRect();
            switch (this.resizeHandleLocation) {
                case 'top-left':
                    return (containerPosition.top < elementPosition.top + move.y &&
                        containerPosition.left < elementPosition.left + move.x);
                case 'top-right':
                    return (containerPosition.top < elementPosition.top + move.y &&
                        containerPosition.right > elementPosition.right + move.x);
                case 'bottom-left':
                    return (containerPosition.bottom > elementPosition.bottom + move.y &&
                        containerPosition.left < elementPosition.left + move.x);
                case 'bottom-right':
                    return (containerPosition.bottom > elementPosition.bottom + move.y &&
                        containerPosition.right > elementPosition.right + move.x);
            }
        };
    }
    /** @hidden Create Observable notifying on resize actions */
    _getResizeEventsNotifiers(trigger$) {
        const emitResizableStart$ = trigger$.pipe(filter((isActive) => isActive), tap(() => this.onResizeStart.emit()));
        const emitResizableEnd$ = trigger$.pipe(filter((isActive) => !isActive), tap(() => this.onResizeEnd.emit()));
        return merge(emitResizableStart$, emitResizableEnd$);
    }
    /** @hidden Block resizable container pointer events when resizing  */
    _blockOtherPointerEvents(trigger$) {
        return trigger$.pipe(tap((isActive) => {
            if (!this.fdkResizeClass) {
                return;
            }
            if (!isActive) {
                this._elementRef.nativeElement.classList.remove(this.fdkResizeClass);
            }
            else {
                this._elementRef.nativeElement.classList.add(this.fdkResizeClass);
            }
        }), map((isActive) => (isActive ? 'none' : 'auto')), tap((value) => {
            this._elementRef.nativeElement.style.pointerEvents = value;
        }));
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: ResizeDirective, deps: [{ token: i0.ElementRef }, { token: RtlService, optional: true }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "19.2.3", type: ResizeDirective, isStandalone: true, selector: "[fdkResize]", inputs: { resizeBoundary: ["fdkResizeBoundary", "resizeBoundary"], disabled: ["fdkResizeDisabled", "disabled"], fdkResizeClass: "fdkResizeClass", resizeHandleLocation: ["fdkResizeHandleLocation", "resizeHandleLocation"], setResizeHandleReference: ["fdkResizeResizeHandleRef", "setResizeHandleReference"] }, outputs: { onResizeStart: "onResizeStart", onResizeEnd: "onResizeEnd" }, queries: [{ propertyName: "resizeHandleReference", first: true, predicate: ResizeHandleDirective, descendants: true }], usesOnChanges: true, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: ResizeDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[fdkResize]',
                    standalone: true
                }]
        }], ctorParameters: () => [{ type: i0.ElementRef }, { type: RtlService, decorators: [{
                    type: Optional
                }] }], propDecorators: { resizeBoundary: [{
                type: Input,
                args: ['fdkResizeBoundary']
            }], disabled: [{
                type: Input,
                args: ['fdkResizeDisabled']
            }], fdkResizeClass: [{
                type: Input
            }], resizeHandleLocation: [{
                type: Input,
                args: ['fdkResizeHandleLocation']
            }], setResizeHandleReference: [{
                type: Input,
                args: ['fdkResizeResizeHandleRef']
            }], onResizeStart: [{
                type: Output
            }], onResizeEnd: [{
                type: Output
            }], resizeHandleReference: [{
                type: ContentChild,
                args: [ResizeHandleDirective, { static: false }]
            }] } });

class ResizeModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: ResizeModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "19.2.3", ngImport: i0, type: ResizeModule, imports: [ResizeDirective, ResizeHandleDirective], exports: [ResizeDirective, ResizeHandleDirective] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: ResizeModule }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: ResizeModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [ResizeDirective, ResizeHandleDirective],
                    exports: [ResizeDirective, ResizeHandleDirective]
                }]
        }] });

class SelectComponentRootToken {
}

class SelectableItemToken {
}

const FDK_SELECTABLE_ITEM_PROVIDER = new InjectionToken('Token for providing custom behaviors to the SelectableListItem');

class SelectionService {
    /** @hidden */
    constructor(_cd) {
        this._cd = _cd;
        /** @hidden */
        this._value$ = new ReplaySubject(1);
        /** @hidden */
        this._destroyRef = inject(DestroyRef);
        /** @hidden */
        this._clear$ = new Subject();
        /** @hidden */
        this._value = [];
        this._normalizedValue$ = this._value$.pipe(distinctUntilChanged(deepEqual), map((v) => coerceArray(v)), map((value) => (this._isMultipleMode ? value : [value[0]])), map((coerced) => coerced.filter(Boolean)));
        this._normalizedValue$.pipe(takeUntilDestroyed(this._destroyRef)).subscribe((val) => (this._value = val));
        this.value$ = this._normalizedValue$.pipe(map((v) => this._getProperValues(v)), shareReplay(1));
    }
    /**
     * Register main select component, which holds config
     * */
    registerRootComponent(rootComponent) {
        this._rootComponent = rootComponent;
    }
    /**
     * Clear listeners
     */
    clear() {
        this._clear$.next();
    }
    /**
     * Initialize watcher for selection changes and user interactions
     * */
    initialize(list) {
        if (list instanceof QueryList) {
            this._items$ = list.changes.pipe(startWith(list), map((items) => items.toArray()), shareReplay(1));
        }
        else {
            this._items$ = isObservable(list) ? list : of(list);
        }
        this.listenToItemInteractions();
    }
    /**
     * Sets Value, on which service looks at and updates UI accordingly
     * */
    setValue(v) {
        this._value$.next(v);
    }
    /** @hidden */
    getValue() {
        return this._getProperValues(this._value);
    }
    /**
     * Start listening for item interactions. Will destroy() first.
     * Will silently continue if service was not initialized first.
     * */
    listenToItemInteractions() {
        this.clear();
        const unsubscribe$ = merge(destroyObservable(this._destroyRef), this._clear$);
        if (this._items$) {
            this._items$
                .pipe(map((items) => items.filter((itm) => itm.fdkSelectableItem !== false)), switchMap((items) => {
                const clickedEvents$ = items.map((item) => item.clicked.pipe(map(() => item)));
                return merge(...clickedEvents$);
            }), tap((clickedItem) => this._itemClicked(clickedItem)), takeUntil(unsubscribe$))
                .subscribe();
            combineLatest([this._normalizedValue$, this._items$])
                .pipe(tap(([value, items]) => {
                if (value.length === 0 &&
                    items.some((itm) => itm.getSelected()) &&
                    !this._rootComponent.toggle) {
                    const selectedValues = this._getSelectedValues(items);
                    this._rootComponent.onChange(selectedValues);
                    return this._value$.next(selectedValues);
                }
                items.forEach((item) => {
                    item.setSelected(value.includes(item.value));
                });
                this._cd.detectChanges();
            }), takeUntil(unsubscribe$))
                .subscribe();
        }
    }
    /** @hidden */
    selectItem(item) {
        if (item.fdkSelectableItem !== false) {
            const val = [item.value, ...this._value];
            const properValues = this._getProperValues(val);
            this._value$.next(properValues);
            this._rootComponent.onChange(properValues);
        }
    }
    /** @hidden */
    deselectItem(item) {
        const canBeDeselected = this._rootComponent.toggle || (this._isMultipleMode && this._value.length > 1);
        if (canBeDeselected) {
            const val = this._value.filter((v) => v !== item.value);
            const properValues = this._getProperValues(val);
            this._value$.next(properValues);
            this._rootComponent.onChange(properValues);
        }
    }
    /** @hidden */
    get _isMultipleMode() {
        return this._rootComponent.multiple === true;
    }
    /** @hidden */
    _itemClicked(item) {
        const wasSelected = this._value.includes(item.value);
        if (wasSelected) {
            this.deselectItem(item);
        }
        else {
            this.selectItem(item);
        }
    }
    /** @hidden */
    _getSelectedValues(items) {
        const selectedValues = items.filter((itm) => itm.getSelected()).map((itm) => itm.value);
        return this._getProperValues(selectedValues);
    }
    /** @hidden */
    _getProperValues(values) {
        return this._isMultipleMode ? values : values[0];
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: SelectionService, deps: [{ token: i0.ChangeDetectorRef }], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: SelectionService }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: SelectionService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i0.ChangeDetectorRef }] });

class SelectableItemDirective {
    /** @hidden */
    set value(val) {
        this._value = val;
    }
    get value() {
        if (this.provider && this.provider.value) {
            return this.provider.value;
        }
        return this._value;
    }
    /** @hidden */
    set fdkSelectableItem(value) {
        const isSelectable = coerceBooleanProperty(value);
        if (isSelectable !== this._selectable) {
            this._selectable = isSelectable;
        }
    }
    get fdkSelectableItem() {
        let selectable = this._selectable;
        if (typeof this.provider?.fdkSelectableItem !== 'undefined') {
            selectable = this.provider.fdkSelectableItem;
        }
        return (selectable &&
            (!this.disabled$ || !this.disabled$?.fdkDisabled) &&
            (!this.readonly$ || !this.readonly$?.fdkReadonly));
    }
    /** @hidden */
    constructor(provider, disabled$, readonly$, selectionService, elementRef, _clicked) {
        this.provider = provider;
        this.disabled$ = disabled$;
        this.readonly$ = readonly$;
        this.selectionService = selectionService;
        this.elementRef = elementRef;
        /** Event emitted when selection state being changed for selectable item. */
        this.selected = new EventEmitter();
        /** @hidden */
        this._selected = false;
        /** @hidden */
        this._selectable = true;
        this.clicked = this.provider?.clicked || _clicked.asObservable();
        this._listenToDisablingEvents();
    }
    /** @hidden */
    getSelected() {
        if (this.provider?.getSelected) {
            return this.provider.getSelected();
        }
        return this._selected;
    }
    /** @hidden */
    setSelected(isSelected) {
        if (this.provider?.setSelected) {
            this.provider.setSelected(isSelected);
        }
        else {
            this._selected = isSelected;
            const htmlElement = this.elementRef.nativeElement;
            const { classList } = htmlElement;
            if (isSelected) {
                classList.add('is-selected');
            }
            else {
                classList.remove('is-selected');
            }
            htmlElement.setAttribute('aria-selected', `${isSelected}`);
        }
        this.selected.emit(isSelected);
    }
    /** @hidden */
    _listenToDisablingEvents() {
        const disablingEvents$ = [];
        if (this.disabled$) {
            disablingEvents$.push(this.disabled$);
        }
        if (this.readonly$) {
            disablingEvents$.push(this.readonly$);
        }
        merge(...disablingEvents$).subscribe(() => this._updateSelectionAndSelectableWatcher());
    }
    /** @hidden */
    _updateSelectionAndSelectableWatcher() {
        if (this.disabled$?.fdkDisabled) {
            this.selectionService.deselectItem(this);
        }
        this._updateSelectableWatcher();
    }
    /** @hidden */
    _updateSelectableWatcher() {
        this.selectionService.listenToItemInteractions();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: SelectableItemDirective, deps: [{ token: FDK_SELECTABLE_ITEM_PROVIDER, optional: true }, { token: FdkDisabledProvider }, { token: FdkReadonlyProvider }, { token: SelectionService }, { token: i0.ElementRef }, { token: FdkClickedProvider }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "19.2.3", type: SelectableItemDirective, isStandalone: true, selector: "[fdkSelectableItem]", inputs: { value: "value", fdkSelectableItem: "fdkSelectableItem" }, outputs: { clicked: "clicked", selected: "selected" }, providers: [
            {
                provide: SelectableItemToken,
                useExisting: SelectableItemDirective
            },
            FdkReadonlyProvider,
            FdkDisabledProvider,
            FdkClickedProvider
        ], exportAs: ["fdkSelectableItem"], ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: SelectableItemDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[fdkSelectableItem]',
                    exportAs: 'fdkSelectableItem',
                    standalone: true,
                    providers: [
                        {
                            provide: SelectableItemToken,
                            useExisting: SelectableItemDirective
                        },
                        FdkReadonlyProvider,
                        FdkDisabledProvider,
                        FdkClickedProvider
                    ]
                }]
        }], ctorParameters: () => [{ type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [FDK_SELECTABLE_ITEM_PROVIDER]
                }] }, { type: FdkDisabledProvider }, { type: FdkReadonlyProvider }, { type: SelectionService }, { type: i0.ElementRef }, { type: FdkClickedProvider }], propDecorators: { value: [{
                type: Input
            }], fdkSelectableItem: [{
                type: Input
            }], clicked: [{
                type: Output
            }], selected: [{
                type: Output
            }] } });

class SelectableListDirective {
    /** @hidden */
    set selected(value) {
        this._selectionService.setValue(value);
    }
    /** @hidden */
    constructor(_selectionService) {
        this._selectionService = _selectionService;
        /** @hidden */
        this.selectedChange = new EventEmitter();
        /** @hidden */
        this.toggle = false;
        /** @hidden */
        this.multiple = false;
        this._selectionService.registerRootComponent(this);
    }
    /** @hidden */
    select(item) {
        this._selectionService.selectItem(item);
    }
    /** @hidden */
    deselect(item) {
        this._selectionService.deselectItem(item);
    }
    /** @hidden */
    toggleSelect(item) {
        if (item.getSelected()) {
            this.deselect(item);
        }
        else {
            this.select(item);
        }
    }
    /** @hidden */
    onChange(value) {
        this.selectedChange.emit(value);
    }
    /** @hidden */
    ngAfterViewInit() {
        this._selectionService.initialize(this.selectableItems);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: SelectableListDirective, deps: [{ token: SelectionService }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "16.1.0", version: "19.2.3", type: SelectableListDirective, isStandalone: true, selector: "[fdkSelectableList]", inputs: { toggle: ["toggle", "toggle", booleanAttribute], multiple: ["multiple", "multiple", booleanAttribute], selected: "selected" }, outputs: { selectedChange: "selectedChange" }, providers: [
            {
                provide: SelectComponentRootToken,
                useExisting: SelectableListDirective
            },
            SelectionService
        ], queries: [{ propertyName: "selectableItems", predicate: SelectableItemToken }], exportAs: ["fdkSelectableList"], ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: SelectableListDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[fdkSelectableList]',
                    exportAs: 'fdkSelectableList',
                    standalone: true,
                    providers: [
                        {
                            provide: SelectComponentRootToken,
                            useExisting: SelectableListDirective
                        },
                        SelectionService
                    ]
                }]
        }], ctorParameters: () => [{ type: SelectionService }], propDecorators: { selectedChange: [{
                type: Output
            }], toggle: [{
                type: Input,
                args: [{ transform: booleanAttribute }]
            }], multiple: [{
                type: Input,
                args: [{ transform: booleanAttribute }]
            }], selected: [{
                type: Input
            }], selectableItems: [{
                type: ContentChildren,
                args: [SelectableItemToken]
            }] } });

class SelectableListModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: SelectableListModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "19.2.3", ngImport: i0, type: SelectableListModule, imports: [SelectableListDirective, SelectableItemDirective], exports: [SelectableListDirective, SelectableItemDirective] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: SelectableListModule }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: SelectableListModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [SelectableListDirective, SelectableItemDirective],
                    exports: [SelectableListDirective, SelectableItemDirective]
                }]
        }] });

class TemplateDirective {
    /** @hidden */
    constructor(templateRef) {
        this.templateRef = templateRef;
    }
    /** @hidden */
    getName() {
        return this.name;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: TemplateDirective, deps: [{ token: i0.TemplateRef }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "19.2.3", type: TemplateDirective, isStandalone: true, selector: "[fdkTemplate]", inputs: { name: ["fdkTemplate", "name"] }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: TemplateDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[fdkTemplate]',
                    standalone: true
                }]
        }], ctorParameters: () => [{ type: i0.TemplateRef }], propDecorators: { name: [{
                type: Input,
                args: ['fdkTemplate']
            }] } });

class TemplateModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: TemplateModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "19.2.3", ngImport: i0, type: TemplateModule, imports: [TemplateDirective], exports: [TemplateDirective] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: TemplateModule }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: TemplateModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [TemplateDirective],
                    exports: [TemplateDirective]
                }]
        }] });

class TruncateDirective {
    /**
     * Width in pixel for truncation of an element , by default
     */
    set fdkTruncateWidth(value) {
        this._customWidthCount = coerceNumberProperty(value);
    }
    /** @hidden */
    constructor(_elementRef) {
        this._elementRef = _elementRef;
        /**
         * Truncating state
         */
        this.fdkTruncateState = false;
        /** @hidden */
        this._customWidthCount = 200;
        /** @hidden */
        this.takeDefaultStyleOnce = true;
    }
    /**
     * Root native element
     */
    get rootElement() {
        return this._elementRef.nativeElement;
    }
    /**
     * Method saves default style of target element before first truncate.
     */
    setDefaultStyle() {
        if (this.takeDefaultStyleOnce) {
            this._defaultStyle = this._truncateTarget.style.cssText;
            this.takeDefaultStyleOnce = false;
        }
    }
    /** @hidden */
    ngAfterViewInit() {
        if (this.rootElement) {
            this._truncate();
        }
    }
    /** @hidden */
    ngOnChanges() {
        this._truncate();
    }
    /** @hidden */
    _truncate() {
        this._truncateTarget = this.rootElement;
        if (!this._truncateTarget) {
            return;
        }
        this.setDefaultStyle();
        this._truncationStyle = `${this._defaultStyle} max-width: ${this._customWidthCount}px; overflow: hidden; text-overflow: ellipsis; white-space: nowrap;`;
        this._truncateTarget.style.cssText = this.fdkTruncateState ? this._truncationStyle : this._defaultStyle;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: TruncateDirective, deps: [{ token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "19.2.3", type: TruncateDirective, isStandalone: true, selector: "[fdkTruncate]", inputs: { fdkTruncateWidth: "fdkTruncateWidth", fdkTruncateState: "fdkTruncateState" }, usesOnChanges: true, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: TruncateDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[fdkTruncate]',
                    standalone: true
                }]
        }], ctorParameters: () => [{ type: i0.ElementRef }], propDecorators: { fdkTruncateWidth: [{
                type: Input
            }], fdkTruncateState: [{
                type: Input
            }] } });
class TruncatedTitleDirective {
    /** @hidden */
    constructor(_elRef) {
        this._elRef = _elRef;
    }
    /** @hidden */
    ngAfterContentChecked() {
        const el = this._elRef.nativeElement;
        if (el.scrollWidth > el.offsetWidth) {
            el.title = el.innerText;
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: TruncatedTitleDirective, deps: [{ token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "19.2.3", type: TruncatedTitleDirective, isStandalone: true, selector: "[fdkTruncatedTitle], [fdTruncatedTitle], [fd-truncate-title]", ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: TruncatedTitleDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[fdkTruncatedTitle], [fdTruncatedTitle], [fd-truncate-title]',
                    standalone: true
                }]
        }], ctorParameters: () => [{ type: i0.ElementRef }] });

class TruncateModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: TruncateModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "19.2.3", ngImport: i0, type: TruncateModule, imports: [TruncateDirective, TruncatedTitleDirective], exports: [TruncateDirective, TruncatedTitleDirective] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: TruncateModule }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: TruncateModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [TruncateDirective, TruncatedTitleDirective],
                    exports: [TruncateDirective, TruncatedTitleDirective]
                }]
        }] });

const DND_ITEM = new InjectionToken('Drag and drop Item');
const DND_LIST = new InjectionToken('Drag and drop List');

class DndItemDirective {
    /** Defines if element is draggable */
    set draggable(draggable) {
        this._draggable = draggable;
        this.changeCDKDragState();
    }
    /** @hidden */
    constructor(elementRef, _dragDrop, _renderer) {
        this.elementRef = elementRef;
        this._dragDrop = _dragDrop;
        this._renderer = _renderer;
        /**
         * Whether to apply "fd-dnd-item" class.
         * @default true
         */
        this.applyDragItemClass = true;
        /** Event thrown when the element is moved by 1px */
        this.moved = new EventEmitter();
        /** Event thrown when the element is released */
        this.released = new EventEmitter();
        /** Event thrown when the element is started to be dragged */
        this.started = new EventEmitter();
        /**
         *  Defines if the item is prevented from being moved by other elements.
         * So nothing can be placed just before and just after it
         */
        this.stickInPlace = false;
        /** Class added to element, when it's dragged. */
        this.classWhenElementDragged = 'fd-dnd-on-drag';
        /** Defines if every element in list is draggable */
        this.listDraggable = true;
        /** @hidden */
        this._draggable = true;
        /** @hidden */
        this._subscriptions = new Subscription();
        /** @hidden */
        this._placeholderElement = null;
        /** @hidden */
        this._lineElement = null;
        /** @hidden */
        this._replaceIndicator = null;
    }
    /** @hidden */
    getElementCoordinates(isBefore) {
        /** Takes distance from the beginning of window page */
        const rect = this.elementRef.nativeElement.getBoundingClientRect();
        const position = isBefore ? 'before' : 'after';
        /** Vertically distance is counted by distance from top of the side + half of the element height */
        return {
            x: rect.left,
            position,
            y: rect.top,
            stickToPosition: this.stickInPlace,
            width: rect.width,
            height: rect.height
        };
    }
    /** @hidden */
    ngAfterContentInit() {
        this._setCDKDrag();
        this._listenElementEvents();
    }
    /** @hidden */
    ngOnDestroy() {
        this._subscriptions.unsubscribe();
        this._dragRef.dispose();
    }
    /** @hidden */
    onCdkMove(position) {
        this.moved.emit(position);
    }
    /** @hidden */
    onCdkDragReleased() {
        /** Remove class which is added, when element is dragged */
        this.elementRef.nativeElement.classList.remove(this.classWhenElementDragged);
        this.released.emit();
        /** Resets the position of element. */
        this._dragRef.reset();
        /** Removes placeholder element */
        this.removePlaceholder();
    }
    /** @hidden */
    onCdkDragStart() {
        /** Adds class */
        this.elementRef.nativeElement.classList.add(this.classWhenElementDragged);
        if (!this._placeholderElement) {
            this.createPlaceholder();
        }
        this.started.emit();
    }
    /** @hidden */
    removePlaceholder() {
        if (this._placeholderElement && this._placeholderElement.parentNode) {
            // IE11 workaround
            this._placeholderElement.parentNode.removeChild(this._placeholderElement);
            this._placeholderElement = null;
        }
    }
    /** @hidden */
    removeLine() {
        if (this._lineElement && this._lineElement.parentNode) {
            // IE11 workaround
            this._lineElement.parentNode.removeChild(this._lineElement);
            this._lineElement = null;
        }
    }
    /** @hidden */
    removeReplaceIndicator() {
        if (this._replaceIndicator && this._replaceIndicator.parentNode) {
            // IE11 workaround
            this._replaceIndicator.parentNode.removeChild(this._replaceIndicator);
            this._replaceIndicator = null;
        }
    }
    /** @hidden */
    createReplaceIndicator() {
        this._replaceIndicator = document.createElement('DIV');
        this._replaceIndicator.classList.add('fd-replace-indicator');
        let container = this.elementRef.nativeElement;
        if (this.containerSelector) {
            const newContainer = this.elementRef.nativeElement.querySelector(this.containerSelector);
            if (newContainer) {
                container = newContainer;
            }
        }
        container.appendChild(this._replaceIndicator);
    }
    /** @hidden */
    createLine(position, gridMode) {
        /** Creating of line element */
        this._lineElement = document.createElement('div');
        this._lineElement.classList.add('drop-area__line');
        if (gridMode) {
            this._lineElement.classList.add('drop-area__line--vertical');
        }
        else {
            this._lineElement.classList.add('drop-area__line--horizontal');
        }
        if (position === 'after') {
            this._lineElement.classList.add('after');
        }
        if (position === 'before') {
            this._lineElement.classList.add('before');
        }
        /** Putting element to the container */
        let container = this.elementRef.nativeElement;
        if (this.containerSelector) {
            const newContainer = this.elementRef.nativeElement.querySelector(this.containerSelector);
            if (newContainer) {
                container = newContainer;
            }
        }
        container.appendChild(this._lineElement);
    }
    /** @hidden */
    changeCDKDragState() {
        if (this._dragRef) {
            this._dragRef.disabled = !(this._draggable && this.listDraggable);
        }
    }
    /**
     * Sets the disabled state of the dnd item.
     * @param state
     */
    setDisabledState(state) {
        if (state) {
            this._renderer.addClass(this.elementRef.nativeElement, 'fd-dnd-item--disabled');
        }
        else {
            this._renderer.removeClass(this.elementRef.nativeElement, 'fd-dnd-item--disabled');
        }
    }
    /** @hidden */
    createPlaceholder() {
        const placeholder = this.elementRef.nativeElement.cloneNode(true);
        /** Cloning container element */
        this._placeholderElement = placeholder;
        placeholder.classList.add('fd-dnd-placeholder');
        this._setPlaceholderStyles();
        /** Including element to the container
         *  IE11 equivalent to `this.element.nativeElement.after(clone);`
         */
        this._placeAfter(this.elementRef.nativeElement, placeholder);
    }
    /** @hidden */
    _setPlaceholderStyles() {
        const offset = this._getOffsetToParent(this.elementRef.nativeElement);
        if (!offset || !this._placeholderElement) {
            return;
        }
        this._placeholderElement.style.top = offset.y + 'px';
        this._placeholderElement.style.left = offset.x + 'px';
        this._placeholderElement.style.position = 'absolute';
        this._placeholderElement.style.zIndex = '0';
        this._placeholderElement.style.opacity = '0.3';
        this._placeholderElement.style.width = this.elementRef.nativeElement.offsetWidth + 'px';
        this._placeholderElement.style.height = this.elementRef.nativeElement.offsetHeight + 'px';
    }
    /** @hidden */
    _getOffsetToParent(element) {
        const parentElement = element.parentElement;
        if (!parentElement) {
            return;
        }
        const parentElmRect = parentElement.getBoundingClientRect();
        const elmRect = element.getBoundingClientRect();
        const parentTop = parentElmRect.top;
        const parentLeft = parentElmRect.left;
        return {
            x: Math.abs(elmRect.left - parentLeft),
            y: Math.abs(elmRect.top - parentTop)
        };
    }
    /** @hidden */
    _setCDKDrag() {
        this._dragRef = this._dragDrop.createDrag(this.elementRef);
        this._dragRef.disabled = !this._draggable;
        this._subscriptions.add(this._dragRef.moved.subscribe((event) => this.onCdkMove(event.pointerPosition)));
        this._subscriptions.add(this._dragRef.released.subscribe(() => this.onCdkDragReleased()));
        this._subscriptions.add(this._dragRef.started.subscribe(() => this.onCdkDragStart()));
    }
    /** IE11 equivalent of Node.after() Method */
    _placeAfter(element, cloneNode) {
        const docFrag = document.createDocumentFragment();
        docFrag.appendChild(cloneNode);
        element.parentNode?.insertBefore(docFrag, element.nextSibling);
    }
    /** @hidden */
    _listenElementEvents() {
        this._subscriptions.add(this.released
            .pipe(
        // postpone blur
        delay(0))
            .subscribe(() => {
            if (this.containerSelector) {
                this.elementRef.nativeElement.children[0].blur();
            }
            this.elementRef.nativeElement.blur();
        }));
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: DndItemDirective, deps: [{ token: i0.ElementRef }, { token: i1$2.DragDrop }, { token: i0.Renderer2 }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "19.2.3", type: DndItemDirective, isStandalone: true, selector: "[fdkDndItem], [fd-dnd-item]", inputs: { item: ["fdkDndItem", "item"], applyDragItemClass: "applyDragItemClass", containerSelector: "containerSelector", stickInPlace: "stickInPlace", draggable: "draggable", classWhenElementDragged: "classWhenElementDragged" }, outputs: { moved: "moved", released: "released", started: "started" }, host: { properties: { "class.fd-dnd-item": "this.applyDragItemClass" } }, providers: [DragDrop, { provide: DND_ITEM, useExisting: forwardRef(() => DndItemDirective) }], ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: DndItemDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[fdkDndItem], [fd-dnd-item]',
                    providers: [DragDrop, { provide: DND_ITEM, useExisting: forwardRef(() => DndItemDirective) }],
                    standalone: true
                }]
        }], ctorParameters: () => [{ type: i0.ElementRef }, { type: i1$2.DragDrop }, { type: i0.Renderer2 }], propDecorators: { item: [{
                type: Input,
                args: ['fdkDndItem']
            }], applyDragItemClass: [{
                type: Input
            }, {
                type: HostBinding,
                args: ['class.fd-dnd-item']
            }], containerSelector: [{
                type: Input
            }], moved: [{
                type: Output
            }], released: [{
                type: Output
            }], started: [{
                type: Output
            }], stickInPlace: [{
                type: Input
            }], draggable: [{
                type: Input
            }], classWhenElementDragged: [{
                type: Input
            }] } });

/**
 * This directive is used to provide drag & drop with keyboard support.
 * It should be used together with directive fdDndKeyboardItem.
 */
class DndKeyboardGroupDirective {
    /** @hidden */
    constructor(_cdr, _rtlService) {
        this._cdr = _cdr;
        this._rtlService = _rtlService;
        /** Whether to disable drag & drop */
        this.disableKeyboardDragDrop = false;
        /** Used to apply indexes when moving between groups */
        this.orientation = 'vertical';
        /** @hidden */
        this._onDndItemFocus$ = new Subject();
        /** Custom function to call when moving item inside the group */
        this.customMoveFn = (group, fromIndex, toIndex) => moveItemInArray(group, fromIndex, toIndex);
        /** Custom function to call when moving item between groups */
        this.customTransferFn = (group, nextGroup, fromIndex, toIndex) => transferArrayItem(group, nextGroup, fromIndex, toIndex);
    }
    /** Process drag & drop */
    processDragDrop(event, itemIndex, groupIndex) {
        if (this.disableKeyboardDragDrop || !event.altKey) {
            return;
        }
        const isRtl = this._rtlService.rtl.value;
        const group = this.groups[groupIndex];
        const indexInNextGroup = this.orientation === 'vertical' ? 0 : itemIndex;
        const nextGroupExists = this.groups.length > groupIndex + 1;
        const prevGroupExists = !!groupIndex;
        if (KeyUtil.isKeyCode(event, RIGHT_ARROW) && (isRtl ? prevGroupExists : nextGroupExists)) {
            event.preventDefault();
            const nextGroupIndex = groupIndex + (isRtl ? -1 : 1);
            const nextGroup = this.groups[nextGroupIndex];
            this.customTransferFn(group, nextGroup, itemIndex, indexInNextGroup);
            this._focusDndItem(nextGroupIndex, indexInNextGroup);
        }
        else if (KeyUtil.isKeyCode(event, LEFT_ARROW) && (isRtl ? nextGroupExists : prevGroupExists)) {
            event.preventDefault();
            const nextGroupIndex = groupIndex + (isRtl ? 1 : -1);
            const nextGroup = this.groups[nextGroupIndex];
            this.customTransferFn(group, nextGroup, itemIndex, indexInNextGroup);
            this._focusDndItem(nextGroupIndex, indexInNextGroup);
        }
        else if (KeyUtil.isKeyCode(event, DOWN_ARROW)) {
            event.preventDefault();
            this.customMoveFn(group, itemIndex, itemIndex + 1);
            this._focusDndItem(groupIndex, itemIndex + 1);
        }
        else if (KeyUtil.isKeyCode(event, UP_ARROW)) {
            event.preventDefault();
            this.customMoveFn(group, itemIndex, itemIndex - 1);
            this._focusDndItem(groupIndex, itemIndex - 1);
        }
    }
    /** @hidden Focus after moving elements with keyboard */
    _focusDndItem(groupIndex, itemIndex) {
        this._cdr.detectChanges();
        this._onDndItemFocus$.next([groupIndex, itemIndex]);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: DndKeyboardGroupDirective, deps: [{ token: i0.ChangeDetectorRef }, { token: RtlService, optional: true }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "19.2.3", type: DndKeyboardGroupDirective, isStandalone: true, selector: "[fdkDndKeyboardGroup], [fdDndKeyboardGroup]", inputs: { groups: "groups", disableKeyboardDragDrop: "disableKeyboardDragDrop", orientation: "orientation", customMoveFn: "customMoveFn", customTransferFn: "customTransferFn" }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: DndKeyboardGroupDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[fdkDndKeyboardGroup], [fdDndKeyboardGroup]'
                }]
        }], ctorParameters: () => [{ type: i0.ChangeDetectorRef }, { type: RtlService, decorators: [{
                    type: Optional
                }] }], propDecorators: { groups: [{
                type: Input
            }], disableKeyboardDragDrop: [{
                type: Input
            }], orientation: [{
                type: Input
            }], customMoveFn: [{
                type: Input
            }], customTransferFn: [{
                type: Input
            }] } });

/**
 * This directive is used to provide drag & drop with keyboard support.
 * It should be used together with directive fdDndKeyboardGroup.
 * We are using _groups from fdDndKeyboardGroup and adding a possibility to move cards.
 * Please see example below:
 * @Component({
 * selector: 'cdk-drag-drop-example',
 * template: `<div
 *               cdkDragListGroup
 *               fdDndKeyboardGroup
 *               [groups]="groups"
 *           >
 *               <div
 *                   *ngFor="let group of groups; let groupIndex = index"
 *                   cdkDragList
 *               >
 *                   Group #{{ groupIndex }}
 *                   <div
 *                       *ngFor="let item of group; let index = index"
 *                       cdkDrag
 *                       fdDndKeyboardItem
 *                       [itemIndex]="index"
 *                       [groupIndex]="groupIndex"
 *                       [dndKeyboardDisabled]="flag for disable/enable keyboard navigation if needed"
 *                       tabindex="0"
 *                   >
 *                       Item #{{ item }}
 *                   </div>
 *               </div>
 *           </div>`,
 * })
 * export class CdkDragDropExample {
 *   groups = [
 *        [1, 2, 3],
 *        [4, 5, 6],
 *      ];
 *   }
 */
class DndKeyboardItemDirective {
    /** @hidden */
    constructor(_dndGroup, _elementRef) {
        this._dndGroup = _dndGroup;
        this._elementRef = _elementRef;
        /** @hidden */
        this._onDestroy$ = new Subject();
    }
    /** @hidden */
    _onKeyDown(event) {
        this._dndGroup.processDragDrop(event, this.itemIndex, this.groupIndex);
    }
    /** @hidden */
    ngOnInit() {
        this._dndGroup._onDndItemFocus$.subscribe(([groupIndex, itemIndex]) => {
            if (this.groupIndex === groupIndex && this.itemIndex === itemIndex) {
                this._elementRef.nativeElement.focus();
            }
        });
    }
    /** @hidden */
    ngOnDestroy() {
        this._onDestroy$.next();
        this._onDestroy$.complete();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: DndKeyboardItemDirective, deps: [{ token: DndKeyboardGroupDirective }, { token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "19.2.3", type: DndKeyboardItemDirective, isStandalone: true, selector: "[fdkDndKeyboardItem], [fdDndKeyboardItem]", inputs: { itemIndex: "itemIndex", groupIndex: "groupIndex" }, host: { listeners: { "keydown": "_onKeyDown($event)" } }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: DndKeyboardItemDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[fdkDndKeyboardItem], [fdDndKeyboardItem]'
                }]
        }], ctorParameters: () => [{ type: DndKeyboardGroupDirective }, { type: i0.ElementRef }], propDecorators: { itemIndex: [{
                type: Input
            }], groupIndex: [{
                type: Input
            }], _onKeyDown: [{
                type: HostListener,
                args: ['keydown', ['$event']]
            }] } });

/**
 * @description Executes function and passes returned value into callback function.
 */
class FunctionStrategy {
    /** @hidden */
    createSubscription(fn, updateLatestValue) {
        const result = isFunction(fn) ? fn() : fn;
        return Promise.resolve(result).then(updateLatestValue);
    }
}

/**
 * @description Converts observable into Promise and passes returned value into callback function.
 */
class ObservableStrategy {
    /** @hidden */
    createSubscription(async, updateLatestValue) {
        return firstValueFrom(async).then(updateLatestValue, (e) => {
            console.error(e);
        });
    }
}

/**
 * @description awaits for promise to resolve it's value and passes returned value into callback function.
 */
class PromiseStrategy {
    /** @hidden */
    createSubscription(async, updateLatestValue) {
        return async.then(updateLatestValue, (e) => {
            console.error(e);
        });
    }
}

/**
 * @description Passes value object into callback function.
 */
class ValueStrategy {
    /** @hidden */
    createSubscription(value, updateLatestValue) {
        return Promise.resolve(value).then(updateLatestValue);
    }
}

/**
 * @description Selects appropriate strategy on how to resolve function value
 * @param obj object to get value from
 * @returns appropriate strategy to retrieve value from the object
 */
function selectStrategy(obj) {
    if (isPromise(obj)) {
        return new PromiseStrategy();
    }
    if (isSubscribable(obj)) {
        return new ObservableStrategy();
    }
    if (isFunction(obj)) {
        return new FunctionStrategy();
    }
    return new ValueStrategy();
}

class DndListDirective {
    constructor() {
        /**
         * Defines if the element is allowed to be dragged in 2 dimensions,
         * When true - replace indicator will be displayed vertically
         */
        this.gridMode = false;
        /**
         * Defines drop strategy:
         * * `shift` mode will create line after the closest drop element.
         * * `group` mode will create replace indicator on a whole closest drop element.
         * * `auto` mode will create a line after the closest drop element
         * if dragged element coordinates are shifted for 30% from the center of the closest drop element.
         * Otherwise, it will create replace indicator on a whole closest drop element.
         *
         * `shift` mode is the default.
         */
        this.dropMode = 'shift';
        /**
         * Threshold of dragged item over another item to define which type of `dropMode` should be used.
         */
        this.threshold = 0.3;
        /** Array of items, that will be sorted */
        this.items = [];
        /**
         * Event emitted when `dropPredicate` function evaluation changes.
         * Emits `true` when evaluation started, and `false` when completed.
         */
        this.dropPredicateCalculating = new EventEmitter();
        /** Event that is thrown when items are reordered */
        this.itemsChange = new EventEmitter();
        /** Event that is thrown when the item is dropped */
        this.itemDropped = new EventEmitter();
        /** Event that is thrown when predicate function returned false. */
        this.dropCancelled = new EventEmitter();
        /** @hidden */
        this._initialClass = 'fd-dnd-list';
        /** @hidden */
        this._closestItemIndex = null;
        /** @hidden */
        this._closestItemPosition = null;
        /** An RxJS Subject that will kill the current data stream (for unsubscribing)  */
        this._refresh$ = new Subject();
        /** @hidden */
        this._destroyRef = inject(DestroyRef);
        /** @hidden */
        this._draggable = true;
        /** @hidden */
        this._linesRemoved = true;
        /** @hidden */
        this._indicatorsRemoved = true;
        /** @hidden */
        this._ignoreDrop = false;
    }
    /** Defines if drag and drop feature should be enabled for list items */
    set draggable(draggable) {
        this._draggable = draggable;
        this._changeDraggableState(draggable);
    }
    /** @hidden */
    ngAfterContentInit() {
        this._changeDraggableState(this._draggable);
        this.dndItems.changes
            .pipe(startWith(null), takeUntilDestroyed(this._destroyRef))
            .subscribe(() => this.refreshQueryList());
    }
    /** @hidden */
    ngOnDestroy() {
        this._refresh$.next();
        this._refresh$.complete();
    }
    /**
     * Refreshes the indexes of the items.
     */
    refreshQueryList() {
        const refresh$ = merge(this._refresh$, destroyObservable(this._destroyRef));
        this._refresh$.next();
        this._dndItemReference = this.dndItems.toArray();
        this._changeDraggableState(this._draggable);
        this.dndItems.forEach((item, index) => {
            item.moved.pipe(takeUntil(refresh$)).subscribe((position) => this.onMove(position, index));
            item.started.pipe(takeUntil(refresh$)).subscribe(() => this.dragStart(index));
            item.released.pipe(takeUntil(refresh$)).subscribe(async () => await this.dragEnd(index));
        });
    }
    /** Method called when the item is being moved by 1 px */
    onMove(mousePosition, draggedItemIndex) {
        /** Temporary object, to store lowest distance values */
        let closestItemIndex = null;
        const closestDndItem = this._elementsCoordinates.find((element, index) => {
            /** Check if an element can be replaced */
            if (!element.stickToPosition && closestItemIndex !== index) {
                const isMouseOnElement = _isMouseOnElement(element, mousePosition);
                if (isMouseOnElement) {
                    closestItemIndex = index;
                    return true;
                }
            }
            return false;
        });
        if (!closestDndItem) {
            closestItemIndex = null;
        }
        /** If the closest element is different from the old one, the new one is picked. It prevents from performance issues */
        if ((closestItemIndex || closestItemIndex === 0) &&
            (closestItemIndex !== this._closestItemIndex || this.dropMode === 'auto')) {
            this._removeAllLines();
            this._removeAllReplaceIndicators();
            this._closestItemIndex = closestItemIndex;
            this._closestItemPosition = this._elementsCoordinates[closestItemIndex].position;
            const closestItem = this.items[this._closestItemIndex];
            // If closest item index is same as dragged item, just remove indicators
            if (closestItemIndex === draggedItemIndex) {
                this._removeAllLines();
                this._removeAllReplaceIndicators();
                return;
            }
            if (this.dragoverPredicate &&
                this._draggedItem &&
                !this.dragoverPredicate(this._draggedItem, closestItem, draggedItemIndex, this._closestItemIndex)) {
                this._ignoreDrop = true;
                this._setDisabledItem(this._closestItemIndex);
                return;
            }
            this._setDisabledItem(-1);
            /** Generating line, that shows where the element will be placed, on a drop */
            if (this.dropMode === 'group') {
                this._createReplaceIndicator(this._closestItemIndex);
            }
            else if (this.dropMode === 'shift') {
                this._createLine(this._closestItemIndex, this._closestItemPosition);
            }
            else {
                this._selectDropModeIndicator(draggedItemIndex, closestDndItem, closestItemIndex);
            }
        }
    }
    /** Method called when an element is started to be dragged */
    dragStart(index) {
        const draggedItemElement = this._dndItemReference[index].elementRef;
        this._draggedItem = this.items[index];
        /** Counting all the element's chords */
        this._elementsCoordinates = this._dndItemReference.map((item) => item.getElementCoordinates(this._isBefore(draggedItemElement, item.elementRef), this.gridMode));
    }
    /** Method called when an element is released */
    async dragEnd(draggedItemIndex) {
        this._draggedItem = undefined;
        const items = this.items.slice();
        const replacedItemIndex = this._closestItemIndex;
        this._setDisabledItem(-1);
        if (this._ignoreDrop) {
            this._ignoreDrop = false;
            return;
        }
        if (replacedItemIndex === null || replacedItemIndex === -1) {
            return;
        }
        const draggedDndItem = this.dndItems.get(draggedItemIndex)?.item ?? items[draggedItemIndex];
        const replacedDndItem = this.dndItems.get(replacedItemIndex)?.item ?? items[replacedItemIndex];
        const predicateSubj = new Subject();
        const evt = {
            replacedItemIndex,
            draggedItemIndex,
            items,
            insertAt: this._closestItemPosition,
            mode: this.dropMode !== 'auto' ? this.dropMode : this._detectedDropMode
        };
        predicateSubj.pipe(take(1)).subscribe((result) => {
            this._removeAllLines();
            this._removeAllReplaceIndicators();
            /** Reset */
            this._elementsCoordinates = [];
            this._closestItemIndex = null;
            this._closestItemPosition = null;
            if (!result) {
                this.dropCancelled.emit();
                return;
            }
            if (draggedItemIndex !== replacedItemIndex) {
                if (draggedItemIndex < replacedItemIndex) {
                    for (let i = draggedItemIndex; i < replacedItemIndex; i++) {
                        items[i] = items[i + 1];
                    }
                }
                else {
                    for (let i = draggedItemIndex; i > replacedItemIndex; i--) {
                        items[i] = items[i - 1];
                    }
                }
                /** Replacing items */
                items[replacedItemIndex] = draggedDndItem;
                this.itemsChange.emit(items);
            }
            this.itemDropped.emit(evt);
        });
        if (this.dropPredicate !== undefined) {
            this.dropPredicateCalculating.emit(true);
            const obj = this.dropPredicate(draggedDndItem, replacedDndItem, evt);
            const strategy = selectStrategy(obj);
            await strategy.createSubscription(obj, (result) => {
                predicateSubj.next(result);
                this.dropPredicateCalculating.emit(false);
            });
        }
        else {
            predicateSubj.next(true);
        }
    }
    /** @hidden */
    _setDisabledItem(itemIndex) {
        this.dndItems.forEach((item, index) => {
            item.setDisabledState(index === itemIndex);
        });
    }
    /** @hidden */
    _selectDropModeIndicator(draggedItemIndex, closestItem, closestItemIndex) {
        if (!closestItem || !this._dndItemReference[draggedItemIndex]) {
            return;
        }
        let newDetectedDropMode;
        const draggedElmCoords = this._dndItemReference[draggedItemIndex].elementRef.nativeElement.getBoundingClientRect();
        const closestItemBoundaries = getElementBoundaries(closestItem, this.threshold);
        const draggedItemStartCoords = getElementStartCoords(draggedElmCoords, closestItem.position);
        if (_between(draggedItemStartCoords.x, closestItemBoundaries.x.start, closestItemBoundaries.x.end) &&
            _between(draggedItemStartCoords.y, closestItemBoundaries.y.start, closestItemBoundaries.y.end)) {
            newDetectedDropMode = 'group';
        }
        else {
            newDetectedDropMode = 'shift';
        }
        if (newDetectedDropMode === this._detectedDropMode && (!this._linesRemoved || !this._indicatorsRemoved)) {
            return;
        }
        this._detectedDropMode = newDetectedDropMode;
        if (this._detectedDropMode === 'shift') {
            this._createLine(closestItemIndex, this._elementsCoordinates[closestItemIndex].position);
        }
        else {
            this._createReplaceIndicator(closestItemIndex);
        }
    }
    /** @hidden */
    _removeAllLines() {
        this._linesRemoved = true;
        this.dndItems.forEach((item) => item.removeLine());
    }
    /** @hidden */
    _removeAllReplaceIndicators() {
        this._indicatorsRemoved = true;
        this.dndItems.forEach((item) => item.removeReplaceIndicator());
    }
    /** @hidden */
    _createLine(closestItemIndex, linkPosition) {
        this._removeAllLines();
        this._removeAllReplaceIndicators();
        this._linesRemoved = false;
        this._dndItemReference[closestItemIndex].createLine(linkPosition, this.gridMode);
    }
    /** @hidden */
    _createReplaceIndicator(closestItemIndex) {
        this._removeAllLines();
        this._removeAllReplaceIndicators();
        this._indicatorsRemoved = false;
        this._dndItemReference[closestItemIndex].createReplaceIndicator();
    }
    /**
     *  @hidden
     * Return information if an element is placed before the dragged element
     */
    _isBefore(draggedElement, targetElement) {
        /** Sometimes the elements are not straight in one column, that's why offset is needed */
        const VERTICAL_OFFSET = 20;
        /** Distances from the top of the screen */
        const draggedElementBound = draggedElement.nativeElement.getBoundingClientRect();
        const targetElementBound = targetElement.nativeElement.getBoundingClientRect();
        if (draggedElementBound.top - targetElementBound.top > VERTICAL_OFFSET) {
            /** If an element is higher than the dragged element, it's for sure before */
            return true;
        }
        else if (targetElementBound.top - draggedElementBound.top > VERTICAL_OFFSET) {
            /** If an element is lower than the dragged element, it's for sure after */
            return false;
        }
        else {
            /** If elements are in same level, the horizontal position decides if it's before/after */
            return draggedElementBound.left - targetElementBound.left > 0;
        }
    }
    /** @hidden */
    _changeDraggableState(draggable) {
        if (this.dndItems) {
            this.dndItems.forEach((item) => {
                item.listDraggable = draggable;
                item.changeCDKDragState();
            });
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: DndListDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "19.2.3", type: DndListDirective, isStandalone: true, selector: "[fdkDndList], [fd-dnd-list]", inputs: { gridMode: "gridMode", dropMode: "dropMode", threshold: "threshold", items: "items", draggable: "draggable", dropPredicate: "dropPredicate", dragoverPredicate: "dragoverPredicate" }, outputs: { dropPredicateCalculating: "dropPredicateCalculating", itemsChange: "itemsChange", itemDropped: "itemDropped", dropCancelled: "dropCancelled" }, host: { properties: { "class": "this._initialClass" } }, providers: [{ provide: DND_LIST, useExisting: forwardRef(() => DndListDirective) }], queries: [{ propertyName: "dndItems", predicate: DND_ITEM }], ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: DndListDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[fdkDndList], [fd-dnd-list]',
                    providers: [{ provide: DND_LIST, useExisting: forwardRef(() => DndListDirective) }],
                    standalone: true
                }]
        }], propDecorators: { gridMode: [{
                type: Input
            }], dropMode: [{
                type: Input
            }], threshold: [{
                type: Input
            }], items: [{
                type: Input
            }], draggable: [{
                type: Input
            }], dropPredicate: [{
                type: Input
            }], dragoverPredicate: [{
                type: Input
            }], dropPredicateCalculating: [{
                type: Output
            }], itemsChange: [{
                type: Output
            }], itemDropped: [{
                type: Output
            }], dropCancelled: [{
                type: Output
            }], dndItems: [{
                type: ContentChildren,
                args: [DND_ITEM]
            }], _initialClass: [{
                type: HostBinding,
                args: ['class']
            }] } });
function _isMouseOnElement(element, mousePosition) {
    const startX = element.x;
    const endX = element.x + element.width;
    const startY = element.y;
    const endY = element.y + element.height;
    return _between(mousePosition.x, startX, endX) && _between(mousePosition.y, startY, endY);
}
function _between(x, min, max) {
    return x >= min && x <= max;
}
function getElementStartCoords(rect, position) {
    return {
        x: position === 'after' ? rect.x + rect.width : rect.x,
        y: position === 'after' ? rect.y + rect.height : rect.y
    };
}
function getElementBoundaries(coordinates, threshold) {
    const widthOffset = coordinates.width * (coordinates.position === 'after' ? 1 : -1);
    const heightOffset = coordinates.height * (coordinates.position === 'after' ? 1 : -1);
    const xStart = coordinates.position === 'after' ? coordinates.x : coordinates.x + coordinates.width;
    const xEnd = xStart + widthOffset + (widthOffset / 2) * threshold;
    const yStart = coordinates.position === 'after' ? coordinates.y : coordinates.y + coordinates.height;
    const yEnd = yStart + heightOffset + (heightOffset / 2) * threshold;
    return {
        x: {
            start: xStart > xEnd ? xEnd : xStart,
            end: xStart > xEnd ? xStart : xEnd
        },
        y: {
            start: yStart > yEnd ? yEnd : yStart,
            end: yStart > yEnd ? yStart : yEnd
        }
    };
}

class DragAndDropModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: DragAndDropModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "19.2.3", ngImport: i0, type: DragAndDropModule, imports: [DragDropModule, DndItemDirective, DndListDirective, DndKeyboardGroupDirective, DndKeyboardItemDirective], exports: [DndItemDirective, DndListDirective, DndKeyboardGroupDirective, DndKeyboardItemDirective] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: DragAndDropModule, imports: [DragDropModule] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: DragAndDropModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [DragDropModule, DndItemDirective, DndListDirective, DndKeyboardGroupDirective, DndKeyboardItemDirective],
                    exports: [DndItemDirective, DndListDirective, DndKeyboardGroupDirective, DndKeyboardItemDirective]
                }]
        }] });

class UtilsModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: UtilsModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "19.2.3", ngImport: i0, type: UtilsModule, imports: [FocusableItemModule,
            FocusableListModule,
            FocusableGridModule,
            DragAndDropModule,
            OnlyDigitsModule,
            TruncateModule,
            LineClampModule,
            OverflowListModule,
            RepeatModule,
            ResizeModule,
            TemplateModule,
            AutoCompleteModule,
            DisabledBehaviorModule,
            SelectableListModule,
            ReadonlyBehaviorModule,
            ClickedDirective,
            InitialFocusModule,
            BreakpointModule,
            IntersectionSpyDirective], exports: [FocusableItemModule,
            FocusableListModule,
            FocusableGridModule,
            DragAndDropModule,
            OnlyDigitsModule,
            TruncateModule,
            LineClampModule,
            OverflowListModule,
            RepeatModule,
            ResizeModule,
            TemplateModule,
            AutoCompleteModule,
            DisabledBehaviorModule,
            SelectableListModule,
            ReadonlyBehaviorModule,
            ClickedDirective,
            InitialFocusModule,
            BreakpointModule,
            IntersectionSpyDirective] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: UtilsModule, providers: [RtlService], imports: [FocusableItemModule,
            FocusableListModule,
            FocusableGridModule,
            DragAndDropModule,
            OnlyDigitsModule,
            TruncateModule,
            LineClampModule,
            OverflowListModule,
            RepeatModule,
            ResizeModule,
            TemplateModule,
            AutoCompleteModule,
            DisabledBehaviorModule,
            SelectableListModule,
            ReadonlyBehaviorModule,
            InitialFocusModule,
            BreakpointModule, FocusableItemModule,
            FocusableListModule,
            FocusableGridModule,
            DragAndDropModule,
            OnlyDigitsModule,
            TruncateModule,
            LineClampModule,
            OverflowListModule,
            RepeatModule,
            ResizeModule,
            TemplateModule,
            AutoCompleteModule,
            DisabledBehaviorModule,
            SelectableListModule,
            ReadonlyBehaviorModule,
            InitialFocusModule,
            BreakpointModule] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: UtilsModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [
                        FocusableItemModule,
                        FocusableListModule,
                        FocusableGridModule,
                        DragAndDropModule,
                        OnlyDigitsModule,
                        TruncateModule,
                        LineClampModule,
                        OverflowListModule,
                        RepeatModule,
                        ResizeModule,
                        TemplateModule,
                        AutoCompleteModule,
                        DisabledBehaviorModule,
                        SelectableListModule,
                        ReadonlyBehaviorModule,
                        ClickedDirective,
                        InitialFocusModule,
                        BreakpointModule,
                        IntersectionSpyDirective
                    ],
                    exports: [
                        FocusableItemModule,
                        FocusableListModule,
                        FocusableGridModule,
                        DragAndDropModule,
                        OnlyDigitsModule,
                        TruncateModule,
                        LineClampModule,
                        OverflowListModule,
                        RepeatModule,
                        ResizeModule,
                        TemplateModule,
                        AutoCompleteModule,
                        DisabledBehaviorModule,
                        SelectableListModule,
                        ReadonlyBehaviorModule,
                        ClickedDirective,
                        InitialFocusModule,
                        BreakpointModule,
                        IntersectionSpyDirective
                    ],
                    providers: [RtlService]
                }]
        }] });

/*
 This abstract class allows the user to set their own custom styles on a Fundamental Library for Angular directive, in addition to the
 styles the library needs to add itself.
 When library styles were added through the directive's host: {'[class]'} property, any styles the user added would be
 overwritten.  By extending this class, we instead add library styles to the user's classList rather than replace them.
 */
/** @hidden */
class AbstractFdNgxClass {
    /** @hidden */
    constructor() {
        /** @hidden */
        this.elementRef = inject(ElementRef);
        this._setProperties();
    }
    /*
     each directive that extends this class will implement this function and populate it with one or more calls to
     the '_addClassToElement' function, passing the style names to be added with each call
     */
    /** @hidden */
    _setClassToElement(className) {
        this.elementRef.nativeElement.classList.value = `${className} ${this.class}`;
    }
    /** @hidden */
    _clearElementClass() {
        this.elementRef.nativeElement.classList.value = '';
    }
    /** @hidden */
    _addClassToElement(className) {
        this.elementRef.nativeElement.classList.add(...className.split(' '));
    }
    /** @hidden */
    _addStyleToElement(attribute, value) {
        this.elementRef.nativeElement.style[attribute] = value;
    }
    /** @hidden */
    ngOnChanges() {
        const classList = this.elementRef.nativeElement.classList;
        while (classList.length > 0) {
            // eslint-disable-next-line @typescript-eslint/no-non-null-assertion
            classList.remove(classList.item(0));
        }
        if (this.class) {
            this._addClassToElement(this.class);
        }
        this._setProperties();
    }
    /** @hidden */
    ngOnInit() {
        this._setProperties();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: AbstractFdNgxClass, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "19.2.3", type: AbstractFdNgxClass, isStandalone: true, inputs: { class: "class" }, usesOnChanges: true, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: AbstractFdNgxClass, decorators: [{
            type: Directive
        }], ctorParameters: () => [], propDecorators: { class: [{
                type: Input
            }] } });

/** @hidden */
function coerceArraySafe(value) {
    return isBlank(value) ? [] : coerceArray(value);
}

/**
 * A component that can be used to attach a portal to a DOM element, without explicitly creating portal instances on place.
 * This is useful when you have a list of the components or templates, or HTMLElmets, and you want to attach them to the DOM
 * dynamically in a loop.
 */
class DynamicPortalComponent {
    constructor() {
        /** Emits when the portal is attached */
        this.attached = new EventEmitter();
        /** @hidden */
        this.portalContent$ = new BehaviorSubject(undefined);
        /** @hidden */
        this._destroyRef = inject(DestroyRef);
        /** @hidden */
        this.viewContainerRef = inject(ViewContainerRef);
        /** @hidden */
        this.renderer = inject(Renderer2);
        /** @hidden */
        this.elementRef = inject(ElementRef);
    }
    /** The DOM element to attach */
    set domElement(value) {
        this.portalContent$.next(value);
    }
    /** The component to attach */
    set component(value) {
        this.portalContent$.next(value);
    }
    /** The template to attach */
    set template(value) {
        this.portalContent$.next(value);
    }
    /** The Content which should be attached and can be any of the items */
    set auto(value) {
        this.portalContent$.next(value);
    }
    /** @hidden */
    ngAfterViewInit() {
        const portalOutlet = this.portalOutlet;
        this.portalContent$
            .pipe(tap$1(() => portalOutlet.detach()), filter$1(Boolean), map$1((content) => {
            if (typeof content === 'string') {
                const textElement = this.renderer.createText(content);
                this.renderer.appendChild(this.elementRef.nativeElement, textElement);
                return new DomPortal(textElement);
            }
            else if (content instanceof HTMLElement || content instanceof ElementRef) {
                return new DomPortal(coerceElement(content));
            }
            else if (content instanceof TemplateRef) {
                return new TemplatePortal(content, this.viewContainerRef);
            }
            return new ComponentPortal(content);
        }), filter$1(Boolean), takeUntilDestroyed(this._destroyRef))
            .subscribe((portal) => {
            const ref = portalOutlet.attach(portal);
            if (portal instanceof DomPortal) {
                // DomPortal Attachment does not refer return Ref, like other portals
                this.attached.emit(portal.element);
            }
            else {
                this.attached.emit(ref);
            }
        });
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: DynamicPortalComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "19.2.3", type: DynamicPortalComponent, isStandalone: true, selector: "fdk-dynamic-portal", inputs: { domElement: "domElement", component: "component", template: "template", auto: "auto" }, outputs: { attached: "attached" }, viewQueries: [{ propertyName: "portalOutlet", first: true, predicate: CdkPortalOutlet, descendants: true }], ngImport: i0, template: ` <ng-template cdkPortalOutlet></ng-template>`, isInline: true, dependencies: [{ kind: "ngmodule", type: PortalModule }, { kind: "directive", type: i1$3.CdkPortalOutlet, selector: "[cdkPortalOutlet]", inputs: ["cdkPortalOutlet"], outputs: ["attached"], exportAs: ["cdkPortalOutlet"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: DynamicPortalComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'fdk-dynamic-portal',
                    imports: [PortalModule],
                    template: ` <ng-template cdkPortalOutlet></ng-template>`
                }]
        }], propDecorators: { domElement: [{
                type: Input
            }], component: [{
                type: Input
            }], template: [{
                type: Input
            }], auto: [{
                type: Input
            }], attached: [{
                type: Output
            }], portalOutlet: [{
                type: ViewChild,
                args: [CdkPortalOutlet]
            }] } });

const MOBILE_CONFIG_ERROR = `Missing configuration object for mobile version of the component.
    Consult the documentation on how to provide MobileModeConfiguration object for this component.
`;
const THEME_SWITCHER_ROUTER_MISSING_ERROR = `You need to import RouterModule to enable theme settings via the url.`;
const INVALID_DATE_ERROR = 'Invalid Date';

const OVERFLOW_PRIORITY_SCORE = new Map([
    ['always', 0],
    ['disappear', 1],
    ['low', 2],
    ['high', 3],
    ['never', 4]
]);

/**
 * Instead of `/\p{L}/u` because of it's not working in IE11 and Edge
 * - https://github.com/Microsoft/ChakraCore/issues/2969
 * */
// eslint-disable-next-line max-len
const LETTERS_UNICODE_RANGE = `[A-Za-z\u00AA\u00B5\u00BA\u00C0-\u00D6\u00D8-\u00F6\u00F8-\u02C1\u02C6-\u02D1\u02E0-\u02E4\u02EC\u02EE\u0370-\u0374\u0376\u0377\u037A-\u037D\u037F\u0386\u0388-\u038A\u038C\u038E-\u03A1\u03A3-\u03F5\u03F7-\u0481\u048A-\u052F\u0531-\u0556\u0559\u0561-\u0587\u05D0-\u05EA\u05F0-\u05F2\u0620-\u064A\u066E\u066F\u0671-\u06D3\u06D5\u06E5\u06E6\u06EE\u06EF\u06FA-\u06FC\u06FF\u0710\u0712-\u072F\u074D-\u07A5\u07B1\u07CA-\u07EA\u07F4\u07F5\u07FA\u0800-\u0815\u081A\u0824\u0828\u0840-\u0858\u08A0-\u08B4\u0904-\u0939\u093D\u0950\u0958-\u0961\u0971-\u0980\u0985-\u098C\u098F\u0990\u0993-\u09A8\u09AA-\u09B0\u09B2\u09B6-\u09B9\u09BD\u09CE\u09DC\u09DD\u09DF-\u09E1\u09F0\u09F1\u0A05-\u0A0A\u0A0F\u0A10\u0A13-\u0A28\u0A2A-\u0A30\u0A32\u0A33\u0A35\u0A36\u0A38\u0A39\u0A59-\u0A5C\u0A5E\u0A72-\u0A74\u0A85-\u0A8D\u0A8F-\u0A91\u0A93-\u0AA8\u0AAA-\u0AB0\u0AB2\u0AB3\u0AB5-\u0AB9\u0ABD\u0AD0\u0AE0\u0AE1\u0AF9\u0B05-\u0B0C\u0B0F\u0B10\u0B13-\u0B28\u0B2A-\u0B30\u0B32\u0B33\u0B35-\u0B39\u0B3D\u0B5C\u0B5D\u0B5F-\u0B61\u0B71\u0B83\u0B85-\u0B8A\u0B8E-\u0B90\u0B92-\u0B95\u0B99\u0B9A\u0B9C\u0B9E\u0B9F\u0BA3\u0BA4\u0BA8-\u0BAA\u0BAE-\u0BB9\u0BD0\u0C05-\u0C0C\u0C0E-\u0C10\u0C12-\u0C28\u0C2A-\u0C39\u0C3D\u0C58-\u0C5A\u0C60\u0C61\u0C85-\u0C8C\u0C8E-\u0C90\u0C92-\u0CA8\u0CAA-\u0CB3\u0CB5-\u0CB9\u0CBD\u0CDE\u0CE0\u0CE1\u0CF1\u0CF2\u0D05-\u0D0C\u0D0E-\u0D10\u0D12-\u0D3A\u0D3D\u0D4E\u0D5F-\u0D61\u0D7A-\u0D7F\u0D85-\u0D96\u0D9A-\u0DB1\u0DB3-\u0DBB\u0DBD\u0DC0-\u0DC6\u0E01-\u0E30\u0E32\u0E33\u0E40-\u0E46\u0E81\u0E82\u0E84\u0E87\u0E88\u0E8A\u0E8D\u0E94-\u0E97\u0E99-\u0E9F\u0EA1-\u0EA3\u0EA5\u0EA7\u0EAA\u0EAB\u0EAD-\u0EB0\u0EB2\u0EB3\u0EBD\u0EC0-\u0EC4\u0EC6\u0EDC-\u0EDF\u0F00\u0F40-\u0F47\u0F49-\u0F6C\u0F88-\u0F8C\u1000-\u102A\u103F\u1050-\u1055\u105A-\u105D\u1061\u1065\u1066\u106E-\u1070\u1075-\u1081\u108E\u10A0-\u10C5\u10C7\u10CD\u10D0-\u10FA\u10FC-\u1248\u124A-\u124D\u1250-\u1256\u1258\u125A-\u125D\u1260-\u1288\u128A-\u128D\u1290-\u12B0\u12B2-\u12B5\u12B8-\u12BE\u12C0\u12C2-\u12C5\u12C8-\u12D6\u12D8-\u1310\u1312-\u1315\u1318-\u135A\u1380-\u138F\u13A0-\u13F5\u13F8-\u13FD\u1401-\u166C\u166F-\u167F\u1681-\u169A\u16A0-\u16EA\u16F1-\u16F8\u1700-\u170C\u170E-\u1711\u1720-\u1731\u1740-\u1751\u1760-\u176C\u176E-\u1770\u1780-\u17B3\u17D7\u17DC\u1820-\u1877\u1880-\u18A8\u18AA\u18B0-\u18F5\u1900-\u191E\u1950-\u196D\u1970-\u1974\u1980-\u19AB\u19B0-\u19C9\u1A00-\u1A16\u1A20-\u1A54\u1AA7\u1B05-\u1B33\u1B45-\u1B4B\u1B83-\u1BA0\u1BAE\u1BAF\u1BBA-\u1BE5\u1C00-\u1C23\u1C4D-\u1C4F\u1C5A-\u1C7D\u1CE9-\u1CEC\u1CEE-\u1CF1\u1CF5\u1CF6\u1D00-\u1DBF\u1E00-\u1F15\u1F18-\u1F1D\u1F20-\u1F45\u1F48-\u1F4D\u1F50-\u1F57\u1F59\u1F5B\u1F5D\u1F5F-\u1F7D\u1F80-\u1FB4\u1FB6-\u1FBC\u1FBE\u1FC2-\u1FC4\u1FC6-\u1FCC\u1FD0-\u1FD3\u1FD6-\u1FDB\u1FE0-\u1FEC\u1FF2-\u1FF4\u1FF6-\u1FFC\u2071\u207F\u2090-\u209C\u2102\u2107\u210A-\u2113\u2115\u2119-\u211D\u2124\u2126\u2128\u212A-\u212D\u212F-\u2139\u213C-\u213F\u2145-\u2149\u214E\u2183\u2184\u2C00-\u2C2E\u2C30-\u2C5E\u2C60-\u2CE4\u2CEB-\u2CEE\u2CF2\u2CF3\u2D00-\u2D25\u2D27\u2D2D\u2D30-\u2D67\u2D6F\u2D80-\u2D96\u2DA0-\u2DA6\u2DA8-\u2DAE\u2DB0-\u2DB6\u2DB8-\u2DBE\u2DC0-\u2DC6\u2DC8-\u2DCE\u2DD0-\u2DD6\u2DD8-\u2DDE\u2E2F\u3005\u3006\u3031-\u3035\u303B\u303C\u3041-\u3096\u309D-\u309F\u30A1-\u30FA\u30FC-\u30FF\u3105-\u312D\u3131-\u318E\u31A0-\u31BA\u31F0-\u31FF\u3400-\u4DB5\u4E00-\u9FD5\uA000-\uA48C\uA4D0-\uA4FD\uA500-\uA60C\uA610-\uA61F\uA62A\uA62B\uA640-\uA66E\uA67F-\uA69D\uA6A0-\uA6E5\uA717-\uA71F\uA722-\uA788\uA78B-\uA7AD\uA7B0-\uA7B7\uA7F7-\uA801\uA803-\uA805\uA807-\uA80A\uA80C-\uA822\uA840-\uA873\uA882-\uA8B3\uA8F2-\uA8F7\uA8FB\uA8FD\uA90A-\uA925\uA930-\uA946\uA960-\uA97C\uA984-\uA9B2\uA9CF\uA9E0-\uA9E4\uA9E6-\uA9EF\uA9FA-\uA9FE\uAA00-\uAA28\uAA40-\uAA42\uAA44-\uAA4B\uAA60-\uAA76\uAA7A\uAA7E-\uAAAF\uAAB1\uAAB5\uAAB6\uAAB9-\uAABD\uAAC0\uAAC2\uAADB-\uAADD\uAAE0-\uAAEA\uAAF2-\uAAF4\uAB01-\uAB06\uAB09-\uAB0E\uAB11-\uAB16\uAB20-\uAB26\uAB28-\uAB2E\uAB30-\uAB5A\uAB5C-\uAB65\uAB70-\uABE2\uAC00-\uD7A3\uD7B0-\uD7C6\uD7CB-\uD7FB\uF900-\uFA6D\uFA70-\uFAD9\uFB00-\uFB06\uFB13-\uFB17\uFB1D\uFB1F-\uFB28\uFB2A-\uFB36\uFB38-\uFB3C\uFB3E\uFB40\uFB41\uFB43\uFB44\uFB46-\uFBB1\uFBD3-\uFD3D\uFD50-\uFD8F\uFD92-\uFDC7\uFDF0-\uFDFB\uFE70-\uFE74\uFE76-\uFEFC\uFF21-\uFF3A\uFF41-\uFF5A\uFF66-\uFFBE\uFFC2-\uFFC7\uFFCA-\uFFCF\uFFD2-\uFFD7\uFFDA-\uFFDC]`;
// eslint-disable-next-line max-len
const ANY_LANGUAGE_LETTERS_REGEX = new RegExp(LETTERS_UNICODE_RANGE, 'g');
// eslint-disable-next-line max-len
const ANY_LANGUAGE_LETTERS_GROUP_REGEX = new RegExp(`(${LETTERS_UNICODE_RANGE})+`, 'g');

/**
 * Polyfill for `/\p{Nd}/u` to work in IE11 and Edge
 */
// eslint-disable-next-line max-len
const DECIMAL_NUMBER_UNICODE_RANGE = `[0-9\u0660-\u0669\u06F0-\u06F9\u07C0-\u07C9\u0966-\u096F\u09E6-\u09EF\u0A66-\u0A6F\u0AE6-\u0AEF\u0B66-\u0B6F\u0BE6-\u0BEF\u0C66-\u0C6F\u0CE6-\u0CEF\u0D66-\u0D6F\u0DE6-\u0DEF\u0E50-\u0E59\u0ED0-\u0ED9\u0F20-\u0F29\u1040-\u1049\u1090-\u1099\u17E0-\u17E9\u1810-\u1819\u1946-\u194F\u19D0-\u19D9\u1A80-\u1A89\u1A90-\u1A99\u1B50-\u1B59\u1BB0-\u1BB9\u1C40-\u1C49\u1C50-\u1C59\uA620-\uA629\uA8D0-\uA8D9\uA900-\uA909\uA9D0-\uA9D9\uA9F0-\uA9F9\uAA50-\uAA59\uABF0-\uABF9\uFF10-\uFF19]`;
const DECIMAL_NUMBER_UNICODE_REGEX = new RegExp(DECIMAL_NUMBER_UNICODE_RANGE, 'g');
const DECIMAL_NUMBER_UNICODE_GROUP_REGEX = new RegExp(`(${DECIMAL_NUMBER_UNICODE_RANGE})+`, 'g');

const ELEMENT_REF_EXCEPTION = 'HasElementRef interface has to be implemented';

/**
 * Method decorator to apply css class to a component through native element
 * decorator will store original method in variable and wrap it with custom one
 * component has to implement CssClassBuilder interface
 * more info abour method decorator: https://www.typescriptlang.org/docs/handbook/decorators.html#method-decorators
 * @param target a component
 * @param propertyKey name of the method
 * @param descriptor method
 */
function applyCssClass(target, propertyKey, descriptor) {
    const originalMethod = descriptor.value;
    descriptor.value = function () {
        const self = this;
        if (!('elementRef' in self)) {
            throw ELEMENT_REF_EXCEPTION;
        }
        const classListToApply = sanitize(originalMethod.apply(this));
        const elementRef = self.elementRef;
        const nativeElement = elementRef?.nativeElement;
        if (!nativeElement) {
            return classListToApply;
        }
        if (!nativeElement._classMap) {
            nativeElement._classMap = {};
        }
        if (!self._uuidv4) {
            self._uuidv4 = uuidv4();
        }
        const currentClassList = Array.from(nativeElement.classList);
        const previousClassListToApply = nativeElement._classMap[self._uuidv4] || [];
        const newClassList = createComponentClassList(currentClassList, previousClassListToApply, classListToApply);
        nativeElement.className = newClassList.join(' ');
        nativeElement._classMap[self._uuidv4] = classListToApply;
        return classListToApply;
    };
}
/** Filter list to unique items */
function unique(value, index, list) {
    return list.indexOf(value) === index;
}
/** Splits merged classes, removes falsy elements and leaves only unique items */
function sanitize(array) {
    return array
        .filter(Boolean)
        .reduce((classList, cssClass) => [...classList, ...cssClass.split(/\s+/)], [])
        .filter(unique);
}
function firstCommonElementIndex(array1, array2) {
    return array1.findIndex((element) => array2.indexOf(element) !== -1);
}
/** Create set of component classes based on previous set and new set */
function createComponentClassList(allClasses, previousComponentClassList, newComponentClassList) {
    allClasses = allClasses.slice();
    let index = firstCommonElementIndex(allClasses, previousComponentClassList);
    index = index === -1 ? 0 : index;
    allClasses.splice(index, previousComponentClassList.length, ...newComponentClassList);
    return allClasses;
}

/**
 * Method decorator to apply css styles to a component through native element
 * decorator will store original method in variable and wrap it with custom one
 * component has to implement HasElementRef or CssStyleBuilder interface
 * more info abour method decorator: https://www.typescriptlang.org/docs/handbook/decorators.html#method-decorators
 * @param target a component
 * @param propertyKey name of the method
 * @param descriptor method
 */
function applyCssStyle(target, propertyKey, descriptor) {
    const originalMethod = descriptor.value;
    descriptor.value = function () {
        const self = this;
        if (!self.elementRef) {
            throw ELEMENT_REF_EXCEPTION;
        }
        const _styles = originalMethod.apply(this);
        const htmlElement = self.elementRef.nativeElement;
        Object.keys(_styles).forEach((key) => {
            htmlElement.style[key] = _styles[key];
        });
        return _styles;
    };
}

/**
 * Function, which generates decorator. Passed mutator will be called during value set
 */
function alternateSetter(mutator) {
    return function (targetObj, propertyKey) {
        const _key = Symbol();
        targetObj[_key] = targetObj[propertyKey];
        Object.defineProperty(targetObj, propertyKey, {
            get() {
                return this[_key];
            },
            set(v) {
                this[_key] = mutator.call(this, v, this);
            }
        });
    };
}

/**
 * Decorator for coercing passed value to boolean, using @angular/cdk coerceBooleanProperty
 */
const coerceBoolean = alternateSetter(coerceBooleanProperty);

const coerceCssPixel = alternateSetter(coerceCssPixelValue);

/** @hidden */
function getDeprecatedModel(current, deprecated) {
    return {
        current,
        deprecated
    };
}
/** @hidden */
function deprecatedModelProvider(current, deprecated) {
    return {
        provide: FD_DEPRECATED_DIRECTIVE_SELECTOR,
        useValue: getDeprecatedModel(current, deprecated)
    };
}
const FD_DEPRECATED_DIRECTIVE_SELECTOR = new InjectionToken('FdDeprecatedDirectiveSelector');
class DeprecatedSelector {
    /** @hidden */
    constructor() {
        /** @hidden */
        this._selectors = inject(FD_DEPRECATED_DIRECTIVE_SELECTOR, { optional: true });
        if (isDevMode() && this._selectors) {
            console.warn(this._messageGenerator(this._selectors.deprecated, this._selectors.current));
        }
    }
    /** @hidden */
    _messageGenerator(deprecated, current) {
        const segments = [`${deprecated} selector(s) are deprecated and may affect input properties`];
        if (current) {
            segments.push(`Use ${current} instead.`);
        }
        return segments.join('. ');
    }
}

class DynamicComponentContainer {
    /** @hidden */
    constructor(elementRef, _injector) {
        this.elementRef = elementRef;
        this._injector = _injector;
        /** @hidden */
        this.childContent = undefined;
        /** @hidden */
        this._contentLoaded$ = new BehaviorSubject(false);
    }
    /** @hidden Load received content as component */
    _createFromComponent(content) {
        this.portalOutlet?.attachedRef?.destroy();
        const injector = Injector.create({
            parent: this._injector,
            providers: []
        });
        this._componentRef = this.portalOutlet.attach(new ComponentPortal(content, null, injector));
    }
    /** @hidden Load received content as embedded view */
    _createFromTemplate(content, context) {
        this.portalOutlet?.attachedRef?.destroy();
        if (this.portalOutlet.hasAttached()) {
            this.portalOutlet.detach();
        }
        this._componentRef = this.portalOutlet.attach(new TemplatePortal(content, null, context));
    }
}

class DynamicComponentInjector {
    /** @hidden */
    constructor(_parentInjector, _additionalTokens) {
        this._parentInjector = _parentInjector;
        this._additionalTokens = _additionalTokens;
    }
    /**
     *
     * @param token
     * @param notFoundValue
     */
    get(token, notFoundValue) {
        const value = this._additionalTokens.get(token);
        if (value) {
            return value;
        }
        return this._parentInjector.get(token, notFoundValue);
    }
}

/**
 * Service used to dynamically generate components like dialogs/alerts/notifications
 */
class DynamicComponentService {
    /** @hidden */
    constructor(_componentFactoryResolver, _applicationRef, _injector, _compiler) {
        this._componentFactoryResolver = _componentFactoryResolver;
        this._applicationRef = _applicationRef;
        this._injector = _injector;
        this._compiler = _compiler;
    }
    /**
     * Function that creates dynamic component and injects services to allow communication between component and outside
     * @param content Type of the component content
     * @param componentType Type of component that should be rendered.
     * @param config Configuration that will be passed to the component.
     * @param inject  enables to provide preconfigured component injector and dependencies
     */
    createDynamicComponent(content, componentType, config, inject = {}) {
        const { injector, services } = inject;
        const dependenciesMap = this._createDependencyMap(services);
        const componentRef = this._createComponent(componentType, dependenciesMap, injector);
        this._passExternalContent(componentRef, content);
        this._attachToContainer(componentRef, config);
        return componentRef;
    }
    /**
     * Function that creates dynamic component and injects services to allow communication between component and outside
     * @param content Type of the component content
     * @param moduleType Type of module that should be compiled.
     * @param componentType Type of component that should be rendered.
     * @param containerRef The container that the dynamic component is appended to.
     * @param injector enables to provide preconfigured component injector
     */
    async createDynamicModule(content, moduleType, componentType, containerRef, injector) {
        const moduleFactory = moduleType instanceof NgModuleFactory ? moduleType : await this._compiler.compileModuleAsync(moduleType);
        const moduleRef = moduleFactory.create(injector || this._injector);
        const componentFactory = moduleRef.componentFactoryResolver.resolveComponentFactory(componentType);
        containerRef.clear();
        const componentRef = containerRef.createComponent(componentFactory);
        this._passExternalContent(componentRef, content);
        return componentRef;
    }
    /** Function that destroys dynamic component */
    destroyComponent(componentRef) {
        this._applicationRef.detachView(componentRef.hostView);
        componentRef.hostView.detach();
        componentRef.destroy();
    }
    /** @hidden */
    _createDependencyMap(services = []) {
        const dependencyMap = new WeakMap();
        services.filter((service) => !!service).forEach((service) => dependencyMap.set(service.constructor, service));
        return dependencyMap;
    }
    /** @hidden */
    _attachToContainer(componentRef, config) {
        const configObj = Object.assign({}, config);
        if (config.containerRef) {
            componentRef.hostView.detach();
            config.containerRef.insert(componentRef.hostView);
            return;
        }
        this._applicationRef.attachView(componentRef.hostView);
        const componentEl = componentRef.hostView.rootNodes[0];
        if (configObj.container !== 'body') {
            configObj.container?.appendChild(componentEl);
        }
        else {
            document.body.appendChild(componentEl);
        }
    }
    /** @hidden */
    _createComponent(componentType, dependenciesMap, injector) {
        const dynamicComponentInjector = new DynamicComponentInjector(injector || this._injector, dependenciesMap);
        const componentFactory = this._componentFactoryResolver.resolveComponentFactory(componentType);
        const componentRef = componentFactory.create(dynamicComponentInjector);
        // this._applicationRef.attachView(componentRef.hostView);
        return componentRef;
    }
    /** @hidden */
    _passExternalContent(componentRef, content) {
        // TODO: this approach should be revisited, it can cause issues, that is really hard to debug
        if (Object.prototype.hasOwnProperty.call(componentRef.instance, 'childContent')) {
            componentRef.instance.childContent = content;
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: DynamicComponentService, deps: [{ token: i0.ComponentFactoryResolver }, { token: i0.ApplicationRef }, { token: i0.Injector }, { token: i0.Compiler }], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: DynamicComponentService, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: DynamicComponentService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: () => [{ type: i0.ComponentFactoryResolver }, { type: i0.ApplicationRef }, { type: i0.Injector }, { type: i0.Compiler }] });

const LIST_ITEM_COMPONENT = new InjectionToken('ListItemComponent');

class AsyncOrSyncPipe {
    /** @hidden */
    constructor(ref) {
        this._cdr = ref;
        this._asyncPipe = new AsyncPipe(this._cdr);
    }
    /**
     * Transforms raw async-like value into static one.
     * @param value raw value. Can be either a static value, or Promise-like, or Observable-like.
     */
    transform(value) {
        return !isPromise(value) && !isSubscribable(value) ? value : (this._asyncPipe?.transform(value) ?? null);
    }
    /** @Hidden */
    ngOnDestroy() {
        this._asyncPipe?.ngOnDestroy();
        this._asyncPipe = null;
        this._cdr = null;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: AsyncOrSyncPipe, deps: [{ token: i0.ChangeDetectorRef }], target: i0.ɵɵFactoryTarget.Pipe }); }
    static { this.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "19.2.3", ngImport: i0, type: AsyncOrSyncPipe, isStandalone: true, name: "fdkAsyncOrSync", pure: false }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: AsyncOrSyncPipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'fdkAsyncOrSync',
                    standalone: true,
                    pure: false
                }]
        }], ctorParameters: () => [{ type: i0.ChangeDetectorRef }] });

class DisplayFnPipe {
    /** Transform value with display function. */
    transform(value, displayFn, ...args) {
        return displayFn(value, ...args);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: DisplayFnPipe, deps: [], target: i0.ɵɵFactoryTarget.Pipe }); }
    static { this.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "19.2.3", ngImport: i0, type: DisplayFnPipe, isStandalone: true, name: "displayFnPipe" }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: DisplayFnPipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'displayFnPipe',
                    standalone: true
                }]
        }] });

class FilterStringsPipe {
    /**
     * Performs filtering.
     * @param values Array of items.
     * @param params Search parameters.
     */
    transform(values = [], params) {
        if (!params.searchTerm) {
            return values;
        }
        if (params.key) {
            values = values.filter((item) => item[params.key].toLocaleLowerCase().includes(params.searchTerm?.toLocaleLowerCase()));
        }
        else {
            values = values.filter((item) => item.toLocaleLowerCase().includes(params.searchTerm?.toLocaleLowerCase()));
        }
        return values;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: FilterStringsPipe, deps: [], target: i0.ɵɵFactoryTarget.Pipe }); }
    static { this.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "19.2.3", ngImport: i0, type: FilterStringsPipe, isStandalone: true, name: "fdFilterStrings" }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: FilterStringsPipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'fdFilterStrings',
                    standalone: true
                }]
        }] });

class IsCompactDensityPipe {
    /** Check if the content density is compact. */
    transform(size) {
        return isCompactDensity(size);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: IsCompactDensityPipe, deps: [], target: i0.ɵɵFactoryTarget.Pipe }); }
    static { this.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "19.2.3", ngImport: i0, type: IsCompactDensityPipe, isStandalone: true, name: "isCompactDensity" }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: IsCompactDensityPipe, decorators: [{
            type: Pipe,
            args: [{ name: 'isCompactDensity', standalone: true }]
        }] });

class MakeAsyncPipe {
    /**
     * Transforms raw value into observable.
     * @param value raw value. Can be either a static value, or Promise-like, or Observable-like.
     */
    transform(value) {
        return isPromise(value) || isSubscribable(value) ? value : of(value);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: MakeAsyncPipe, deps: [], target: i0.ɵɵFactoryTarget.Pipe }); }
    static { this.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "19.2.3", ngImport: i0, type: MakeAsyncPipe, isStandalone: true, name: "fdkMakeAsync" }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: MakeAsyncPipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'fdkMakeAsync',
                    pure: true,
                    standalone: true
                }]
        }] });

class SafePipe {
    /** @hidden */
    constructor(sanitizer) {
        this.sanitizer = sanitizer;
    }
    /** Sanitize HTML string. */
    transform(value, type) {
        switch (type) {
            case 'html':
                return this.sanitizer.bypassSecurityTrustHtml(value);
            case 'style':
                return this.sanitizer.bypassSecurityTrustStyle(value);
            case 'script':
                return this.sanitizer.bypassSecurityTrustScript(value);
            case 'url':
                return this.sanitizer.bypassSecurityTrustUrl(value);
            case 'resourceUrl':
                return this.sanitizer.bypassSecurityTrustResourceUrl(value);
            default:
                throw new Error(`Invalid safe type specified: ${type}`);
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: SafePipe, deps: [{ token: i1$4.DomSanitizer }], target: i0.ɵɵFactoryTarget.Pipe }); }
    static { this.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "19.2.3", ngImport: i0, type: SafePipe, isStandalone: true, name: "safe" }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: SafePipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'safe',
                    standalone: true
                }]
        }], ctorParameters: () => [{ type: i1$4.DomSanitizer }] });

class SearchHighlightPipe {
    /** Highlight search term in string. */
    transform(value, matches, active = true, includeSpans = false) {
        value = escape(value);
        let result = value;
        if (value && active && matches) {
            if (Array.isArray(matches)) {
                matches.forEach((match) => {
                    const matchingString = value.substring(match[0], match[1] + 1);
                    result = result.replace(matchingString, '<strong>' + matchingString + '</strong>');
                });
            }
            else if (typeof matches === 'string') {
                const testStr = escape(matches.trim().toLowerCase());
                const startIndex = value.toLowerCase().indexOf(testStr);
                if (startIndex !== -1) {
                    const matchingString = value.substring(startIndex, startIndex + testStr.length);
                    result = value.replace(matchingString, '<strong>' + matchingString + '</strong>');
                }
            }
        }
        if (includeSpans) {
            result = '<span>' + result + '</span>';
        }
        return result;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: SearchHighlightPipe, deps: [], target: i0.ɵɵFactoryTarget.Pipe }); }
    static { this.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "19.2.3", ngImport: i0, type: SearchHighlightPipe, isStandalone: true, name: "highlight" }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: SearchHighlightPipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'highlight',
                    standalone: true
                }]
        }] });

class TruncatePipe {
    /** Truncate string to given length. */
    transform(value, limit = 500) {
        return value && value.length > limit ? value.substring(0, limit) + '...' : value;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: TruncatePipe, deps: [], target: i0.ɵɵFactoryTarget.Pipe }); }
    static { this.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "19.2.3", ngImport: i0, type: TruncatePipe, isStandalone: true, name: "truncate" }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: TruncatePipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'truncate',
                    standalone: true
                }]
        }] });

class TwoDigitsPipe {
    /** Transform number to two digits. */
    transform(value, enable = true) {
        if ((value || value === 0) && enable) {
            return value < 10 ? '0' + value : value.toString();
        }
        else {
            return String(value);
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: TwoDigitsPipe, deps: [], target: i0.ɵɵFactoryTarget.Pipe }); }
    static { this.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "19.2.3", ngImport: i0, type: TwoDigitsPipe, isStandalone: true, name: "twoDigits" }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: TwoDigitsPipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'twoDigits',
                    standalone: true
                }]
        }] });

class ValueByPathPipe {
    /** Get value by path. */
    transform(value, key) {
        return get(value, key);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: ValueByPathPipe, deps: [], target: i0.ɵɵFactoryTarget.Pipe }); }
    static { this.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "19.2.3", ngImport: i0, type: ValueByPathPipe, isStandalone: true, name: "valueByPath" }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: ValueByPathPipe, decorators: [{
            type: Pipe,
            args: [{ name: 'valueByPath', standalone: true }]
        }] });

class PipeModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: PipeModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "19.2.3", ngImport: i0, type: PipeModule, imports: [DisplayFnPipe,
            SearchHighlightPipe,
            TwoDigitsPipe,
            SafePipe,
            ValueByPathPipe,
            IsCompactDensityPipe,
            TruncatePipe,
            FilterStringsPipe,
            MakeAsyncPipe,
            AsyncOrSyncPipe], exports: [DisplayFnPipe,
            SearchHighlightPipe,
            TwoDigitsPipe,
            SafePipe,
            ValueByPathPipe,
            IsCompactDensityPipe,
            TruncatePipe,
            FilterStringsPipe,
            MakeAsyncPipe,
            AsyncOrSyncPipe] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: PipeModule }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: PipeModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [
                        DisplayFnPipe,
                        SearchHighlightPipe,
                        TwoDigitsPipe,
                        SafePipe,
                        ValueByPathPipe,
                        IsCompactDensityPipe,
                        TruncatePipe,
                        FilterStringsPipe,
                        MakeAsyncPipe,
                        AsyncOrSyncPipe
                    ],
                    exports: [
                        DisplayFnPipe,
                        SearchHighlightPipe,
                        TwoDigitsPipe,
                        SafePipe,
                        ValueByPathPipe,
                        IsCompactDensityPipe,
                        TruncatePipe,
                        FilterStringsPipe,
                        MakeAsyncPipe,
                        AsyncOrSyncPipe
                    ]
                }]
        }] });

/**
 * Animations used by the Toast components.
 */
const baseToastAnimations = {
    /** Animation that shows and hides Toast. */
    toastState: trigger('state', [
        state('void, hidden', style({
            transform: 'translateY(1rem)',
            opacity: 0
        })),
        state('visible', style({
            transform: 'translateY(0)',
            opacity: 1
        })),
        transition('* => visible', animate('150ms cubic-bezier(0, 0, 0.2, 1)')),
        transition('* => void, * => hidden', animate('75ms cubic-bezier(0.4, 0.0, 1, 1)', style({
            opacity: 0
        })))
    ])
};

const toastConnectedTopPosition = {
    originX: 'center',
    originY: 'bottom',
    overlayX: 'center',
    overlayY: 'top',
    offsetY: 16
};
const toastConnectedTopLeftPosition = {
    ...toastConnectedTopPosition,
    ...{ overlayX: 'start', originX: 'start' }
};
const toastConnectedTopRightPosition = {
    ...toastConnectedTopPosition,
    ...{ overlayX: 'end', originX: 'end' }
};
const toastConnectedBottomPosition = {
    originX: 'center',
    originY: 'top',
    overlayX: 'center',
    overlayY: 'bottom',
    offsetY: -16
};
const toastConnectedBottomLeftPosition = {
    ...toastConnectedBottomPosition,
    ...{ overlayX: 'start', originX: 'start' }
};
const toastConnectedBottomRightPosition = {
    ...toastConnectedBottomPosition,
    ...{ overlayX: 'end', originX: 'end' }
};
/**
 * Base Toast Position class.
 */
class BaseToastPosition {
}
/**
 * Toast Position class.
 * The first item will pop from the top-center of the screen.
 * New items will stack after the first item.
 */
class ToastTopCenterPosition extends BaseToastPosition {
    /** @hidden */
    static { this.global = {
        top: '1rem',
        center: true
    }; }
    /** @hidden */
    static { this.connected = toastConnectedTopPosition; }
}
/**
 * Toast Position class.
 * The first item will pop from the bottom-center of the screen.
 * New items will stack before first item.
 */
class ToastBottomCenterPosition extends BaseToastPosition {
    /** @hidden */
    static { this.global = {
        bottom: '1rem',
        center: true
    }; }
    /** @hidden */
    static { this.connected = toastConnectedBottomPosition; }
}
/**
 * Toast Position class.
 * The first item will pop from the top-left of the screen.
 * New items will stack after first item.
 */
class ToastTopLeftPosition extends ToastTopCenterPosition {
    /** @hidden */
    static { this.global = { ...ToastTopCenterPosition.global, ...{ left: '1rem', center: false } }; }
    /** @hidden */
    static { this.connected = toastConnectedTopLeftPosition; }
}
/**
 * Toast Position class.
 * The first item will pop from the top-right of the screen.
 * New items will stack after first item.
 */
class ToastTopRightPosition extends ToastTopCenterPosition {
    /** @hidden */
    static { this.global = { ...ToastTopCenterPosition.global, ...{ right: '1rem', center: false } }; }
    /** @hidden */
    static { this.connected = toastConnectedTopRightPosition; }
}
/**
 * Toast Position class.
 * The first item will pop from the bottom-left of the screen.
 * New items will stack before first item.
 */
class ToastBottomLeftPosition extends ToastBottomCenterPosition {
    /** @hidden */
    static { this.global = { ...ToastBottomCenterPosition.global, ...{ left: '1rem', center: false } }; }
    /** @hidden */
    static { this.connected = toastConnectedBottomLeftPosition; }
}
/**
 * Toast Position class.
 * The first item will pop from the bottom-right of the screen.
 * New items will stack before first item.
 */
class ToastBottomRightPosition extends ToastBottomCenterPosition {
    /** @hidden */
    static { this.global = { ...ToastBottomCenterPosition.global, ...{ right: '1rem', center: false } }; }
    /** @hidden */
    static { this.connected = toastConnectedBottomRightPosition; }
}

class BaseToastService {
    /** @hidden */
    constructor(overlay, injector) {
        this.overlay = overlay;
        this.injector = injector;
        /**
         * @hidden
         * Array of all current toasts.
         */
        this._toasts = [];
        /**
         * @hidden
         */
        this._toastsMap = new Map();
        /** @hidden */
        this._destroyRef = inject(DestroyRef);
    }
    /**
     * Dismisses all Toasts.
     */
    hideAll() {
        this._toasts.forEach((t) => t.dismiss());
    }
    /**
     * Returns `true` if there are some message toasts currently open. `False` otherwise.
     */
    hasOpenMessageToasts() {
        return this._toasts.length > 0;
    }
    /**
     * Sets new position strategy for all Toast items.
     * @param newStrategy New Position Strategy
     */
    setNewPositionStrategy(newStrategy) {
        if (newStrategy === this.toastPositionStrategy) {
            return;
        }
        this.toastPositionStrategy = newStrategy;
        this._refreshOverlayPositions();
    }
    /**
     * @hidden
     * Places a new component or a template as the content of the Toast container.
     */
    _attach(content, userConfig) {
        const config = { ...this.defaultConfig, ...userConfig };
        const positionStrategy = config.positionStrategy || this.toastPositionStrategy;
        const { overlay, isAnchor } = this._createOverlay(positionStrategy);
        const containerRef = this.attachToastContainerComponent(overlay, config);
        const toastRef = this.getToastRef(containerRef, overlay, positionStrategy);
        toastRef._defaultPositionStrategy = !config.positionStrategy;
        toastRef._isAnchor = isAnchor;
        if (content instanceof TemplateRef) {
            // TemplatePortal requires viewContainer ref
            const viewRef = null;
            const portal = new TemplatePortal(content, viewRef, { $implicit: config, toastRef });
            toastRef.instance = containerRef.attachTemplatePortal(portal);
        }
        else {
            const injector = this.createContentComponentInjector(config, toastRef);
            const portal = new ComponentPortal(content, undefined, injector);
            const contentRef = containerRef.attachComponentPortal(portal);
            // We can't pass this via the injector, because the injector is created earlier.
            toastRef.instance = contentRef.instance;
            contentRef.changeDetectorRef.detectChanges();
        }
        const allToasts = this._toastsMap.get(positionStrategy) || [];
        allToasts.push(toastRef);
        this._toasts.push(toastRef);
        this._toastsMap.set(positionStrategy, allToasts);
        this.animateToast(toastRef);
        return toastRef;
    }
    /**
     * Attaches the Toast container component to the overlay.
     */
    attachToastContainerComponent(overlayRef, config) {
        const injector = Injector.create({
            parent: this.injector,
            providers: this.getContainerComponentProviders(config)
        });
        const containerPortal = new ComponentPortal(this.toastContainerComponent, null, injector);
        const containerRef = overlayRef.attach(containerPortal);
        containerRef.instance.config = config;
        containerRef.instance.overlayRef = overlayRef;
        return containerRef.instance;
    }
    /**
     * Creates an injector to be used inside a Toast component.
     * @param config Config that was used to create the Toast.
     * @param toastRef Reference to the Toast.
     */
    createContentComponentInjector(config, toastRef) {
        return Injector.create({
            parent: this.injector,
            providers: this.getContentComponentProviders(config, toastRef)
        });
    }
    /**
     * Animates the old Toast out and the new one in.
     */
    animateToast(toastRef) {
        const positionStrategy = toastRef.positionStrategy;
        // When the toast is dismissed, clear the reference to it.
        toastRef
            .afterDismissed()
            .pipe(takeUntilDestroyed(this._destroyRef))
            .subscribe(() => {
            const allToasts = this._toastsMap.get(positionStrategy) || [];
            allToasts.splice(allToasts.indexOf(toastRef), 1);
            this._toasts.splice(this._toasts.indexOf(toastRef), 1);
            this._toastsMap.set(positionStrategy, allToasts);
            this._refreshOverlayPositions();
        });
        toastRef.containerInstance.enter();
    }
    /**
     * @hidden
     * Creates a new overlay and places it in the correct location.
     */
    _createOverlay(positionStrategy) {
        const overlayConfig = new OverlayConfig();
        overlayConfig.scrollStrategy = positionStrategy.scrollPosition || this.overlay.scrollStrategies.reposition();
        const { position, isAnchor } = this._getPositionStrategy(positionStrategy);
        overlayConfig.positionStrategy = position;
        overlayConfig.panelClass = 'fd-toast-overlay';
        return { overlay: this.overlay.create(overlayConfig), isAnchor };
    }
    /**
     * @hidden
     * @returns Initial Position Strategy of the Toast Overlay Reference.
     */
    _getPositionStrategy(positionStrategy) {
        const lastOverlay = this._getLastToastWithSamePosition(positionStrategy);
        const globalOverlay = this._toastsMap.get(positionStrategy)?.find(({ _isAnchor }) => _isAnchor);
        if (lastOverlay && globalOverlay) {
            return {
                position: this._composeFlexibleConnectedPosition(lastOverlay.overlayRef.overlayElement, positionStrategy),
                isAnchor: false
            };
        }
        return { position: this._composeGlobalPosition(positionStrategy), isAnchor: true };
    }
    /**
     * @hidden
     * @param needlePosition
     * @private
     */
    _getLastToastWithSamePosition(needlePosition) {
        return [...(this._toastsMap.get(needlePosition) || [])]?.reverse()[0];
    }
    /**
     * @hidden
     * @param connectedElm element to connect with.
     * @param positionStrategy Position Strategy
     * @returns Flexible Connected Position Strategy for Overlay Reference.
     */
    _composeFlexibleConnectedPosition(connectedElm, positionStrategy) {
        positionStrategy = positionStrategy || this.toastPositionStrategy;
        return this.overlay
            .position()
            .flexibleConnectedTo(connectedElm)
            .withPush(false)
            .withPositions([positionStrategy.connected]);
    }
    /**
     * @hidden
     * @returns Default Global Position for Overlay Reference.
     */
    _composeGlobalPosition(positionStrategy) {
        let position;
        if (this._isBoundGlobalPosition(positionStrategy.global)) {
            position = this.overlay
                .position()
                .flexibleConnectedTo(positionStrategy.global.boundTo)
                .withPositions([positionStrategy.global])
                .withPush(false);
        }
        else {
            position = this.overlay.position().global();
            const globalToastPositionStrategy = positionStrategy.global;
            for (const [pos, value] of Object.entries(globalToastPositionStrategy)) {
                switch (pos) {
                    case 'left':
                        position.left(value);
                        break;
                    case 'right':
                        position.right(value);
                        break;
                    case 'bottom':
                        position.bottom(value);
                        break;
                    case 'top':
                        position.top(value);
                        break;
                    case 'center':
                        position.centerHorizontally();
                        break;
                    case 'centerVertically':
                        position.centerVertically();
                        break;
                }
            }
        }
        return position;
    }
    /** @hidden */
    _refreshOverlayPositions() {
        this._toastsMap.forEach((toasts) => {
            this._updateOverlayPositionStrategy(toasts);
        });
    }
    /** @hidden */
    _updateOverlayPositionStrategy(toasts) {
        toasts.forEach((toastRef) => {
            const positionStrategy = this._updatePositionStrategy(toastRef);
            const overlayConfig = toastRef.overlayRef.getConfig();
            toastRef.overlayRef.updatePositionStrategy(positionStrategy);
            overlayConfig.positionStrategy = positionStrategy;
        });
    }
    /**
     * @hidden
     * Updates the position of a current Overlay Reference.
     * @returns New Position Strategy.
     * @param toast Toast Reference
     */
    _updatePositionStrategy(toast) {
        const positionStrategy = toast._defaultPositionStrategy ? this.toastPositionStrategy : toast.positionStrategy;
        if (toast._isAnchor) {
            return this._composeGlobalPosition(positionStrategy);
        }
        const toasts = this._toastsMap.get(positionStrategy) || [];
        const globalOverlay = toasts?.find(({ _isAnchor }) => _isAnchor);
        if (!globalOverlay) {
            toast._isAnchor = true;
            return this._composeGlobalPosition(positionStrategy);
        }
        // Get Previous overlay item.
        const overlayItemIndex = toasts.findIndex((t) => t === toast);
        const previousOverlay = toasts[overlayItemIndex - 1];
        toast._isAnchor = false;
        return this._composeFlexibleConnectedPosition(previousOverlay.overlayRef.overlayElement, positionStrategy);
    }
    /** @hidden */
    _isBoundGlobalPosition(position) {
        return !!position.boundTo;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: BaseToastService, deps: [{ token: i1$5.Overlay }, { token: i0.Injector }], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: BaseToastService }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: BaseToastService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1$5.Overlay }, { type: i0.Injector }] });

class BaseToastRef {
    /** @hidden */
    constructor(containerInstance, overlayRef, positionStrategy) {
        this.containerInstance = containerInstance;
        this.overlayRef = overlayRef;
        this.positionStrategy = positionStrategy;
        /** @hidden */
        this._defaultPositionStrategy = true;
        /** @hidden
         * Used for flagging the toast as an anchor for all next appearing toasts.
         */
        this._isAnchor = false;
        /**
         * @hidden
         * Subject for notifying the user that the Toast has been dismissed.
         */
        this._afterDismissed$ = new Subject();
        containerInstance.onExit$.subscribe(() => this._finishDismiss());
    }
    /** Dismisses the Toast. */
    dismiss() {
        if (!this._afterDismissed$.closed) {
            this.containerInstance.exit();
        }
    }
    /** Gets an observable that is notified when the Toast is finished closing. */
    afterDismissed() {
        return this._afterDismissed$.asObservable();
    }
    /** Gets an observable that is notified when the Toast has opened and appeared. */
    afterOpened() {
        return this.containerInstance.onEnter$.asObservable();
    }
    /**
     * @hidden
     * Cleans up the DOM after closing.
     */
    _finishDismiss() {
        this.overlayRef.dispose();
        this._afterDismissed$.next();
        this._afterDismissed$.complete();
    }
}

/** Maximum number of milliseconds that can be passed into setTimeout. */
const MAX_TIMEOUT = Math.pow(2, 31) - 1;
class BaseToastDurationDismissibleRef extends BaseToastRef {
    /** @hidden */
    constructor(containerInstance, overlayRef, positionStrategy) {
        super(containerInstance, overlayRef, positionStrategy);
    }
    /** Dismisses the toast and clears the timeout. */
    dismiss() {
        clearTimeout(this.durationTimeoutId);
        super.dismiss();
    }
    /** Dismisses the Toast component after some duration */
    dismissAfter(duration) {
        this.durationTimeoutId = setTimeout(() => this.dismiss(), Math.min(duration, MAX_TIMEOUT));
    }
    /** Cancels current dismiss timeout */
    cancelDismiss() {
        clearTimeout(this.durationTimeoutId);
    }
}

class BaseToastActionDismissibleRef extends BaseToastDurationDismissibleRef {
    /** @hidden */
    constructor(containerInstance, overlayRef, positionStrategy) {
        super(containerInstance, overlayRef, positionStrategy);
        /** Subject for notifying the user that the Toast action-dismissible was called. */
        this.onAction$ = new Subject();
        /** Whether the Toast was dismissed using the action-dismissible button. */
        this.dismissedByAction = false;
        this.onAction().subscribe(() => this.dismiss());
    }
    /** Marks the Toast action-dismissible clicked. */
    dismissWithAction(reason = null) {
        if (!this.onAction$.closed) {
            this.dismissedByAction = true;
            this.onAction$.next(reason);
            this.onAction$.complete();
        }
    }
    /** Gets an observable that is notified when the Toast action-dismissible is called. */
    onAction() {
        return this.onAction$;
    }
    /**
     * @hidden
     * Cleans up the DOM after closing.
     */
    _finishDismiss() {
        if (!this.onAction$.closed) {
            this.onAction$.complete();
        }
        super._finishDismiss();
    }
}

/**
 * Base Configuration class used when opening a Toast.
 */
class BaseToastConfig {
    constructor() {
        /**
         * Toast position strategy.
         */
        this.positionStrategy = ToastBottomCenterPosition;
    }
}
/**
 * Base Configuration class used when opening an animated Toast.
 */
class BaseAnimatedToastConfig extends BaseToastConfig {
    constructor() {
        super(...arguments);
        /** Whether the toast should be animated. */
        this.animated = true;
    }
}

let toastUniqueId = 0;
class BaseToastContainerComponent extends BasePortalOutlet {
    /** @hidden */
    constructor(config) {
        super();
        this.config = config;
        /** Subject for notifying that the Toast has finished exiting from view. */
        this.onExit$ = new Subject();
        /** Subject for notifying that the Toast has finished entering the view. */
        this.onEnter$ = new Subject();
        this.minWidth = this.config.minWidth;
        this.maxWidth = this.config.maxWidth;
        this.width = this.config.width;
        this.minHeight = this.config.minHeight;
        this.maxHeight = this.config.maxHeight;
        this.height = this.config.height;
        this.ariaLabel = this.config.ariaLabel;
        this.id = this.config.id || 'fd-message-toast-' + toastUniqueId++;
    }
    /**
     * Attaches component to the portal.
     */
    attachComponentPortal(portal) {
        return this._portalOutlet.attachComponentPortal(portal);
    }
    /**
     * Attaches Template to the portal.
     * @param portal
     */
    attachTemplatePortal(portal) {
        return this._portalOutlet.attachTemplatePortal(portal);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: BaseToastContainerComponent, deps: "invalid", target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "19.2.3", type: BaseToastContainerComponent, isStandalone: true, viewQueries: [{ propertyName: "_portalOutlet", first: true, predicate: CdkPortalOutlet, descendants: true, static: true }], usesInheritance: true, ngImport: i0 }); }
}
__decorate([
    coerceCssPixel,
    __metadata("design:type", Object)
], BaseToastContainerComponent.prototype, "minWidth", void 0);
__decorate([
    coerceCssPixel,
    __metadata("design:type", Object)
], BaseToastContainerComponent.prototype, "maxWidth", void 0);
__decorate([
    coerceCssPixel,
    __metadata("design:type", Object)
], BaseToastContainerComponent.prototype, "width", void 0);
__decorate([
    coerceCssPixel,
    __metadata("design:type", Object)
], BaseToastContainerComponent.prototype, "minHeight", void 0);
__decorate([
    coerceCssPixel,
    __metadata("design:type", Object)
], BaseToastContainerComponent.prototype, "maxHeight", void 0);
__decorate([
    coerceCssPixel,
    __metadata("design:type", Object)
], BaseToastContainerComponent.prototype, "height", void 0);
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: BaseToastContainerComponent, decorators: [{
            type: Directive
        }], ctorParameters: () => [{ type: undefined }], propDecorators: { _portalOutlet: [{
                type: ViewChild,
                args: [CdkPortalOutlet, { static: true }]
            }], minWidth: [], maxWidth: [], width: [], minHeight: [], maxHeight: [], height: [] } });

/**
 * Custom overlay container for CDK Overlay.
 */
class BaseToastOverlayContainer extends OverlayContainer {
    /**
     * This method returns the overlay container element. It will lazily
     * create the element the first time it is called to facilitate using
     * the container in non-browser environments.
     * @returns the container element
     */
    getContainerElement() {
        const containerElement = super.getContainerElement();
        containerElement.classList.add('fn-toast-overlay-container');
        return containerElement;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: BaseToastOverlayContainer, deps: null, target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: BaseToastOverlayContainer }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: BaseToastOverlayContainer, decorators: [{
            type: Injectable
        }] });

/**
 * Base configuration class used when opening a Toast which automatically destroys after some time.
 */
class BaseToastDurationDismissibleConfig extends BaseToastConfig {
    constructor() {
        super(...arguments);
        /**
         * The length of time in milliseconds to wait before automatically dismissing the Message Toast.
         */
        this.duration = 3000;
        /**
         * Whether the message toast should stay visible if the cursor is over it.
         * Default is `true`
         */
        this.mousePersist = true;
    }
}

class BaseToastAnimatedContainerComponent extends BaseToastContainerComponent {
    /**
     * @hidden
     * The state of the Message Toast animations.
     */
    get _animationState() {
        return this._animationStateSignal();
    }
    /** @hidden */
    constructor(config) {
        super(config);
        /**
         * @hidden
         * Whether the animations should be disabled.
         */
        this._animationsDisabled = false;
        /** @hidden */
        this._ngZone = inject(NgZone);
        /** @hidden */
        this._animationStateSignal = signal('void');
        this._animationsDisabled = !config.animated;
    }
    /**
     * @hidden
     * Handle end of animations, updating the state of the Message Toast.
     */
    _onAnimationEnd(event) {
        const { fromState, toState } = event;
        if ((toState === 'void' && fromState !== 'void') || toState === 'hidden') {
            this._completeExit();
        }
        if (toState === 'visible') {
            // Note: we shouldn't use `this` inside the zone callback,
            // because it can cause a memory leak.
            const onEnter = this.onEnter$;
            this._ngZone.run(() => {
                onEnter.next();
                onEnter.complete();
            });
        }
    }
    /** Begin animation of Message Toast entrance into view. */
    enter() {
        this._animationStateSignal.set('visible');
    }
    /** Begin animation of Message Toast removal. */
    exit() {
        this._animationStateSignal.set('hidden');
    }
    /** @hidden */
    ngOnDestroy() {
        this._completeExit();
    }
    /**
     * @hidden
     * Waits for the zone to settle before removing the element. Helps prevent
     * errors where we end up removing an element which is in the middle of an animation.
     */
    _completeExit() {
        // Note: we shouldn't use `this` inside the zone callback,
        // because it can cause a memory leak.
        const onExit = this.onExit$;
        this._ngZone.onMicrotaskEmpty.pipe(take$1(1)).subscribe(() => {
            onExit.next();
            onExit.complete();
        });
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: BaseToastAnimatedContainerComponent, deps: "invalid", target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "19.2.3", type: BaseToastAnimatedContainerComponent, isStandalone: true, host: { listeners: { "@state.done": "_onAnimationEnd($event)" }, properties: { "@state": "this._animationState", "@.disabled": "this._animationsDisabled" } }, usesInheritance: true, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: BaseToastAnimatedContainerComponent, decorators: [{
            type: Directive
        }], ctorParameters: () => [{ type: undefined }], propDecorators: { _animationState: [{
                type: HostBinding,
                args: ['@state']
            }], _animationsDisabled: [{
                type: HostBinding,
                args: ['@.disabled']
            }], _onAnimationEnd: [{
                type: HostListener,
                args: ['@state.done', ['$event']]
            }] } });

class BaseToastDurationDismissibleContainerComponent extends BaseToastAnimatedContainerComponent {
    constructor() {
        super(...arguments);
        /** Subject for notifying that component is out of hover */
        this.mouseleave$ = new Subject();
        /** Subject for notifying that component is hovered */
        this.mouseover$ = new Subject();
    }
    /** Emits mouseleave$ subject when component is out of hover. */
    onMouseLeave() {
        this.mouseleave$.next();
    }
    /** Emits mouseover$ subject when component is hovered. */
    onMouseOver() {
        this.mouseover$.next();
    }
    /** @Hidden */
    ngOnDestroy() {
        this.mouseover$.complete();
        this.mouseleave$.complete();
        super.ngOnDestroy();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: BaseToastDurationDismissibleContainerComponent, deps: null, target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "19.2.3", type: BaseToastDurationDismissibleContainerComponent, isStandalone: true, host: { listeners: { "mouseleave": "onMouseLeave()", "mouseover": "onMouseOver()" } }, usesInheritance: true, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.3", ngImport: i0, type: BaseToastDurationDismissibleContainerComponent, decorators: [{
            type: Directive
        }], propDecorators: { onMouseLeave: [{
                type: HostListener,
                args: ['mouseleave']
            }], onMouseOver: [{
                type: HostListener,
                args: ['mouseover']
            }] } });

class BaseDismissibleToastService extends BaseToastService {
    /**
     * Animates the old Toast out and the new one in.
     */
    animateToast(toastRef) {
        super.animateToast(toastRef);
        const config = toastRef.containerInstance.config;
        // If dismiss timeout is provided, set up dismiss based on after the Notification is opened.
        if (config.duration && config.duration > 0) {
            toastRef.afterOpened().subscribe(() => {
                toastRef.dismissAfter(config.duration);
                if (config.mousePersist) {
                    toastRef.containerInstance.mouseover$.subscribe(() => {
                        toastRef.cancelDismiss();
                    });
                    toastRef.containerInstance.mouseleave$.subscribe(() => {
                        toastRef.dismissAfter(config.duration);
                    });
                }
            });
        }
    }
}

/**
 * Generated bundle index. Do not edit.
 */

export { ANY_LANGUAGE_LETTERS_GROUP_REGEX, ANY_LANGUAGE_LETTERS_REGEX, AbstractFdNgxClass, AsyncOrSyncPipe, AttributeObserver, AutoCompleteDirective, AutoCompleteModule, BaseAnimatedToastConfig, BaseDismissibleToastService, BaseToastActionDismissibleRef, BaseToastConfig, BaseToastContainerComponent, BaseToastDurationDismissibleConfig, BaseToastDurationDismissibleContainerComponent, BaseToastDurationDismissibleRef, BaseToastOverlayContainer, BaseToastPosition, BaseToastRef, BaseToastService, BreakpointDirective, BreakpointModule, ClickedBehaviorModule, ClickedBehaviorModuleForRootLoadedOnce, ClickedDirective, ContentDensityService, DECIMAL_NUMBER_UNICODE_GROUP_REGEX, DECIMAL_NUMBER_UNICODE_RANGE, DECIMAL_NUMBER_UNICODE_REGEX, DEFAULT_CONTENT_DENSITY, DND_ITEM, DND_LIST, DefaultReadonlyViewModifier, DeprecatedSelector, DestroyedService, DisabledBehaviorDirective, DisabledBehaviorModule, DisabledObserver, DisplayFnPipe, DndItemDirective, DndKeyboardGroupDirective, DndKeyboardItemDirective, DndListDirective, DragAndDropModule, DynamicComponentContainer, DynamicComponentInjector, DynamicComponentService, DynamicPortalComponent, ELEMENT_REF_EXCEPTION, FDK_DISABLED_DIRECTIVE, FDK_FOCUSABLE_GRID_DIRECTIVE, FDK_FOCUSABLE_ITEM_DIRECTIVE, FDK_FOCUSABLE_LIST_DIRECTIVE, FDK_INDIRECT_FOCUSABLE_ITEM_ORDER, FDK_READONLY_DIRECTIVE, FDK_SELECTABLE_ITEM_PROVIDER, FD_DEPRECATED_DIRECTIVE_SELECTOR, FOCUSABLE_ITEM, FdkClickedProvider, FdkDisabledProvider, FdkReadonlyProvider, FilterStringsPipe, FocusKeyManagerHelpersModule, FocusKeyManagerItemDirective, FocusKeyManagerListDirective, FocusTrapService, FocusableGridDirective, FocusableGridModule, FocusableItemDirective, FocusableItemModule, FocusableListDirective, FocusableListModule, FocusableObserver, FunctionStrategy, INVALID_DATE_ERROR, IgnoreClickOnSelectionDirective, IgnoreClickOnSelectionDirectiveToken, IgnoreClickOnSelectionModule, IndirectFocusableItemDirective, IndirectFocusableListDirective, InitialFocusDirective, InitialFocusModule, IntersectionSpyDirective, IsCompactDensityPipe, KeyUtil, KeyboardSupportService, LETTERS_UNICODE_RANGE, LIST_ITEM_COMPONENT, LineClampDirective, LineClampModule, LineClampTargetDirective, LocalStorageService, MOBILE_CONFIG_ERROR, MakeAsyncPipe, ModuleDeprecations, OVERFLOW_PRIORITY_SCORE, ObservableStrategy, OnlyDigitsDirective, OnlyDigitsModule, OverflowListDirective, OverflowListItemDirective, OverflowListModule, PipeModule, PromiseStrategy, RTL_LANGUAGE, RangeSelector, ReadonlyBehaviorDirective, ReadonlyBehaviorModule, ReadonlyObserver, RepeatDirective, RepeatModule, ResizeDirective, ResizeHandleDirective, ResizeModule, ResizeObserverDirective, ResizeObserverFactory, ResizeObserverService, ResponsiveBreakpoints, RtlService, SafePipe, SearchHighlightPipe, SelectComponentRootToken, SelectableItemDirective, SelectableItemToken, SelectableListDirective, SelectableListModule, SelectionService, THEME_SWITCHER_ROUTER_MISSING_ERROR, TabbableElementService, TemplateDirective, TemplateModule, ToastBottomCenterPosition, ToastBottomLeftPosition, ToastBottomRightPosition, ToastTopCenterPosition, ToastTopLeftPosition, ToastTopRightPosition, TruncateDirective, TruncateModule, TruncatePipe, TruncatedTitleDirective, TwoDigitsPipe, UtilsModule, ValueByPathPipe, ValueStrategy, ViewportSizeObservable, alternateSetter, applyCssClass, applyCssStyle, baseToastAnimations, coerceArraySafe, coerceBoolean, coerceCssPixel, consumerProviderFactory, deprecatedModelProvider, destroyObservable, dfs, elementClick$, getBreakpointName, getDeprecatedModel, getDocumentFontSize, getElementCapacity, getElementWidth, getNativeElement, getRandomColorAccent, hasElementRef, intersectionObservable, isBlank, isBoolean, isCompactDensity, isFunction, isItemFocusable, isJsObject, isNumber, isObject, isOdd, isPresent, isPromise, isString, isStringMap, isSubscribable, isType, isValidContentDensity, moduleDeprecationsFactory, moduleDeprecationsProvider, parserFileSize, provideFdkClicked, pxToNum, resizeObservable, scrollIntoView, scrollTop, selectStrategy, setDisabledState, setReadonlyState, toNativeElement, toastConnectedBottomLeftPosition, toastConnectedBottomPosition, toastConnectedBottomRightPosition, toastConnectedTopLeftPosition, toastConnectedTopPosition, toastConnectedTopRightPosition, uuidv4, warnOnce };
//# sourceMappingURL=fundamental-ngx-cdk-utils.mjs.map
